# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.App.KeyboardShortcutManager.KeyboardShortcutManager as KeyboardShortcutManager
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import sip
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class KeyboardShortcutManagerMixin:
    def __init__(self, *args, **kwargs) -> None: ...
    def _installEventFilterForChildWidgets(self): ...
    def eventFilter(self, obj: QObject, event: QEvent) -> bool: ...
    @classmethod
    def getShortcutsContextName(cls) -> str: ...
    @classmethod
    def registerKeyboardShortcut(cls, shortcutID: str, name: str, shortcut: str, keyPressCallback: typing.Optional[typing.Callable] = ..., keyReleaseCallback: typing.Optional[typing.Callable] = ..., data: Incomplete | None = ...): ...
    @classmethod
    def setShortcutsContextName(cls, name: str): ...

class KeyboardShortcutManagerMixinMetaclass(sip.wrappertype):
    _KeyboardShortcutManagerMixinMetaclass__reservedNames: ClassVar[tuple] = ...
    def __init__(self, name: str, bases: tuple[type, ...], dct: dict) -> None: ...
    def __call__(self): ...
