# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import typing
from UI4.Widgets.StopButton import StopButton as StopButton
from typing import Set, Tuple

class ModalProcessInterruptWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, interruptCallback: typing.Callable, minWidth: int = ...) -> None: ...
    def _ModalProcessInterruptWidget__interrupt(self, *args, **kwargs): ...
    def closeEvent(self, e): ...
    def disableStopButton(self): ...
    def interrupted(self): ...
    def update(self, message, tick: bool = ...): ...
