# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyUtilModule.KatanaFile as KatanaFile
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def BrowseForLiveGroup(assetId: str = ...): ...
def CanVersionUpAndSave(): ...
def CheckForUnsavedChanges(dialogTitle: str, actionDescription: str) -> bool: ...
def ExportSelection(): ...
def Import(): ...
def ImportLiveGroup(): ...
def New(): ...
def Open(filename: Incomplete | None = ...): ...
def Revert(): ...
def Save(checkForModifiedLiveGroups: bool = ...) -> bool: ...
def SaveAs(checkForModifiedLiveGroups: bool = ...) -> bool: ...
def ShowLoadLiveGroupDialog(filenameOrAssetID: str = ..., title: str = ...) -> str: ...
def VersionUpAndSave(checkForModifiedLiveGroups: bool = ...) -> bool: ...
