# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import Utils as Utils
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from typing import Set, Tuple

class BandSelectionLayer(RectangleLayer):
    def __init__(self, clickPoint, inclusiveDrag, *args, **kwargs) -> None: ...
    def _BandSelectionLayer__cancelBandSelectMode(self): ...
    def _BandSelectionLayer__cleanUp(self): ...
    def _BandSelectionLayer__finishBandSelectMode(self): ...
    def _BandSelectionLayer__nodeDeleteHandler(self, eventType, eventID, **kwargs): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setLayerStack(self, stack): ...
