# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import ViewerAPI as ViewerAPI
from typing import Set, Tuple

def GetViewports(viewerDelegate): ...
def PopupMenuUnderWidget(menu, widget): ...
def SetOptionOnAllMonitorLayers(name, value, delegate): ...
def SetOptionOnMonitorLayer(name, value, viewport): ...
def TruncateText(text, numChars): ...
