# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
from typing import Set, Tuple

class StructuredPort:
    def __init__(self, node: NodegraphAPI.Node, port: NodegraphAPI.Port, name, parent) -> None: ...
    def getBarCode(self): ...
    def getChildren(self): ...
    def getChildrenIter(self): ...
    def getFullName(self): ...
    def getName(self): ...
    def getParent(self): ...
    def getRawPort(self): ...
    def getType(self): ...

class _NodePortQuery:
    def __init__(self, node: NodegraphAPI.Node, isInput) -> None: ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getPort(self, name): ...
    def getPorts(self): ...

def GetStructuredInputPorts(node: NodegraphAPI.Node): ...
def GetStructuredOutputPorts(node: NodegraphAPI.Node): ...
def GetStructuredPort(port: NodegraphAPI.Port): ...
