# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import AutoPosition as AutoPosition, CustomColors as CustomColors, Manifest as Manifest, NodeShapeAttrUtil as NodeShapeAttrUtil
from DrawingModule.AutoPosition import AutoPositionNodes as AutoPositionNodes, FitBackdropNodeAroundNodes as FitBackdropNodeAroundNodes, FitStickyAroundNodes as FitStickyAroundNodes
from DrawingModule.CustomColors import CopyNodeColorToLinkColor as CopyNodeColorToLinkColor, GetCustomNodeColor as GetCustomNodeColor, HasCustomNodeColor as HasCustomNodeColor, RemoveCustomNodeColor as RemoveCustomNodeColor, SetCustomNodeColor as SetCustomNodeColor
from drawing_cmodule import GetFontFile as GetFontFile, angleVector2D as angleVector2D, boundBoxBox as boundBoxBox, insideVector2DBox as insideVector2DBox, intersectBoxBox as intersectBoxBox, intersectLineBox as intersectLineBox, intersectLines as intersectLines, lengthVector2D as lengthVector2D, nodeShape_clearAllHiddenPortLinks as nodeShape_clearAllHiddenPortLinks, nodeShape_setPortLinkHidden as nodeShape_setPortLinkHidden, nodeWorld_addNode as nodeWorld_addNode, nodeWorld_draw as nodeWorld_draw, nodeWorld_drawFloatingLink as nodeWorld_drawFloatingLink, nodeWorld_drawPreselect as nodeWorld_drawPreselect, nodeWorld_drawSelectedLink as nodeWorld_drawSelectedLink, nodeWorld_drawSelectedPort as nodeWorld_drawSelectedPort, nodeWorld_drawShadow as nodeWorld_drawShadow, nodeWorld_drawText as nodeWorld_drawText, nodeWorld_findGroupNodeOfClick as nodeWorld_findGroupNodeOfClick, nodeWorld_flowText as nodeWorld_flowText, nodeWorld_getBounds as nodeWorld_getBounds, nodeWorld_getBoundsOfListOfNodes as nodeWorld_getBoundsOfListOfNodes, nodeWorld_getChildBounds as nodeWorld_getChildBounds, nodeWorld_getFloatingOffset as nodeWorld_getFloatingOffset, nodeWorld_getGroupNodeRelativeAndAbsoluteChildScales as nodeWorld_getGroupNodeRelativeAndAbsoluteChildScales, nodeWorld_getLinkEndPoints as nodeWorld_getLinkEndPoints, nodeWorld_getNodeDehilitingMode as nodeWorld_getNodeDehilitingMode, nodeWorld_getPortPosition as nodeWorld_getPortPosition, nodeWorld_getShapeAttrAsNumber as nodeWorld_getShapeAttrAsNumber, nodeWorld_getShapeAttrAsString as nodeWorld_getShapeAttrAsString, nodeWorld_hitTestBox as nodeWorld_hitTestBox, nodeWorld_hitTestInset as nodeWorld_hitTestInset, nodeWorld_hitTestNode as nodeWorld_hitTestNode, nodeWorld_hitTestPoint as nodeWorld_hitTestPoint, nodeWorld_isLargePortAreaEnabled as nodeWorld_isLargePortAreaEnabled, nodeWorld_loadSceneIntoNodegraphSvgManager as nodeWorld_loadSceneIntoNodegraphSvgManager, nodeWorld_mapFromWorldPositionToCurrentGroupWorldPosition as nodeWorld_mapFromWorldPositionToCurrentGroupWorldPosition, nodeWorld_measureText as nodeWorld_measureText, nodeWorld_moveNode as nodeWorld_moveNode, nodeWorld_refreshAllViewMaskLinkColors as nodeWorld_refreshAllViewMaskLinkColors, nodeWorld_refreshAllViewMasks as nodeWorld_refreshAllViewMasks, nodeWorld_refreshNodeViewMaskFlags as nodeWorld_refreshNodeViewMaskFlags, nodeWorld_removeNode as nodeWorld_removeNode, nodeWorld_sceneIsLoadedIntoNodegraphSvgManager as nodeWorld_sceneIsLoadedIntoNodegraphSvgManager, nodeWorld_setExpressionLinksEnabled as nodeWorld_setExpressionLinksEnabled, nodeWorld_setFloatingOffset as nodeWorld_setFloatingOffset, nodeWorld_setLargePortAreaEnabled as nodeWorld_setLargePortAreaEnabled, nodeWorld_setLargePortAreaIncludeTypes as nodeWorld_setLargePortAreaIncludeTypes, nodeWorld_setLowContrastLookEnabled as nodeWorld_setLowContrastLookEnabled, nodeWorld_setNodeActive as nodeWorld_setNodeActive, nodeWorld_setNodeDehilitingEnabled as nodeWorld_setNodeDehilitingEnabled, nodeWorld_setNodeDehilitingMode as nodeWorld_setNodeDehilitingMode, nodeWorld_setNodeState as nodeWorld_setNodeState, nodeWorld_setNodeThumbnail as nodeWorld_setNodeThumbnail, nodeWorld_setNodeThumbnailEnabled as nodeWorld_setNodeThumbnailEnabled, nodeWorld_setParent as nodeWorld_setParent, nodeWorld_setShapeAttr as nodeWorld_setShapeAttr, nodeWorld_setShowNodeIcons as nodeWorld_setShowNodeIcons, nodeWorld_setViewMasksEnabled as nodeWorld_setViewMasksEnabled, nodeWorld_shouldLargePortAreaIncludeInputPorts as nodeWorld_shouldLargePortAreaIncludeInputPorts, nodeWorld_shouldLargePortAreaIncludeOutputPorts as nodeWorld_shouldLargePortAreaIncludeOutputPorts, nodeWorld_tranformPointToChildSpace as nodeWorld_tranformPointToChildSpace, nodeWorld_updateNodeHiliteTableWithIncomingNodes as nodeWorld_updateNodeHiliteTableWithIncomingNodes, normalizeVector2D as normalizeVector2D, scaleBoxVector2D as scaleBoxVector2D, translateBoxVector2D as translateBoxVector2D
from typing import Set, Tuple

NodeDehilightingModeConnected: int
NodeDehilightingModeContributing: int
