# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import Utils as Utils
from NodegraphAPI_cmodule import Predefined as Predefined
from typing import Set, Tuple

def AddNodeFlavor(nodeType, flavor): ...
def ClearFlavorNodes(flavor): ...
def GetAllFlavors(): ...
def GetFlavorNodes(flavor, filterExists: bool = ...): ...
def GetNodeFlavors(nodeType): ...
def NodeMatchesFlavors(nodeType, flavors, ignoreFlavors): ...
def RemoveNodeFlavor(nodeType, flavor): ...
