# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import Nodes2DAPI as Nodes2DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
from UI4.Widgets.SortablePanel import ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget
from typing import Set, Tuple

class GradientInputPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def _GradientInputPanel__valueChangedCallback(self): ...
    def getName(self): ...

class LinearGradientGroupFormWidget(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _getPanelForPolicy(self, vp): ...
    def addPoint(self): ...
    def buildAddMenu(self, menu): ...

class SuperGradientFormWidget(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _getPanelForPolicy(self, vp): ...
    def addPoint(self): ...
    def buildAddMenu(self, menu): ...
