# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ChildProcess:
    def __init__(self, childProc) -> None: ...
    def kill(self, sig): ...
    def poll(self): ...
    def read(self, n): ...
    def write(self, str): ...
    def __del__(self) -> None: ...
