# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from typing import ClassVar, Set, Tuple

class LightLinkItemDelegate(ParameterItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    MinimumColumnWidth: ClassVar[int] = ...
    _LightLinkItemDelegate__colors: ClassVar[None] = ...
    def _LightLinkItemDelegate__getBadgeColors(self, isEnabled: bool, isLocal: bool) -> tuple[QColor, QColor, QColor]: ...
    def _LightLinkItemDelegate__getBadgeDimensions(self, option: PyQt5.QtWidgets.QStyleOptionViewItem) -> None: ...
    def _LightLinkItemDelegate__getLightData(self, index: PyQt5.QtCore.QModelIndex): ...
    def getContentWidth(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> int: ...
    def paint(self, painter: PyQt5.QtGui.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
