# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class FnMatchHintsDelegate:
    def __init__(self, hints) -> None: ...
    def addWidgetHints(self, param, name, attrDict): ...

class SimpleDictHintsDelegate:
    def __init__(self, hints) -> None: ...
    def addWidgetHints(self, param, name, attrDict): ...

def RegisterAttributeHintsDelegate(delegate): ...
def RegisterHintsDelegate(nodeType, delegate): ...
def UpdateAttributeHintsWithDelegates(name, attrDict): ...
def UpdateHintsWithDelegates(nodeType, param, name, attrDict): ...
