# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.DynamicTemplateGroup
from UI4.FormMaster.Editors.DynamicTemplateGroup import DynamicTemplateGroupFormWidget as DynamicTemplateGroupFormWidget
from UI4.FormMaster.Editors.ShadingNetworkPopupButton import ShadingNetworkPopupButton as ShadingNetworkPopupButton
from typing import ClassVar, Set, Tuple

class NetworkMaterialParameterEditFormWidget(UI4.FormMaster.Editors.DynamicTemplateGroup.DynamicTemplateGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _NetworkMaterialParameterEditFormWidget__addNode(self, groupName): ...
    def _NetworkMaterialParameterEditFormWidget__getMaterialAttr(self): ...
    def _NetworkMaterialParameterEditFormWidget__getNetworkAttr(self): ...
    def _NetworkMaterialParameterEditFormWidget__toggleNodeCallback(self, name): ...
    def _buildControlWidget(self, layout): ...
    def _childPanelsShouldAddWrench(self): ...
    def _menuAction(self, action): ...
    def buildAddMenu(self, menu): ...

class _NodeCheckboxLayer(QT4GLLayerStack.LayerStack.Layer):
    toggleNode: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, name, param) -> None: ...
    def _NodeCheckboxLayer__getMenu(self): ...
    def _NodeCheckboxLayer__toggleName(self): ...
    def processEvent(self, event): ...
