# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def begin_timing(context): ...
def end_timing(context): ...
def init_gpu_timing(name): ...
def render_timing_stats(layerStack): ...
