# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import Set, Tuple

class AssetIdSaveWidget(AssetIdWidget):
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...

class AssetIdWidget(StringFormWidget):
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...
    def _AssetIdWidget__getRenderNodeFromEvent(self, event): ...
    def _AssetIdWidget__setupEventHandlers(self, active): ...
    def _AssetIdWidget__showExtendedInfo(self, infoDialog): ...
    def _AssetIdWidget__updatePluginWidget(self, *args, **kwargs): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _fillMenu(self, menu): ...
    def _filterValueText(self, text): ...
    def _freeze(self): ...
    def _helper(self): ...
    def _lockChanged(self, state): ...
    def _popupMenuCreated(self, menu): ...
    def _thaw(self): ...
    def _updateControlWidget(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def getMenu(self): ...
    def valueChangedEvent(self, event): ...

class FileInputWidget(AssetIdWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class LiveGroupSourceWidget(AssetIdWidget):
    class PolicyWrapper(QT4FormWidgets.ValuePolicy.ValuePolicyProxy):
        def isLocked(self): ...
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...
    def isLocked(self): ...
