# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Tabs.ExampleProjectsTab.ExampleProjectsTab import ExampleProjectsTab as ExampleProjectsTab
from typing import Set, Tuple

PluginRegistry: list
