# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from UI4.Util.ScenegraphLocation import GetNodesCreatingSceneGraphLocations as GetNodesCreatingSceneGraphLocations
from typing import ClassVar, Set, Tuple

class MaterialAssignDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    _ValidItems: ClassVar[list] = ...
    _ValidNodes: ClassVar[list] = ...
    def _MaterialAssignDelegate__droppedNode(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialAssignDelegate__droppedScenegraphItem(self, targetNode, item): ...
    def _MaterialAssignDelegate__validNodeDrop(self, targetNode, event): ...
    def _MaterialAssignDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...
