# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

def GetMissingOpenGlExtensions() -> list[str | None]: ...
def ShowErrorInitializingOpenGlDialog() -> bool: ...
def ShowExtensionErrorDialog(window, missingExtensions): ...
def ShowRemoteHostDialog(window, missingExtensions): ...
