# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from typing import Set, Tuple

def DrawBucketOrderPreview(catalogItem, layerview, numTiles: int = ...): ...
def DrawBufferRectVisualization(catalogItem, layerview): ...
