# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class FormWidgetLabel(PyQt5.QtWidgets.QLabel):
    def __init__(self, text: str, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def FormatByteSize(size: int) -> str: ...
    def _FormWidgetLabel__updateToolTip(self): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def getBuddy(self): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def setColor(self, color: PyQt5.QtGui.QColor): ...
    def setText(self, text: str): ...
