# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import ConfigurationAPI_cmodule as Configuration
import PyUtilModule.FileUtils as FileUtils
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyUtilModule.ScenegraphBookmarkManager as ScenegraphBookmarkManager
import PyUtilModule.UndoEntries as UndoEntries
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

def CrashSave(forceSave: bool = ..., logCompletion: bool = ...): ...
def CrashSaveDisable(): ...
def CrashSaveEnable(): ...
def CreateSceneAsset(asset: str, versionUp: bool = ..., publish: bool = ..., extraOptionsDict: dict = ...) -> str: ...
def Export(fileNameOrAssetId: str, nodes: list[NodegraphAPI.Node], extraOptionsDict: Incomplete | None = ...) -> str: ...
def GetCrashActions() -> int: ...
def GetCrashTime() -> float: ...
def GetTimeOfFirstUnsavedAction() -> float | None: ...
def GetViableCrashFiles(smartPrune: bool = ...) -> list: ...
def Import(fileName: str, floatNodes: bool = ..., parentNode: Incomplete | None = ...) -> list[NodegraphAPI.Node]: ...
def IsFileDirty() -> bool: ...
def IsFileSavedAsAsset() -> bool: ...
def Load(fileName: str, isCrashFile: bool = ...): ...
def New(): ...
def Paste(nodeXML: str, parent: NodegraphAPI.GroupNode): ...
def PopFileDirtyState(): ...
def PostCreateSceneAsset(asset: str, versionUp: bool = ..., publish: bool = ..., extraOptionsDict: dict = ...) -> str: ...
def PushFileDirtyState(): ...
def RegisterPasteHandler(cb: typing.Callable): ...
def Revert(): ...
def Save(fileNameOrAssetId: str, extraOptionsDict: Incomplete | None = ...) -> str: ...
def SetFileDirty(): ...
def WasFileLoadedFromCrashFile() -> bool: ...
def WasFileVersionedOnLoad() -> bool: ...
