# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

APPLICATION_ACTIVESHELF: str
APPLICATION_CODEFONTFAMILY: str
APPLICATION_CODEFONTSIZE: str
APPLICATION_DISMISSED_TAB_DEPRECATION_WARNINGS: str
APPLICATION_FONTFAMILY: str
APPLICATION_FONTSIZE: str
APPLICATION_MACRO_SAVE_PATH: str
APPLICATION_NODESPECIFICACTIVESHELF: str
APPLICATION_NUMBEROFRECENTPROJECTS: str
APPLICATION_NUMBEROFRECENTPROJECTS_MAX: int
APPLICATION_SCENEGRAPHACTIVESHELF: str
ATTRIBUTES: str
ATTRIBUTES_SHOW_INTERNAL_NODES_IN_ATTRIBUTE_HISTORY: str
CATALOG: str
CATALOG_COLUMNWIDTH: str
CATALOG_CREATE_PER_RENDER_PROJECT_SNAPSHOT: str
CATALOG_STATE: str
CATALOG_SYNC_TO_PROJECT_SETTINGS: str
COLOR: str
COLOR_ENABLE_DISPLAY_TRANSFORM_DEFAULT: str
COLOR_RESTRICT_RGBA_COMPONENTS_DEFAULT: str
COLOR_USE_SINGLE_COMPONENT_RGB: str
CRASHFILE: str
CRASHFILE_NUMBEROFACTIONS: str
CRASHFILE_TIME: str
DOCUMENTATION: str
DOCUMENTATION_SOURCE: str
DOPESHEET: str
DOPESHEET_SHOWTOOLTIPS: str
EXTERNAL_TOOLS: str
EXTERNAL_TOOLS_EDITOR: str
EXTERNAL_TOOLS_IMAGE_VIEWER: str
EXTERNAL_TOOLS_PDF_VIEWER: str
EXTERNAL_TOOLS_WEB_BROWSER: str
EXT_SUFFIX: str
ExpansionHandleColor: int
ExpansionHandleDraggedColor: int
ExpansionHandleHighlightColor: int
FLIPBOOK: str
FLIPBOOK_COLORSPACE: str
FLIPBOOK_FORMAT: str
HighlightColor: int
JoiningLineColor: int
LAYOUT: str
LAYOUT_DEFAULT: str
LAYOUT_HOTKEY1: str
LAYOUT_HOTKEY2: str
LAYOUT_HOTKEY3: str
LAYOUT_HOTKEY4: str
MANIPULATOR_LOCKEDCOLOR: str
MANIPULATOR_NORMALCOLOR: str
MANIPULATOR_SELECTCOLOR: str
MONITOR: str
MONITOR_ALLOW_KEYLESS_TABLET_INTERACTION: str
MONITOR_BGCOLOR: str
MONITOR_RENDER_ID_PASS: str
MONITOR_SHOW: str
MONITOR_SHOWSWIPELINE: str
MONITOR_SHOW_COLORTIMING: str
MONITOR_SHOW_COMMENT: str
MONITOR_SHOW_OVERLAY: str
MONITOR_SHOW_PIXEL_PROBE: str
MONITOR_SHOW_TEXT_RESOLUTION: str
MONITOR_SWIPELINECOLOR: str
NODEGRAPH: str
NODEGRAPH_ALLOW_KEYLESS_TABLET_INTERACTION: str
NODEGRAPH_AUTOCONNECTONCREATE: str
NODEGRAPH_AUTOSCROLL: str
NODEGRAPH_DEFAULT_VIEWSTATE: str
NODEGRAPH_DIMNONCONTRIBUTINGNODES: str
NODEGRAPH_DIMUNCONNECTEDTOVIEWNODE: str
NODEGRAPH_DRAWLOWCONTRAST: str
NODEGRAPH_FIND_ONLY_NODES_IN_THIS_GROUP_DEFAULT: str
NODEGRAPH_FLAGERRORSFILEIN: str
NODEGRAPH_FLAGERRORS_NODE_CONNECTION: str
NODEGRAPH_GRIDSNAP: str
NODEGRAPH_LOCKSTICKYNOTENODES: str
NODEGRAPH_NME_DIMDISCONNECTEDNODES: str
NODEGRAPH_NME_DIMEDITEDNODES: str
NODEGRAPH_NME_DIMNEWNODES: str
NODEGRAPH_NME_DIMUNCHANGEDNODES: str
NODEGRAPH_SHOWARROWS: str
NODEGRAPH_SHOWEXPRESSIONLINKS: str
NODEGRAPH_SHOWNODEICONS: str
NODEGRAPH_SHOWPAGESCONNECTEDONLY: str
NODEGRAPH_SHOWROLLOVERNODENAMES: str
NODEGRAPH_SHOWVIEWMASKS: str
NODEGRAPH_STICKYDRAG: str
NODEGRAPH_USE_COLOR_FROM_INPUT_PORT_FOR_CONNECTIONS: str
NODEMENU: str
NODEMENU_CATEGORIES: str
NODEMENU_DEFAULT_CATEGORIES: str
NODEMENU_RECENTCOUNT: str
NODEMENU_RECENTLIST: str
NODES: str
NODES_GAFFER: str
NODES_GAFFER_SYNC_SELECTION: str
NODES_LOOKFILEMANAGER: str
NODES_LOOKFILEMANAGER_ADDASLOOKFILEGLOBALSDEFAULT: str
PARAMETERS: str
PARAMETERS_CACHEEDITORS: str
PARAMETERS_OPENCELEDITORS: str
PARAMETERS_SELECT_LINE_EDIT_TEXT_ON_FOCUS: str
PARAMETERS_SINGLE_DIGIT_SCROLLING: str
PARAMETERS_STICKY_SCRUB: str
RECENTFILES: str
RENDERING: str
RENDERING_CONCURRENTRENDERS: str
RENDERING_RENDER_VARIABLES_PINNED_BY_DEFAULT: str
RENDERING_RESTART_LIVE_RENDER_ON_TIME: str
RENDERING_THREADS_2D: str
RENDERING_THREADS_3D: str
RENDERING_UPDATEMODE2D: str
RENDERING_UPDATEMODE3D: str
RENDERING_USE_THREAD_PREF: str
SCENEGRAPH: str
SCENEGRAPH_FIND_FILTERS: list
SCENEGRAPH_FIND_FILTER_ALL: str
SCENEGRAPH_FIND_FILTER_CAMERAS: str
SCENEGRAPH_FIND_FILTER_DEFAULT: str
SCENEGRAPH_FIND_FILTER_LIGHTS: str
SCENEGRAPH_FIND_FILTER_PINNED: str
SCENEGRAPH_FIND_FILTER_SELECTED: str
SCENEGRAPH_SHOWLIGHTSCOLUMN: str
SCENEGRAPH_SHOW_RENDER_COLUMN: str
SCENEGRAPH_SHOW_VIEWER_VISIBILITY_COLUMN: str
SCENEGRAPH_USER_COLUMN: str
SCENEGRAPH_USER_COLUMN_EXT: str
SplineColor: int
SplineHighlightColor: int
TERMINAL: str
TERMINAL_AUTOCOMPLETIONBEHAVIOR: str
TERMINAL_AUTOCOMPLETIONBEHAVIORS: list
TERMINAL_AUTOCOMPLETIONBEHAVIOR_IDE: int
TERMINAL_AUTOCOMPLETIONBEHAVIOR_SHELL: int
TERMINAL_AUTOINDENT: str
TERMINAL_COMMAND_AREA_BUFFER: str
TERMINAL_FORMATTER: str
TERMINAL_FORMATTERSTYLE: str
TERMINAL_HIGHLIGHTTRAILINGWHITESPACE: str
TERMINAL_RULERPOSITION: str
TERMINAL_SHOWRULER: str
TERMINAL_TOOLTIPS: str
TERMINAL_WORDWRAP: str
TangentArrowHeadColor: int
TangentColor: int
TangentDraggedColor: int
TangentHighlightColor: int
TangentLineColor: int
VIEWER: str
VIEWER_ANTIALIASING: str
VIEWER_BACKGROUND_COLOR: str
VIEWER_FACE_SELECTION_COLOR: str
VIEWER_FACE_SELECT_MODE_COLOR: str
VIEWER_MANIPULATION_FREEZE_PERIOD: str
VIEWER_MANIPULATORS: str
VIEWER_MANIPULATORS_SCALE: str
VIEWER_MONITOR_LAYER: str
VIEWER_MONITOR_LAYER_HIGHLIGHT_COLOR: str
VIEWER_MONITOR_LAYER_SELECTION_COLOR: str
VIEWER_SCREENWINDOW: str
VIEWER_SCREENWINDOW_COLOR: str
VIEWER_SCREENWINDOW_DASHED: str
VIEWER_SCREENWINDOW_LINEWIDTH: str
VIEWER_SELECTION_COLOR: str
VIEWER_SNAPPING: str
VIEWER_SNAPPING_AXIS_NORMAL_ORIENTATION: str
VIEWER_SNAPPING_AXIS_UP_ORIENTATION: str
VIEWER_SNAPPING_HIT_AREA_COLOR: str
VIEWER_SNAPPING_HIT_AREA_SIZE: str
VIEWER_SNAPPING_WIREFRAME_COLOR: str
VertexClosureColor: int
VertexColor: int
VertexHighlightColor: int
VertexSelectColor: int
