# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
from UI4.Tabs.NodeGraphTab.Layers.MenuLayer import MenuLayer as MenuLayer
from typing import Set, Tuple

_NODE_EXCLUDE_LIST: set
g_chosenNodeType: None
g_entries: list
kDeprecatedColor: tuple

class NodeCreationMenuLayer(MenuLayer):
    def _isNodeTypeVisible(self, nodeType: str) -> bool: ...
    def getBottomText(self): ...
    def getChosenValue(self): ...
    def getEntries(self): ...
    def onEntryChosen(self, value): ...
    def setEntries(self, entries): ...

def _on_nodegraph_registerType(eventType: str | None, eventID: object, type: str): ...
