# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class MaterialDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def __init__(self, editValue, inheritValue, nodeTypes, editParamName: str = ..., inheritParamName: str = ...) -> None: ...
    def _MaterialDelegate__dialogPrompt(self, nodeType, nameString): ...
    def _MaterialDelegate__editFromNodeReference(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialDelegate__editFromScenegraphLocation(self, targetNode, loc): ...
    def _MaterialDelegate__inheritFromNodeReference(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialDelegate__inheritFromScenegraphLocation(self, targetNode, loc): ...
    def _MaterialDelegate__validNodeDrop(self, targetNode, event): ...
    def _MaterialDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...
