# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FilterFieldWidget(PyQt5.QtWidgets.QFrame):
    filterUpdate: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, name: str = ..., filterTypes: Incomplete | None = ..., yellowClearIcon: bool = ...) -> None: ...
    def _FilterFieldWidget__clearFilterField(self): ...
    def clear(self): ...
    def getFilterField(self): ...
    def getFilterText(self): ...
    def getFilterType(self): ...
    def signalUpdate(self, text: Incomplete | None = ...): ...
