# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import MachineInfo as MachineInfo
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import UI4 as UI4
import Utils as Utils
from Callbacks.Callbacks import Callbacks as Callbacks
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from _typeshed import Incomplete
from typing import Set, Tuple

class PreferenceValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent: Incomplete | None = ..., name: str = ...) -> None: ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getPrefType(self): ...
    def getType(self): ...
    def getValue(self) -> Tuple[float, int | str]: ...
    def getWidgetHints(self): ...
    def restoreOldValues(self): ...
    def saveOldValues(self): ...
    def setValue(self, value: Tuple[float, int | str], final: bool = ...) -> bool: ...

class PreferencesDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, *args, **kwargs) -> None: ...
    def accept(self): ...
    def reject(self): ...
    def selectItem(self, category): ...

class PreferencesEditor(PyQt5.QtWidgets.QWidget):
    def __init__(self, *args) -> None: ...
    def _PreferencesEditor__currentItemChanged(self, item): ...
    def buildPrefFrame(self, prefName): ...
    def rebuildContent(self, keepItems: bool = ...): ...
    def revert(self): ...
    def selectItem(self, itemName): ...
    def showEvent(self, event): ...
    def store(self): ...

def ApplyPreferences(): ...
def ShowPreferencesDialog(*args, **kwargs): ...
