# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from typing import ClassVar, Set, Tuple

class NameItemDelegate(BaseItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    PolishOpAttributeName: ClassVar[str] = ...
    TopLevelLocation: ClassVar[str] = ...
    _NameItemDelegate__customIcons: ClassVar[dict] = ...
    _NameItemDelegate__greyColor: ClassVar[None] = ...
    _NameItemDelegate__pinnedPixmaps: ClassVar[dict] = ...
    _NameItemDelegate__visibilityPixmaps: ClassVar[dict] = ...
    def _NameItemDelegate__applyCustomIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, locationType: str, isVisible: int, localVisible: bool, isPinned: bool, childrenPinned: bool): ...
    def _NameItemDelegate__applyIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, icon: PyQt5.QtGui.QIcon, width: int, height: int): ...
    def _NameItemDelegate__applySceneGraphLocationTypeIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, locationType: str): ...
    def _NameItemDelegate__createPinnedPixmap(self, pinned: bool, childrenPinned: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__createVisibilityPixmap(self, visible: int, local: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__getAttributePixmapKey(self, attributeValue: int, local: bool, height: float) -> str: ...
    def _NameItemDelegate__getPinnedPixmap(self, pinned: bool, childrenPinned: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__getPinnedStatus(self, locationPath: str) -> tuple[bool, bool]: ...
    def _NameItemDelegate__getVisibilityPixmap(self, visible: int, local: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _applyIconDecorations(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def _getGreyColor(self) -> None: ...
    def _isMuted(self, locationPath: str) -> bool: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def shouldShowPinning(self) -> bool: ...
