# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LineNumberAreaWidget(PyQt5.QtWidgets.QWidget):
    kBackgroundColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kCurrentLineTextColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kTextColor: ClassVar[PyQt5.QtGui.QColor] = ...
    def __init__(self, textEdit) -> None: ...
    def _LineNumberAreaWidget__getDigitCount(self): ...
    def _LineNumberAreaWidget__getDigitWidth(self): ...
    def _LineNumberAreaWidget__getMargin(self): ...
    def _LineNumberAreaWidget__on_textEdit_cursorPositionChanged(self): ...
    def _LineNumberAreaWidget__on_textEdit_documentUpdated(self, rect: Incomplete | None = ...): ...
    def _LineNumberAreaWidget__on_textEdit_selectionChanged(self): ...
    def _LineNumberAreaWidget__updateGeometry(self): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...
