# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def AddLayer(color: Incomplete | None = ..., label: str = ...): ...
def ClearAll(): ...
def DeleteLayer(index): ...
def GetLayerName(index): ...
def GetLayers(): ...
def GetRoot(): ...
def ReorderLayer(oldPos, newPos): ...
