# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class DoubleSpinBox(PyQt5.QtWidgets.QDoubleSpinBox):
    def __init__(self, parent) -> None: ...
    def mouseReleaseEvent(self, event): ...
    def stepBy(self, steps): ...
    def wheelEvent(self, event): ...
