# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FormWidget import FormWidget
from UI4.Widgets.HorizontalDivider import HorizontalDivider as HorizontalDivider
from typing import Set, Tuple

class SeparatorFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, text): ...
    def _destroyLabel(self): ...
    def setHeight(self, height): ...
    def setSeparatorLabel(self, text): ...
