# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import PyQt5.QtCore as QtCore
from UI4.Widgets.FilterPopups import ShaderFilterPopup as ShaderFilterPopup
from typing import Set, Tuple

class ShaderComboBox(QT4FormWidgets.InputWidgets.InputComboBox):
    def __init__(self, parent: QT4FormWidgets.FormWidget) -> None: ...
    def _ShaderComboBox__on_shaderFilterPopup_hide(self): ...
    def _ShaderComboBox__on_shaderFilterPopup_itemChosen(self, text, meta): ...
    def _ShaderComboBox__on_shaderFilterPopup_show(self): ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
    def showPopup(self): ...
