# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.Bridge
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate import NameItemDelegate as NameItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class SceneGraphTabColorColumnDelegate(BaseItemDelegate):
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def paint(self, painter: PyQt5.QtGui.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...

class SceneGraphTabCustomColumnDelegate(BaseItemDelegate):
    ColorSwatchWidth: ClassVar[int] = ...
    Margin: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    Padding: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _SceneGraphTabCustomColumnDelegate__getDisplayValue(self, modelValues: list[PyQt5.QtCore.QVariant]) -> str: ...
    def _SceneGraphTabCustomColumnDelegate__getModelValues(self, index: PyQt5.QtCore.QModelIndex) -> list[PyQt5.QtCore.QVariant | None]: ...
    def _drawColorSwatch(self, painter: PyQt5.QtGui.QPainter, values: list[PyQt5.QtCore.QVariant], parentRect: PyQt5.QtCore.QRect, width: int) -> PyQt5.QtCore.QRect: ...
    def _drawLabel(self, painter, values, parentRect): ...
    def _variantsToFloats(self, values): ...
    def isColorSwatchEnabled(self) -> bool: ...
    def isFilmlookEnabled(self) -> bool: ...
    def isLabelsEnabled(self) -> bool: ...
    def paint(self, painter: PyQt5.QtGui.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setColorSwatchEnabled(self, colorSwatchEnabled: bool): ...
    def setFilmlookEnabled(self, filmlookEnabled: bool): ...
    def setLabelsEnabled(self, labelsEnabled: bool): ...

class SceneGraphTabNameItemDelegate(NameItemDelegate):
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def shouldShowPinning(self) -> bool: ...
