# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import ResolutionTable as ResolutionTable
from typing import ClassVar, Set, Tuple

class ResolutionComboBox(QT4FormWidgets.InputWidgets.InputComboBox):
    _ResolutionComboBox__Groups: ClassVar[dict] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    @staticmethod
    def _ResolutionComboBox__GroupsCallback(value: str, name: str, meta: object) -> bool: ...
    def _ResolutionComboBox__on_filterablePopup_aboutToShow(self): ...
    def _ResolutionComboBox__on_filterablePopup_hide(self): ...
    def _ResolutionComboBox__on_filterablePopup_itemChosen(self, text, meta): ...
    def _ResolutionComboBox__on_filterablePopup_show(self): ...
    def getResolutionTableEntry(self) -> ResolutionTable.ResolutionTableEntry: ...
    def getSettings(self) -> tuple[str, int, int, float]: ...
    def getSize(self) -> None: ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
    def setSelectionByName(self, name: str): ...
    def setSelectionBySize(self, width: int, height: int, aspectRatio: float = ...): ...
    def showPopup(self): ...
