# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI_cmodule as Nodes2DAPI_cmodule
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

_mtrsCache: dict

class _frame:
    def __init__(self, x0, y0, x1, y1) -> None: ...

def GetDisplayWindow(port: int = ..., node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def GetXform(node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def GetXformR(node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def GetXformS(node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def GetXformT(node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def _GetXformMTRS(node: typing.Optional[NodegraphAPI.Node] = ..., time: Incomplete | None = ...): ...
def __clearMTRSCache(*args, **kwargs): ...
def _getSourcePortAndTime(portName, node: NodegraphAPI.Node, time): ...
