# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import ConfigurationAPI_cmodule as Configuration
import Utils.EventModule as EventModule
import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import PyXmlIO as PyXmlIO
import Utils as Utils
import NodegraphAPI.Version as Version
import NodegraphAPI.Xio as Xio
from NodegraphAPI_cmodule import __root_node as __root_node
from _typeshed import Incomplete
from typing import Set, Tuple

def CheckNodeType(node: NodegraphAPI.Node, stringOrClassTypes): ...
def GetAutoKeyAll() -> bool: ...
def GetCurrentTime() -> float: ...
def GetInTime() -> float: ...
def GetKatanaSceneName() -> str | None: ...
def GetNodegraphVersionString(xmlString) -> str: ...
def GetOriginalProjectAssetID() -> str: ...
def GetOriginalSourceFile() -> str: ...
def GetOutTime() -> float: ...
def GetProjectAssetID() -> str: ...
def GetProjectDir() -> str: ...
def GetProjectFile() -> str: ...
def GetRootNode() -> NodegraphAPI.GroupNode: ...
def GetSourceFile() -> str: ...
def GetTimeIncrement() -> float: ...
def GetWorkingInTime() -> float: ...
def GetWorkingOutTime() -> float: ...
def IsLoading() -> bool: ...
def IsLoadingAsync() -> bool: ...
def LoadXmlFromFile(fileName): ...
def LoadXmlFromString(stringData): ...
def NeedsRedraw(): ...
def NewNodegraph(): ...
def RegisterNodegraphChangedEvents(): ...
def ResetAllFloatingCurves(): ...
def SetAutoKeyAll(autoKeyAll: bool): ...
def SetCurrentTime(newTime: float, final: bool = ...): ...
def SetInTime(inTime: float, final: bool = ...): ...
def SetKatanaSceneName(katanaSceneName): ...
def SetNeedsRedraw(state): ...
def SetOriginalProjectAssetID(originalProjectAssetID): ...
def SetOriginalSourceFile(originalSourceName): ...
def SetOutTime(outTime: float, final: bool = ...): ...
def SetProjectAssetID(filenameOrAssetID: str): ...
def SetRootNode(newNode): ...
def SetSourceFile(filenameOrAssetID: str): ...
def SetTimeIncrement(incTime: float, final: bool = ...): ...
def SetWorkingInTime(workingInTime: float, final: bool = ...): ...
def SetWorkingOutTime(workingOutTime: float, final: bool = ...): ...
def UpdatePluginsFromGlobals(): ...
def WriteKatanaFile(filename: str, element: PyXmlIO.Element, compress: bool = ..., archive: bool = ..., opaqueParams: Incomplete | None = ...): ...
def WriteKatanaString(element: PyXmlIO.Element, compress: bool = ..., archive: bool = ..., opaqueParams: Incomplete | None = ...) -> str: ...
