# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import WorkQueue as WorkQueue
from typing import Set, Tuple

class QuadTree:
    def __init__(self) -> None: ...
    def _QuadTree__filterTree(self): ...
    def addContent(self, items): ...
    def clear(self): ...
    def filterTreeBegin(self): ...
    def getContentsInRect(self, rect): ...
    def setBounds(self, rect): ...

class QuadTreeNode:
    def __init__(self, bounds, depth: int = ...) -> None: ...
    def GetMaxDepth(self, depth): ...
    def _QuadTreeNode__distributeToChildren(self, items): ...
    def addContent(self, item): ...
    def clear(self): ...
    def getBounds(self): ...
    def getContentsInRect(self, rect): ...
    def printContents(self, depth: int = ...): ...
    def setBounds(self, rect): ...

def rectContainsPoint(rect, point): ...
def rectsIntersect(rect1, rect2): ...
