# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import Utils as Utils
from PyUtilModule.VirtualKatana import RenderGlobals as RenderGlobals, RenderManager as RenderManager
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from typing import Set, Tuple

class RoiLayer(RectangleLayer):
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def _RoiLayer__renderManager_roiChanged_CB(self, eventType, eventID, *args, **kwargs): ...
    def _RoiLayer__updateROI(self): ...
    def getDataWindow(self): ...
    def getDisplayWindow(self): ...
    def processEvent(self, event): ...
    def setRectangle(self, rect): ...
    def update(self): ...
