# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from QT4Widgets.FilterFieldWidget import FilterFieldWidget as FilterFieldWidget
from QT4Widgets.TreeWidgetUtil import UpdateSuppressor as UpdateSuppressor
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class BrowserColumn(PyQt5.QtWidgets.QFrame):
    itemDoubleClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    itemSelectionChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _BrowserColumn__doubleClick(self, index): ...
    def _BrowserColumn__treeMousePress(self, event): ...
    def _BrowserColumn__updateSelectNoneState(self): ...
    def filterItem(self, item, text, filterType): ...
    def getFilterField(self): ...
    def getFooter(self): ...
    def getHeader(self): ...
    def getSelectedItem(self): ...
    def getStatusLabel(self): ...
    def getTree(self): ...
    def selectItemByName(self, name): ...
    def singleVisibleItem(self): ...
    def updateFilter(self, text: Incomplete | None = ..., filterType: Incomplete | None = ...): ...
