# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import GeoAPI as GeoAPI
import QT4FormWidgets.InputWidgets as InputWidgets
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
from QT4FormWidgets.WidgetFactory import WidgetFactory
from UI4.Widgets.ComboBoxNoWheel import ComboBoxNoWheel as ComboBoxNoWheel
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumn as SceneGraphColumn
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class ScenegraphColumnDescriptionWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    class ColumnAction(PyQt5.QtWidgets.QAction):
        def __init__(self, scenegraphColumnWidget, newColumnArgs: None, *args) -> None: ...
        def _ColumnAction__activatedCallback(self): ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _ScenegraphColumnDescriptionWidget__buildBaseValueFromPanels(self) -> str: ...
    def _ScenegraphColumnDescriptionWidget__buildExtValueFromPanels(self) -> str: ...
    def _ScenegraphColumnDescriptionWidget__processGenericAssignAttrs(self, attr, menu: PyQt5.QtWidgets.QMenu, parentName: str = ...): ...
    def _ScenegraphColumnDescriptionWidget__updateModel(self): ...
    def buildAddMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    @classmethod
    def getColumnPreferenceKeys(cls) -> None: ...
    def panelDeleted(self, index: Unused): ...
    def panelValueChanged(self, index: Unused): ...
    def updateLabel(self): ...
    def updatePanels(self): ...

class TagEditorPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, tags: None) -> None: ...
    def _TagEditorPanel__changedCallback(self, *args): ...
    def getAttrLocality(self) -> str: ...
    def getBaseValue(self) -> None: ...
    def getDisplayType(self) -> str: ...
    def getExtValue(self) -> None: ...
    def getName(self) -> str: ...
    def getNoneAttrValue(self) -> str: ...
    def isVisible(self) -> str: ...
    def updateEnabledState(self): ...

def buildPreferences(baseValue: str, extValue: str) -> tuple: ...
