# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFCurve as PyFCurve
import Utils as Utils
from typing import Set, Tuple

class FCurveSelectionSnapshot(PyFCurve.SelectionObserver):
    def __init__(self, container, selection) -> None: ...
    def _FCurveSelectionSnapshot__keyframeSelectTuple(self, keyframe): ...
    def deselected(self, object): ...
    def restoreSelection(self): ...
    def restoreSelectionConditional(self): ...
    def selected(self, object): ...
    def selectionCleared(self): ...
    def setIgnoreChanges(self, ignore): ...
    def snapshotSelection(self): ...
