# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import Set, Tuple

class RectangleLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _RectangleLayer__fillBackground(self): ...
    def _RectangleLayer__findDragEdges(self, localX, localY): ...
    def _RectangleLayer__paintDimBackground(self): ...
    def _RectangleLayer__pointInCenter(self, localX, localY): ...
    def _RectangleLayer__pointInRect(self, localX, localY, includeGravity: bool = ...): ...
    def _RectangleLayer__pointOnAxis(self, localX, localY): ...
    def beginEdgeDrag(self, xEdge, yEdge): ...
    def boxColor(self): ...
    def center(self): ...
    def clamped(self): ...
    def defaultProcessEvent(self, event): ...
    def dimBackground(self): ...
    def displayRectangle(self): ...
    def drawBox(self): ...
    def edgeDragProcessEvent(self, event): ...
    def endEdgeDrag(self): ...
    def intermediate(self): ...
    def originLock(self): ...
    def outlineWidth(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def rectangle(self): ...
    def rectangleDragProcessEvent(self, event): ...
    def setBoxColor(self, color): ...
    def setCenter(self, center): ...
    def setClamped(self, v): ...
    def setDimBackground(self, flag): ...
    def setDrawBox(self, drawFlag): ...
    def setOriginLock(self, v): ...
    def setOutlineWidth(self, width): ...
    def setRectangle(self, rect): ...
    def setSize(self, size): ...
    def size(self): ...
    def windowRectangle(self): ...
