# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.Layers.Transform2D as Transform2D
import UI4.FormMaster.Editors.Layers.Transform2D
import Utils as Utils
from typing import Set, Tuple

class RepositionManipLayer(UI4.FormMaster.Editors.Layers.Transform2D.Transform2DManipLayer):
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def getTranslate(self): ...
    def hasRotate(self): ...
    def hasScale(self, horizontal): ...
    def hasTranslate(self, horizontal): ...
    def setTranslate(self, value, final): ...
    def translateIsExpressioned(self, horizontal): ...
    def translateIsLocked(self, horizontal): ...
