# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Flavor as Flavor
import NodegraphAPI.NodeExtensions as NodeExtensions
import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import NodegraphAPI.NodegraphGlobals as NodegraphGlobals
import Utils as Utils
from typing import Set, Tuple

class SuperTool(NodegraphAPI_cmodule.PythonGroupNode):
    def __init__(self) -> None: ...
    def getNodesCreatingSceneGraphLocations(self) -> list[NodegraphAPI.Node | None]: ...
    def hideNodegraphGroupControls(self): ...
    def isChildNodePersistent(self, node: NodegraphAPI.Node) -> bool: ...
    def isUserParameterEditingAllowed(self) -> bool: ...
    def polish(self): ...
    @classmethod
    def superToolRegistered(cls): ...

def RegisterSuperTool(name, superToolClass): ...
