# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyUtilModule.EnvUtils as EnvUtils
import UI4.Util.ExternalTools as ExternalTools
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class RenderLogTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _RenderLogTab__actionMenuAboutToShow(self): ...
    def _RenderLogTab__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item): ...
    def _RenderLogTab__catalog_rebuild_CB(self, args: list): ...
    def _RenderLogTab__clearContents_CB(self): ...
    def _RenderLogTab__numLinesChanged_CB(self): ...
    def _RenderLogTab__on_renderLogWidget_autoScrollingChanged(self, autoScrolling: bool): ...
    def _RenderLogTab__on_scrollLockToolButton_clicked(self): ...
    def _RenderLogTab__openInEditor_CB(self): ...
    def _RenderLogTab__updateScrollLockToolButton(self, autoScrolling: bool): ...
    def copySelectedTextActionCallback(self): ...
    def getCatalogItem(self): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
    def setCatalogItem(self, item): ...
