# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from typing import Set, Tuple

class GraphStateVariablesFormWidget(GroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _GraphStateVariablesFormWidget__addVariable(self): ...
    def _GraphStateVariablesFormWidget__deleteAllVariables(self): ...
    def _GraphStateVariablesFormWidget__on_menuButton_menu(self, menu): ...
    def _lockChanged(self, state): ...
