# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.ArrayItemEntry as ArrayItemEntry
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4FormWidgets.GroupFormWidget import GroupFormWidget as GroupFormWidget
from QT4FormWidgets.InputWidgets import InputLineEdit as InputLineEdit
from typing import Set, Tuple

class MultiFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _MultiFormWidget__doValueEdit(self): ...
    def _MultiFormWidget__freezeEntries(self): ...
    def _MultiFormWidget__syncArrayValues(self): ...
    def _buildControlWidget(self, controlLayout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _freeze(self): ...
    def _lockChanged(self, state): ...
    def _participatesInLabelAlignment(self): ...
    def _thaw(self): ...
    def showPopdown(self, value): ...
    def valueChangedEvent(self, event): ...
