# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from typing import Set, Tuple

class HtmlEditorFormWidget(FormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _HtmlEditorFormWidget__expressionChanged(self): ...
    def _HtmlEditorFormWidget__toggleExpressionState(self): ...
    def _HtmlEditorFormWidget__valueChanged(self, event): ...
    def _freeze(self): ...
    def _lockChanged(self, value): ...
    def _thaw(self): ...
    def cleanupError(self, error): ...
    def doReturnPressed(self): ...
    def generateMenu(self): ...
