# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from PyQt5.QtGui import EXPRESSION_TRIANGLE_COLOR as EXPRESSION_TRIANGLE_COLOR, TEXTCOLOR_ERROR as TEXTCOLOR_ERROR, TEXTCOLOR_WARNING as TEXTCOLOR_WARNING
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import Set, Tuple

HIGHLIGHTSTYLE_ALWAYS: int
HIGHLIGHTSTYLE_NONE: int
HIGHLIGHTSTYLE_ROLLOVER: int
HIGHLIGHTSTYLE_TRANSPARENT: int
PALETTE_COLOR_ROLES_POLICY: list
PALETTE_COLOR_ROLES_READ_ONLY: list
STATE_BADGE_DEFAULT_SIZE: int
TOGGLE_STATE_BADGE_DEFAULT_SIZE: int

def ApplyPolicyPalette(policy: QT4FormWidgets.AbstractValuePolicy, widget: PyQt5.QtWidgets.QWidget, locked: Incomplete | None = ...): ...
def GetDefaultBoldLabelFont(): ...
def GetDefaultFixedPitchFont(): ...
def GetDefaultLabelFont(scale: Incomplete | None = ...): ...
def GetDefaultSecondaryLabelFont(): ...
def GetGroupLabelColor(palette: Incomplete | None = ...): ...
def GetHighlightColor(palette, on: bool = ..., active: bool = ...): ...
def GetPolicyPalette(policy: QT4FormWidgets.AbstractValuePolicy, locked: Incomplete | None = ...) -> PyQt5.QtGui.QPalette: ...
def GetReadOnlyPalette(locked: bool) -> PyQt5.QtGui.QPalette: ...
def GetStateBadgePixmap(letter, color, palette: Incomplete | None = ...): ...
def HighlightStyleValid(style): ...
def PaintBicolorRect(painter, rect, ulColor, lrColor): ...
def PaintCheckers(painter, rect, size: int = ..., lightValue: int = ..., darkValue: int = ...): ...
def PaintDisclosureTriangle(painter, _width, height, aspect, palette, rotation: Incomplete | None = ..., size: Incomplete | None = ..., outlineColor: Incomplete | None = ..., color: Incomplete | None = ..., hovered: bool = ...): ...
def PaintDragBar(painter, rect, multiplier: float = ...): ...
def PaintGroupEnclosureSidebar(painter, fullRect, color, end: bool = ..., sidebarWidth: int = ...): ...
def PaintHighlightBar(painter, fullRect, color, roundTop: bool = ..., roundBottom: bool = ...): ...
def PaintQLineEditText(painter, option, flags, text, leftAlignUnderflow: bool = ...): ...
def PaintStateBadge(painter, width, height, letter, color, palette: Incomplete | None = ..., glow: bool = ..., textColor: Incomplete | None = ..., size: int = ...): ...
def PaintToggleStateBadge(painter, width, height, color, palette: Incomplete | None = ..., glow: bool = ..., size: int = ...): ...
def UpdateFontCache(font): ...
