# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import GetCapsuleRgbaDict as GetCapsuleRgbaDict
from typing import Set, Tuple

BloomAmountParamHints: dict
BloomEnableParamHints: dict
BloomGroupParamHints: dict
BloomModeParamHints: dict
BloomThresholdParamHints: dict
BorderExtendParamHints: dict
BorderOverscanParamHints: dict
_NodeHints: dict
_NodeName: str
