# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from typing import Set, Tuple

class StringFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _StringFormWidget__on_control_textChanged(self, text): ...
    def _StringFormWidget__on_defaultButton_clicked(self): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _filterValueText(self, text): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...
    def selectAll(self): ...
