# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

SMALL: float

class UnDegenerator:
    def __init__(self) -> None: ...
    def RGBAFromComponent(self, componentValue, component, baseColor: Incomplete | None = ..., lockedComponents: Incomplete | None = ...): ...
    def getNonDegenerateColor(self, component): ...
    def setColor(self, color): ...

def IsComponentDegenerate(componentValue, component): ...
