# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class ImplicitFilterToggle(ToolbarButton):
    def __init__(self, parent) -> None: ...
    def _ImplicitFilterToggle__clicked(self): ...
    def _ImplicitFilterToggle__updateCallback(self, eventType, scenegraphID, implicitResolversActive, **kwargs): ...

class ImplicitFilterWarningLabel(PyQt5.QtWidgets.QFrame):
    def __init__(self, *args) -> None: ...
    def _ImplicitFilterWarningLabel__highlightedText(self, text): ...
    def _ImplicitFilterWarningLabel__implicitResolverListText(self, stage): ...
    def _ImplicitFilterWarningLabel__update(self, eventType, scenegraphID, implicitResolversActive, **kwargs): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
