# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from typing import ClassVar, Set, Tuple

class VariablesPopup(PyQt5.QtWidgets.QFrame):
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def hideEvent(self, e): ...
    def popup(self, globalPos): ...
    def showEvent(self, e): ...

class VariablesPopupButton(PyQt5.QtWidgets.QFrame):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _VariablesPopupButton__clicked(self): ...
    def _VariablesPopupButton__on_updateTextTimer_timeout(self): ...
    def _VariablesPopupButton__popupHidden(self): ...
    def _VariablesPopupButton__popupShow(self): ...
    def _VariablesPopupButton__possibleChange(self, args): ...
    def _VariablesPopupButton__updateText(self): ...
    def mousePressEvent(self, ev): ...
