# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class GetSetAction(PyQt5.QtWidgets.QAction):
    def __init__(self, name, parent, value, setFunc, getFunc, expandTuple: bool = ..., shortcut: Incomplete | None = ..., isBoolean: bool = ..., useWeakMethod: bool = ...) -> None: ...
    def doGet(self): ...
    def doSet(self): ...

class GetSetMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, name, parent) -> None: ...
    def _GetSetMenu__doAboutToShow(self): ...
    def _GetSetMenu__doTriggered(self, action): ...
