# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ResourceManager:
    def __init__(self, paths, exceptionForMissing: bool = ...) -> None: ...
    def clearCache(self): ...
    def getResourceFile(self, resourceName): ...
    def isExceptionForMissing(self): ...
    def setExceptionForMissing(self, doExc): ...
