# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class ContextMenuHelper:
    def __init__(self, tree, event) -> None: ...
    def __enter__(self): ...
    def __exit__(self, *args): ...

class UpdateSuppressor:
    def __init__(self, treeWidget) -> None: ...
    def __enter__(self): ...
    def __exit__(self, *args): ...
