# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def TraceCall(loggerOrFunction: Incomplete | None = ...): ...
def stacktrace(_name): ...
def undogroup(_name): ...
