# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class WorkQueue:
    class QueueAbort(Exception): ...
    def __init__(self, busyProcess: Incomplete | None = ...) -> None: ...
    def _WorkQueue__disable(self, cleanExit): ...
    def _WorkQueue__enable(self): ...
    def _WorkQueue__idleCB(self, *args, **kwargs): ...
    def addWork(self, fcn, *args, **kwargs): ...
    def addWorkToFront(self, fcn, *args, **kwargs): ...
    def busy(self): ...
    def checkAbort(self): ...
    def empty(self): ...
    def finishWork(self): ...
    def report(self): ...
    def workCompletedCleanExit(self): ...
    def workCompletedEarlyExit(self): ...
