# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from PyUtilModule.WorkingSet import WorkingSet as WorkingSet
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class WorkingSetDebugNode(Node3D):
    _WorkingSetDebugNode__OutputAttributeName: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _WorkingSetDebugNode__locationStateChangedCallback(self, locationStateChanges, workingSet, sender): ...
    def _WorkingSetDebugNode__updateWorkingSet(self, workingSetName): ...
    def _WorkingSetDebugNode__updateWorkingSetParams(self, workingSet): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...

def __GetWorkingSetContentsChildren(): ...
