# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.VerticalDivider import VerticalDivider as VerticalDivider
from typing import ClassVar, Set, Tuple

class ToolbarWidget(PyQt5.QtWidgets.QWidget):
    toolbarChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _ToolbarWidget__toolbarChoiceTriggered_CB(self, action): ...
    def _ToolbarWidget__updateToolbar(self): ...
    def addToolbar(self, toolbar): ...
    def popToolbar(self, toolbar): ...
    def removeToolbar(self, toolbar): ...
