# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import Set, Tuple

class PanInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, name, *args, **kwargs) -> None: ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setHorizontalLock(self, isLocked): ...
    def setVerticalLock(self, isLocked): ...
    def thaw(self): ...

class PanTransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, event, horizontalLock, verticalLock, prevFocusLayer, *args, **kwargs) -> None: ...
    def _PanTransientLayer__setup(self): ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setLayerStack(self, s): ...
    def thaw(self): ...
