# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LabeledToolbarButton(PyQt5.QtWidgets.QWidget):
    class _ClickLabel(PyQt5.QtWidgets.QLabel):
        clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def mousePressEvent(self, event): ...
    toggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label, parent, *args, **kwargs) -> None: ...
    def isOn(self): ...
    def setOn(self, on): ...

class ToolbarButton(PyQt5.QtWidgets.QPushButton):
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rightClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label, parent, normalPixmap, disabledPixmap: Incomplete | None = ..., rolloverPixmap: Incomplete | None = ..., onPixmap: Incomplete | None = ..., sizeFromPixmap: bool = ..., isToggle: bool = ..., disabledRolloverPixmap: Incomplete | None = ..., onRolloverPixmap: Incomplete | None = ..., errorPixmap: Incomplete | None = ..., errorRolloverPixmap: Incomplete | None = ..., clickAction: Incomplete | None = ...) -> None: ...
    def _ToolbarButton__actionToggled(self): ...
    def _ToolbarButton__update(self): ...
    def disabledPixmap(self): ...
    def disabledRolloverPixmap(self): ...
    def enterEvent(self, ev): ...
    def errorPixmap(self): ...
    def errorRolloverPixmap(self): ...
    def isEnabled(self): ...
    def isError(self): ...
    def isOn(self): ...
    def leaveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def normalPixmap(self): ...
    def onPixmap(self): ...
    def onRolloverPixmap(self): ...
    def rolloverPixmap(self): ...
    def setDisabledPixmap(self, p): ...
    def setDisabledRolloverPixmap(self, p): ...
    def setEnabled(self, value): ...
    def setError(self, value, toolTip: Incomplete | None = ...): ...
    def setErrorPixmap(self, p): ...
    def setErrorRolloverPixmap(self, p): ...
    def setNormalPixmap(self, p): ...
    def setOn(self, value): ...
    def setOnPixmap(self, p): ...
    def setOnRolloverPixmap(self, p): ...
    def setRolloverPixmap(self, p): ...
    def toggle(self): ...
    def triggerAction(self): ...
