# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import DrawingModule as DrawingModule
import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from PyUtilModule.VirtualKatana import KatanaFile as KatanaFile
from typing import Set, Tuple

class DragAndDropLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _DragAndDropLayer__getDropNode(self, event): ...
    def _DragAndDropLayer__getGroup(self, event): ...
    def _DragAndDropLayer__handleFaceSetDrop(self, event): ...
    def _DragAndDropLayer__handleFileRefDrop(self, event): ...
    def _DragAndDropLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _DragAndDropLayer__setDropNode(self, node: NodegraphAPI.Node): ...
    def _DragAndDropLayer__setHiliteGroup(self, group): ...
    def dragMoveEvent(self, event): ...
    def dropEvent(self, event): ...
    def dropPosition(self, parentNode, event): ...
    def paintGL(self): ...
    def processEvent(self, event): ...

def CatalogDialogPrompt(parent): ...
def GetCatalogItemFromEvent(event): ...
