# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Utils as Utils
from typing import ClassVar, Set, Tuple

class LayerWithTransform:
    _LayerWithTransform__identity: ClassVar[tuple] = ...
    def __init__(self, node: NodegraphAPI.Node) -> None: ...
    def _LayerWithTransform__freeze(self): ...
    def _LayerWithTransform__setupEventHandlers(self, enabled): ...
    def _LayerWithTransform__thaw(self): ...
    def _LayerWithTransform__transformPoint(self, matrix, point2D): ...
    def _LayerWithTransform__updateEditToMonitorTransform(self): ...
    def _LayerWithTransform__updateEditTransformCallback(self, args): ...
    def applyWorldSpace(self): ...
    def applyWorldSpaceWithDropShadow(self, screendx: float = ..., screendy: float = ...): ...
    def editTransformHasError(self): ...
    def getEditTransformErrorMessage(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getViewScale(self): ...
    def mapFromQTLocalToWorld(self, qtLocalX, qtLocalY): ...
    def mapFromWindowToWorld(self, winX, winY): ...
    def mapFromWorldToQTLocal(self, layerX, layerY): ...
    def mapFromWorldToWindow(self, layerX, layerY): ...
    def updateEditTransform(self): ...
