# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import GeoAPI as GeoAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets as Widgets
from typing import Set, Tuple

class ArgsExportDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, shaderName, rendererInfoPluginName) -> None: ...
    def _ArgsExportDialog__fileToggleCallback(self): ...
    def _ArgsExportDialog__okClicked(self): ...
    def _ArgsExportDialog__publishToggleCallback(self): ...
    def _ArgsExportDialog__updateState(self): ...
    def _ArgsExportDialog__validityChangeCallback(self, state): ...
    def getResult(self): ...
