# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogNameWidget(PyQt5.QtWidgets.QLabel):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogNameWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogNameWidget__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def resizeEvent(self, event: PyQt5.QtGui.QResizeEvent): ...
    def setCatalogItem(self, catalogItem: CatalogAPI.CatalogItem.CatalogItem | None): ...
    def updateState(self): ...
