# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def DefaultResourcePath(subdir: Incomplete | None = ...): ...
def GetIconPath(name: str) -> str | None: ...
def GetResourceFile(resourceName: str): ...
def GetSearchPaths(subdir: str = ...) -> list[str]: ...
def GetUserKatanaPath(subdir: str = ...) -> str: ...
def Initialize(): ...
def InternalResourcePath(subdir: Incomplete | None = ...): ...
