# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from typing import ClassVar, Set, Tuple

class CheckBoxFormWidget(BaseValueFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _CheckBoxFormWidget__checkControlWidget(self, state): ...
    def _CheckBoxFormWidget__interpretValue(self, value): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...

class MinimalCheckBox(PyQt5.QtWidgets.QWidget):
    stateChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def checkState(self) -> PyQt5.QtCore.Qt.CheckState: ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def setCheckState(self, state: PyQt5.QtCore.Qt.CheckState): ...
