# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.Edge as Edge
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class DragOverlay(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent) -> None: ...
    def _isCompositingEnabled(self): ...
    def hide(self): ...
    def paintEvent(self, event): ...
    def setPosition(self, area, rects): ...
    def show(self): ...

class HighlightRubberBand(PyQt5.QtWidgets.QRubberBand):
    def paintEvent(self, event): ...

class SplittableBoxOverlay(PyQt5.QtWidgets.QWidget):
    def __init__(self) -> None: ...
    def _SplittableBoxOverlay__tick(self): ...
    def paintEvent(self, event): ...
    def setRect(self, rect, showSplits): ...
    def show(self): ...

def GetHighlightColor(palette: PyQt5.QtGui.QPalette) -> PyQt5.QtGui.QColor: ...
def _BlendColors(c1, c2, blend): ...
