# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Utils as Utils
from typing import ClassVar, Set, Tuple

class CelResultsWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, paths) -> None: ...
    def _CelResultsWidget__aboutToDrag(self, dragItems, dragObject): ...
    def _CelResultsWidget__actionMenuAboutToShow(self): ...
    def _CelResultsWidget__deleteHidden(self): ...
    def _CelResultsWidget__deleteSelected(self): ...
    def _CelResultsWidget__filterUpdate(self, filterText): ...
    def _CelResultsWidget__keypressCallback(self, event): ...
    def _CelResultsWidget__onlyShowBaseName(self, checked): ...
    def _CelResultsWidget__selectAllVisible(self): ...
    def getTreeWidget(self): ...
    def showEvent(self, event): ...
    def sizeHint(self): ...
    def update(self): ...

class CelResultsWindow(PyQt5.QtWidgets.QDialog):
    _CelResultsWindow__dialogs: ClassVar[dict] = ...
    def __init__(self, paths) -> None: ...
    def closeEvent(self, event): ...
