# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.BaseParameterPolicy
import Utils as Utils
from typing import Set, Tuple

class ParameterPolicyDelegate:
    def createPolicy(self, parentPolicy, param): ...

def CreateDefaultParameterPolicy(parentPolicy, param): ...
def CreateParameterPolicy(parentPolicy: UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy | None, param: NodegraphAPI.Parameter) -> UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy | None: ...
def IsParameterEnabled(param): ...
def RegisterPolicyDelegate(typeName, delegate): ...
