# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class ComboBoxNoWheel(PyQt5.QtWidgets.QComboBox):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def keyPressEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def wheelEvent(self, event): ...
