# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
from typing import Set, Tuple

class HistogramLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def drawHistogram(self): ...
    def getHistogram(self): ...
    def isChannelEnabled(self, channel): ...
    def paintGL(self): ...
    def setChannels(self, channels): ...
    def setHistogram(self, histogram): ...
    def setScale(self, scale): ...
