# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyXmlIO as PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.SortablePanel
import Utils as Utils
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget
from UI4.Widgets.SortablePanel import ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget, SortablePanelBase as SortablePanelBase
from typing import Set, Tuple

class FileOutFormatFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class FileOutInputsEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FileOutInputsEditor__actionMenuCB(self, menu): ...
    def _FileOutInputsEditor__addInputCB(self): ...
    def _FileOutInputsEditor__portsUpdate(self): ...
    def _FileOutInputsEditor__portsUpdateCB(self, args): ...
    def _FileOutInputsEditor__postCreateAssets(self, versionUp: bool = ...): ...
    def _FileOutInputsEditor__postCreateAssetsVersionUp(self): ...
    def _FileOutInputsEditor__preCreateAssets(self, versionUp: bool = ...): ...
    def _FileOutInputsEditor__preCreateAssetsVersionUp(self): ...
    def _FileOutInputsEditor__renumberPanels(self): ...
    def _FileOutInputsEditor__setupEventHandlers(self, enabled): ...
    def _freeze(self): ...
    def _getPanelForPolicy(self, vp): ...
    def _thaw(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class FileOutPostScriptsEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FileOutPostScriptsEditor__portsUpdate(self): ...
    def _FileOutPostScriptsEditor__portsUpdateCB(self, args): ...
    def _FileOutPostScriptsEditor__renumberPanels(self): ...
    def _FileOutPostScriptsEditor__setupEventHandlers(self, enabled): ...
    def _freeze(self): ...
    def _getPanelForPolicy(self, vp): ...
    def _thaw(self): ...
    def addPostScript(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class FileOutRepPrefixFormWidget(StringFormWidget):
    def __init__(self, *args) -> None: ...
    def _checkControlWidget(self): ...
    def setIndex(self, index): ...

class FileOutRepPrefixHelp(QT4FormWidgets.InputWidgets.HelpFWidget):
    def __init__(self, *args) -> None: ...
    def getHelpText(self): ...
    def getHelpType(self): ...
    def isHelpEnabled(self): ...
    def setIndex(self, index): ...

class InputPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def _InputPanel__copyExpression(self): ...
    def setIndex(self, index): ...

class PostScriptPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def setIndex(self, index): ...
