# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import KatanaResources as KatanaResources
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
from PyUtilModule.ScenegraphUtils import AbbreviateScenegraphLocations as AbbreviateScenegraphLocations
from QT4Widgets.FilterablePopupButton import FilterablePopupButton as FilterablePopupButton
from UI4.Widgets.SceneGraphView.SceneGraphView import SceneGraphView
from typing import ClassVar, Set, Tuple

class SceneGraphFindButton(FilterablePopupButton):
    _SceneGraphFindButton__SelectAllButtonText: ClassVar[str] = ...
    def __init__(self, parent, sceneGraphView) -> None: ...
    def _SceneGraphFindButton__getFilteredLocationPaths(self, locationFilter: str) -> list[str]: ...
    def _SceneGraphFindButton__getSelectedLocations(self): ...
    def _SceneGraphFindButton__getVisibleCameraLocations(self): ...
    def _SceneGraphFindButton__getVisibleLightLocations(self): ...
    def _SceneGraphFindButton__getVisibleLocations(self): ...
    def _SceneGraphFindButton__on_aboutToShow(self, *args): ...
    def _SceneGraphFindButton__on_itemChosen(self, nodeName, meta): ...
    def _SceneGraphFindButton__scrollToLocation(self, locationPath): ...
    def _SceneGraphFindButton__selectAllClicked(self): ...
    def _SceneGraphFindButton__setSelectButtonState(self, addToSelection: bool = ...): ...
    def _getAttribute(self, locationPath, attributeName): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def getSceneGraphView(self) -> SceneGraphView: ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def setLocationFilter(self, locationFilter: str): ...
