# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets as Widgets
from QT4FormWidgets.FormWidget import FormWidget
from typing import ClassVar, Set, Tuple

class DeferredGroupTreeFormWidget(FormWidget):
    NAMECOLUMN: ClassVar[int] = ...
    STATECOLUMN: ClassVar[int] = ...
    VALUECOLUMN: ClassVar[int] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _DeferredGroupTreeFormWidget__addExpandedDescendentsToStash(self, item): ...
    def _DeferredGroupTreeFormWidget__addPolicyChildren(self, policy, parentItem): ...
    def _DeferredGroupTreeFormWidget__filterUpdate(self, filterText): ...
    def _DeferredGroupTreeFormWidget__refresh(self): ...
    def _DeferredGroupTreeFormWidget__treeAboutToDrag(self, dragItems, dragObject): ...
    def _DeferredGroupTreeFormWidget__treeContextMenuEvent(self, event): ...
    def _DeferredGroupTreeFormWidget__treeItemCollapsed(self, item): ...
    def _DeferredGroupTreeFormWidget__treeItemExpanded(self, item): ...
    def _DeferredGroupTreeFormWidget__treeKeyPressEvent(self, event): ...
    def _DeferredGroupTreeFormWidget__treeMousePressEvent(self, event): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _thaw(self): ...
    def on_copyAction_triggered(self): ...
    def showPopdown(self, value): ...
