# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from typing import ClassVar, Set, Tuple

class FileSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _FileSaveDialog__updateState(self): ...
    def _FileSaveDialog__validityChangeCallback(self, state): ...
    def getResult(self): ...

class FileSaveWidget(PyQt5.QtWidgets.QWidget):
    fileTextChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    validityChange: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _FileSaveWidget__browseCallback(self): ...
    def _FileSaveWidget__fileTextChanged(self, text): ...
    def _FileSaveWidget__setValid(self, valid): ...
    def getActionMenu(self): ...
    def getResult(self): ...
    def isValid(self): ...
    def setLocation(self, loc): ...

class ProductOrFileSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _ProductOrFileSaveDialog__fileToggleCallback(self): ...
    def _ProductOrFileSaveDialog__productToggleCallback(self): ...
    def _ProductOrFileSaveDialog__updateState(self): ...
    def _ProductOrFileSaveDialog__validityChangeCallback(self, state): ...
    def addAdditionalWidgets(self, layout): ...
    def addButtonsToLayout(self): ...
    def getProductSaveWidget(self): ...
    def getResult(self): ...
    def isValid(self): ...
    def validityChange(self): ...

class ProductSaveDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, options: dict = ...) -> None: ...
    def _ProductSaveDialog__updateState(self): ...
    def _ProductSaveDialog__validityChangeCallback(self, state): ...
    def addAdditionalWidgets(self, layout): ...
    def getResult(self): ...
    def isValid(self): ...
    def validityChange(self): ...

class _ClickableHBox(PyQt5.QtWidgets.QFrame):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def mousePressEvent(self, e): ...
