# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

NoVersion: tuple

def GetCurrentVersion(): ...
def GetNodegraphVersion(xmlString): ...
def GetVersionKey(version): ...
def VersionCmp(a, b): ...
def tupleToVersion(versionTuple): ...
def versionToTuple(versionTag): ...
