# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import Set, Tuple

class AbstractSyntaxHighlighter(PyQt5.QtGui.QSyntaxHighlighter):
    def __init__(self, document: PyQt5.QtWidgets.QTextEdit | PyQt5.QtGui.QTextDocument | PyQt5.QtCore.QObject, baseFormat: PyQt5.QtGui.QTextCharFormat, specialWords: Incomplete | None = ...) -> None: ...
    def _AbstractSyntaxHighlighter__configureHighlighter(self): ...
    def _createCustomBlocks(self): ...
    def _createFormat(self, color: str = ..., backgroundColor: str = ..., underlineColor: str = ..., style: str = ...) -> PyQt5.QtGui.QTextCharFormat: ...
    def _createFormats(self) -> dict[str, PyQt5.QtGui.QTextCharFormat]: ...
    def _createPostBlockRules(self): ...
    def _createRules(self): ...
    def _getBaseFormat(self) -> PyQt5.QtGui.QTextCharFormat: ...
    def highlightBlock(self, text: str): ...
    def setTrailingWhitespaceHighlighted(self, trailingWhitespaceHighlighted: bool): ...
