# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class _GlobalColorPolicy(PyQt5.QtCore.QObject):
    displayChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def _GlobalColorPolicy__rebuildProcessor(self): ...
    def getDisplay(self): ...
    def getDisplayColorSpaceName(self): ...
    def getNoFilmlookColorSpaceName(self): ...
    def getNoFilmlookProcessor(self): ...
    def getProcessor(self): ...
    def setDisplay(self, display): ...

def ApplyFilmlook(color, processor: Incomplete | None = ...): ...
def GetErrorMessageForColor(color, checkAlpha: bool = ...): ...
def GetGlobalColorPolicy(): ...
def GetGlobalDisplay(): ...
def Get_UseFixedSatHSV(): ...
def Get_UseSingleComponentRGB(): ...
def SetGlobalDisplay(display): ...
def Set_UseFixedSatHSV(value): ...
def Set_UseSingleComponentRGB(value): ...
