# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ScriptButtonFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ScriptButtonFormWidget__clicked(self): ...
    def _buildControlWidget(self, layout): ...
    def _thaw(self): ...
    def contextMenuEvent(self, event): ...
    def setLabelWidth(self, width): ...

class ScriptToolbarFormWidget(FormWidget):
    class _ToolbarButton(PyQt5.QtWidgets.QPushButton):
        runscript: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, parent, name: str = ..., iconPath: Incomplete | None = ..., scriptText: Incomplete | None = ..., flat: bool = ...) -> None: ...
        def _ToolbarButton__clicked(self): ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ScriptToolbarFormWidget__runScript(self, button, scriptText): ...
    def _buildControlWidget(self, layout): ...
    def contextMenuEvent(self, event): ...
    def setLabelWidth(self, width): ...
