# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple

class Criteria:
    def __init__(self, numberOfElements: int = ...) -> None: ...
    def getAsFloat(self) -> tuple[float, ...]: ...
    def getAsInt(self) -> tuple[int, ...]: ...
    def getAsObject(self) -> tuple[Any, ...]: ...
    def getAsString(self) -> tuple[str, ...]: ...
    def setValue(self, index: int, value): ...
