# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.InputWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class ColorTextValidator(PyQt5.QtGui.QValidator):
    def __init__(self, *args) -> None: ...
    def parseColor(self, text): ...
    def validate(self, inStr, qPos): ...

class ColorTextWidget(QT4FormWidgets.InputWidgets.InputLineEdit):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _ColorTextWidget__updateText(self): ...
    def _ColorTextWidget__valueChangedCB(self): ...
    def getColorText(self, color): ...
    def keyPressEvent(self, event): ...
    def setColor(self, color): ...

def ColorFromText(text): ...
def ColorToText(color, roundDigits: int = ...): ...
