# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DefaultColorPanel(PyQt5.QtWidgets.QFrame):
    class ColorEntry(PyQt5.QtWidgets.QFrame):
        colorSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, color, emitFromWidget, *args) -> None: ...
        def enterEvent(self, ev): ...
        def leaveEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def paintEvent(self, ev): ...
        def sizeHint(self): ...
        def sizePolicy(self): ...
    _DefaultColorPanel__hues: ClassVar[list] = ...
    colorSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...

class EditBackdropNodeDialog(PyQt5.QtWidgets.QDialog):
    DEFAULT_GREY: ClassVar[float] = ...
    MIN_FONTSCALE: ClassVar[float] = ...
    def __init__(self, node: NodegraphAPI.Node, previewCallback: typing.Optional[typing.Callable] = ...) -> None: ...
    def _EditBackdropNodeDialog__buildWidgets(self): ...
    def _EditBackdropNodeDialog__connectSignals(self): ...
    def _EditBackdropNodeDialog__finalizeNodeAttrs(self): ...
    def _EditBackdropNodeDialog__fontScaleChanged(self, event): ...
    def _EditBackdropNodeDialog__fontScaleEdited(self, text): ...
    def _EditBackdropNodeDialog__setColor(self, event): ...
    def _EditBackdropNodeDialog__setShapeAttrs(self, **attrs): ...
    def _EditBackdropNodeDialog__setText(self): ...
    def _EditBackdropNodeDialog__updateFontScale(self, fontScale): ...
    def accept(self): ...
    def getColor(self): ...
    def getFontScale(self): ...
    def getShowInBookmarks(self): ...
    def getText(self): ...
    def reject(self): ...

class StickyNoteInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    @staticmethod
    def _StickyNoteInteractionLayer__calcNodeAreaSq(node: NodegraphAPI.Node): ...
    def _StickyNoteInteractionLayer__findBackdropChildren(self, backdropNode): ...
    def _StickyNoteInteractionLayer__findBackdropDescendants(self, backdropNode): ...
    def _StickyNoteInteractionLayer__handleBackdropClicked(self, backdropNode, event): ...
    def _StickyNoteInteractionLayer__node_delete_cb(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _StickyNoteInteractionLayer__node_shapeAttr_changed(self, node: NodegraphAPI.Node, attrDict): ...
    def processEvent(self, event): ...
