# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.FormWidget import FormWidget
from UI4.FormMaster.Editors.NodeDropWidget import NodeDropWidget as NodeDropWidget
from typing import ClassVar, Set, Tuple

class NodeDropLabel(PyQt5.QtWidgets.QLabel):
    nodeDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...

class NodeProxyPlaceholderWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _NodeProxyPlaceholderWidget__buildOrUpdateDropWidget(self): ...
    def _NodeProxyPlaceholderWidget__nodeDropped(self, path): ...
    def decorateUserParameterFrame(self, parent): ...
