# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
from typing import ClassVar, Set, Tuple

class AttrTypes:
    kTypeAnyAttribute: ClassVar[int] = ...
    kTypeDoubleAttribute: ClassVar[int] = ...
    kTypeDynamic: ClassVar[int] = ...
    kTypeFloatAttribute: ClassVar[int] = ...
    kTypeGroupAttribute: ClassVar[int] = ...
    kTypeIntAttribute: ClassVar[int] = ...
    kTypeNumericAttribute: ClassVar[int] = ...
    kTypeStringAttribute: ClassVar[int] = ...
    @classmethod
    def toString(cls, value: int) -> str: ...

class OpDescription:
    def __init__(self, opType: str, descriptionAttr: PyFnAttribute.GroupAttribute) -> None: ...
    @staticmethod
    def _OpDescription__getAttrs(descriptionAttr, attrsAttrName): ...
    @staticmethod
    def _OpDescription__getChildValue(groupAttr, childName): ...
    @staticmethod
    def _OpDescription__getOpArgs(descriptionAttr): ...
    @staticmethod
    def _OpDescription__sort(items, descriptionAttr, orderingAttrName): ...

def GenerateRstDocument() -> str: ...
