# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Util.AbstractSyntaxHighlighter import AbstractSyntaxHighlighter as AbstractSyntaxHighlighter
from typing import Set, Tuple

class LuaSyntaxHighlighter(AbstractSyntaxHighlighter):
    def _createCustomBlocks(self): ...
    def _createFormats(self): ...
    def _createPostBlockRules(self): ...
    def _createRules(self): ...
