# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import GeolibRuntime
import NodegraphAPI
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import RenderingAPI as RenderingAPI
import PyUtilModule.RenderingCommon as RenderingCommon
import PyResolutionTableFn as ResolutionTable
from typing import Set, Tuple

def AddCameraOverrideToRecipe(txn, inputOp, cameraLocationPath): ...
def AddRenderOutputsToRecipe(txn: GeolibRuntime.Transaction, op: GeolibRuntime.Op, outputs: list) -> GeolibRuntime.Op: ...
def AddRenderSettingsToRecipe(txn, renderOp, graphState: NodegraphAPI.GraphState, renderSettingsAttr): ...
def AddVirtualCameraToRecipe(txn, inputOp, cameraLocationPath): ...
def BakeAOVs(txn: GeolibRuntimeTransaction, mainSequenceID: int, op: GeolibRuntimeOp) -> GeolibRuntime.Op: ...
def GetInteractiveOutputs(client: GeolibRuntime.Client) -> list[str]: ...
