# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
from typing import Set, Tuple

def GetBrowserSettings(): ...
def LoadFrameGeometry(widget, group): ...
def SaveFrameGeometry(widget, group): ...
