# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class AddTabButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...

class CloseAllTabsButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _CloseAllTabsButton__on_clicked(self): ...

class CloseTabButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _CloseTabButton__on_clicked(self): ...

class MaximizePaneButton(ToolbarButton):
    def __init__(self, parent, frame) -> None: ...
    def _MaximizePaneButton__on_clicked(self): ...
    def _MaximizePaneButton__on_frame_frameMaximized(self, state): ...
