# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.ProductSaveWidgets
from typing import Set, Tuple

class CatalogSaveDialog(UI4.Widgets.ProductSaveWidgets.ProductOrFileSaveDialog):
    def __init__(self, parent, options) -> None: ...
    def _CatalogSaveDialog__colorspace_activated_CB(self, *args): ...
    def _CatalogSaveDialog__imageExtension_activated_CB(self, *args): ...
    def addButtonsToLayout(self): ...
    def getResult(self): ...
