# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import Utils as Utils
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class ArrayParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _ArrayParameterPolicy__checkForUpdate(self, final: bool = ...): ...
    def _freeze(self): ...
    def _handleParamChanged(self, args): ...
    def _handleParamFinalized(self, args): ...
    def _handleTimeChanged(self, final): ...
    def _thaw(self): ...
    def getArrayChild(self, index: int) -> BaseParameterPolicy.BaseParameterPolicy | None: ...
    def getArraySize(self): ...
    def getNumChildren(self): ...
    def getType(self): ...
    def removeArrayChild(self, index: int): ...
    def removeArrayChildren(self, index: int, count: int): ...
    def reorderArrayChild(self, oldIndex: int, newIndex: int): ...
    def reorderArrayChildren(self, oldIndex: int, newIndex: int, count: int): ...
    def setArraySize(self, size): ...
