# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import KatanaResources as KatanaResources
import PyXmlIO as PyXmlIO
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
from _typeshed import Incomplete
from typing import Set, Tuple

class LineDrawable:
    def __init__(self, p1, p2, lineColor: tuple = ..., lineWidth: int = ..., **kwargs) -> None: ...
    def draw(self): ...

class MaskLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def advanceMask(self): ...
    def getActiveMask(self): ...
    def getAutoScale(self): ...
    def getMasks(self): ...
    def isEnabled(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setAutoScale(self, autoScaleEnabled): ...
    def setEnabled(self, isEnabled): ...
    def setMask(self, maskName): ...
    def toggleEnabled(self): ...

class MaskRectDrawable:
    def __init__(self, window: Incomplete | None = ..., fillColor: Incomplete | None = ..., outlineColor: Incomplete | None = ..., outlineStippleSize: int = ..., outlineWidth: int = ..., holdoutWindow: Incomplete | None = ..., label: str = ..., labelColor: tuple = ..., labelSize: float = ..., **kwargs) -> None: ...
    def _MaskRectDrawable__drawFill(self): ...
    def _MaskRectDrawable__drawLabel(self): ...
    def _MaskRectDrawable__drawOutline(self): ...
    def draw(self): ...
