# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import ClassVar, Set, Tuple

class RolloverPixmap:
    IconMode: ClassVar[int] = ...
    PixmapMode: ClassVar[int] = ...
    def __init__(self, offMap, onMap) -> None: ...
    def enterEvent(self, e): ...
    def leaveEvent(self, e): ...
    def offMap(self): ...
    def onMap(self): ...
    def setOffMap(self, offMap): ...
    def setOnMap(self, onMap): ...
    def setRolloverEnabled(self, state): ...
    def showOffMap(self): ...
    def showOnMap(self): ...
