# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import MediaCacheHandler.DiskUtil as DiskUtil
import MediaCacheHandler.ImageUtil as ImageUtil
from _typeshed import Incomplete
from typing import Set, Tuple

def CopyElementsToMediaCache(elementList, deletionCB: Incomplete | None = ..., elementProgressCB: Incomplete | None = ..., fileProgressCB: Incomplete | None = ..., logTiming: bool = ...): ...
def DeleteElementFromMediaCache(localMediaElementDir): ...
def GetElementProportionLocal(element): ...
def GetElementsSafeForDeletion(excludeElementDirs: Incomplete | None = ..., initialLocalElements: Incomplete | None = ...): ...
def GetLocalElements(directory: Incomplete | None = ...): ...
def GetMediaCacheFreeSpaceB(): ...
def GetMediaCacheSizeB(): ...
def GetTargetMediaCacheSizeB(): ...
