# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtGui as QtGui
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
from _typeshed import Incomplete
from typing import Set, Tuple

class ContextMenuEvent(PyQt5.QtGui.QContextMenuEvent):
    def __init__(self, event, locationPath: Incomplete | None = ..., topLevelLocationPath: Incomplete | None = ..., selectedLocations: Incomplete | None = ..., sceneGraphColumn: Incomplete | None = ...) -> None: ...
    def getLocationPath(self) -> str | None: ...
    def getSceneGraphColumn(self) -> SceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumn]: ...
    def getSelectedLocations(self) -> list[tuple]: ...
    def getTopLevelLocationPath(self) -> str | None: ...
