# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple, overload

RETIME_FREEZE: int
RETIME_MIRROR: int
RETIME_REPEAT: int

def cfit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def clamp(value: object, min: object, max: object) -> Any: ...
def fit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def ifelse(expr: object, a: object, b: object) -> Any: ...
def isfinite(value: float) -> bool: ...
def isinf(value: float) -> bool: ...
def isnan(value: float) -> bool: ...
def lerp(t: object, min: object, max: object) -> Any: ...
def noise(x: float, y: float = ..., z: float = ..., w: float = ...) -> float: ...
def randval(min: float, max: float, seed: int) -> float: ...
def retime(frame: float, start: float, end: float, inMode: object, outMode: object) -> float: ...
@overload
def smoothstep(value: object) -> Any: ...
@overload
def smoothstep(easein, easeout) -> Any: ...
def snoise(x: float, y: float = ..., z: float = ..., w: float = ...) -> float: ...
def softcfit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def stablehash(str: str) -> int: ...
