# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def GenerateXMLFile(**kwargs): ...
def GetAutoMkproxy(node: NodegraphAPI.Node): ...
def GetFarmSettings(node: NodegraphAPI.Node): ...
def GetSortedDependencies(nodeList: Incomplete | None = ..., syncAllOutputPorts: bool = ..., includeInternalDeps: bool = ..., includeBypassed: bool = ...) -> list[dict]: ...
def GetSortedDependencyList(nodeList: Incomplete | None = ..., syncAllOutputPorts: bool = ..., includeInternalDeps: bool = ..., includeBypassed: bool = ...): ...
def GetVersionSync(node: NodegraphAPI.Node): ...
def WriteFarmFile(fileName, outlineString): ...
