# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
from typing import Set, Tuple

class RenderNodeReferencePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, nodeName, portName) -> None: ...
    def getExpressionNamespace(self): ...
    def getExpressionReference(self): ...
    def getName(self): ...
    def getType(self): ...
    def getValue(self): ...
