# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple

class GroupInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _GroupInteractionLayer__buildMenus(self): ...
    def _GroupInteractionLayer__deletePortCallback(self): ...
    def _GroupInteractionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _GroupInteractionLayer__renamePortCallback(self): ...
    def processEvent(self, event): ...

def smoothstep(x): ...
