# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
import PyFnGeolibProducers
from typing import Any, Set, Tuple

class RendererPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def configureDiskRenderOutputProcess(self, outputName: str, outputPath: str, renderMethodName: str, frameTime: float) -> PyFnAttribute.GroupAttribute: ...

def GetPlugin(pluginName: str, producer: PyFnGeolibProducers.GeometryProducer) -> Any: ...
def ReleaseManager() -> None: ...
