# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

class UniqueListDict:
    def __init__(self, name: Incomplete | None = ..., defaultKey: Incomplete | None = ..., pairList: list = ...) -> None: ...
    def append(self, pair): ...
    def get(self, key): ...
    def getDefault(self): ...
    def getName(self): ...
    def next(self, pos): ...
    def setDefault(self, defaultKey): ...
    def setName(self, name): ...
