# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyUtilModule.RenderManager as RenderManager
import UI4.Widgets.StopButton
import Utils as Utils
from UI4.Widgets.StopButton import SimpleStopWidget as SimpleStopWidget
from typing import Set, Tuple

class CatalogStopWidget(UI4.Widgets.StopButton.SimpleStopWidget):
    def __init__(self, parent) -> None: ...
    def _CatalogStopWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogStopWidget__catalog_itemPropertyUpdate_cb(self, eventType, eventID, item, **kwargs): ...
    def _CatalogStopWidget__updateAndAdvance(self): ...
    def mousePressEvent(self, event): ...
    def setCatalogItem(self, item): ...
