# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import PyUtilModule.ScenegraphUtils as ScenegraphUtils
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def GetScenegraphMaskEnabled(): ...
def GetScenegraphMaskLocationsAndRoot(cameraPath: str, selectedLocations: Incomplete | None = ...): ...
def GetScengraphMaskLocations() -> list[str]: ...
def GetVisibilityFollowsWorkingSet(): ...
def SetScenegraphMaskEnabled(scenegraphMaskEnabled): ...
def SetVisibilityFollowsWorkingSet(enabled): ...
