# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4Color.ColorPolicy import CreateColorPolicy as CreateColorPolicy, DoesColorPolicyEnableFilmlook as DoesColorPolicyEnableFilmlook, DoesColorPolicyEnableNoFilmlookColorSpace as DoesColorPolicyEnableNoFilmlookColorSpace, DoesColorPolicyHaveAlpha as DoesColorPolicyHaveAlpha, DoesColorPolicyRestrictComponents as DoesColorPolicyRestrictComponents, GetColorPolicyChildren as GetColorPolicyChildren, GetColorPolicyRGBA as GetColorPolicyRGBA, GetDefaultColorComponentTab as GetDefaultColorComponentTab, SetColorPolicyEnableFilmlook as SetColorPolicyEnableFilmlook, SetColorPolicyEnableFilmlookDefault as SetColorPolicyEnableFilmlookDefault, SetColorPolicyEnableNoFilmlookColorSpaceDefault as SetColorPolicyEnableNoFilmlookColorSpaceDefault, SetColorPolicyRGBA as SetColorPolicyRGBA, SetColorPolicyRestrictComponents as SetColorPolicyRestrictComponents, SetColorPolicyRestrictComponentsDefault as SetColorPolicyRestrictComponentsDefault
from QT4Color.Gradient1D import LinearGradientWidget as LinearGradientWidget
from QT4FormWidgets.NumberFormWidget import NumberFormWidget
from typing import Set, Tuple

class ColorComponentFormWidget(NumberFormWidget):
    def __init__(self, colorComponent, parent, colorPolicy, widgetFactory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def doSliderMoved(self, change): ...
    def doSliderPressed(self): ...
    def doSliderReleased(self): ...
    def getMode(self): ...
    def getPopdownWidget(self): ...
    def resetChildValuePolicy(self): ...
    def setLocked(self, state, checkLockOps: bool = ...): ...
    def toggleColorClamping(self): ...
    def toggleFilmlookVisualization(self): ...

def BuildColorComponentQT4FormWidgets(colorPolicy, parent, includeHSL: bool = ...): ...
