# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI
from _typeshed import Incomplete
from typing import Set, Tuple

def GetModifiedFrameTime(node: NodegraphAPI.Node, frameTime): ...
def GetTimingParameterAttrsForNodeTypeBuilder(): ...
def GetTimingParameterHints(attrName: Incomplete | None = ...): ...
def GetTimingParameterXML(): ...
def HasTimingParameter(node: NodegraphAPI.Node): ...
def SetTimingParametersExpressionsForNodeTypeBuilder(node: NodegraphAPI.Node): ...
