# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def ClampRGBA(rgba): ...
def ConvertColorToUnits(units, rgbColor): ...
def ConvertUnitsToColor(units, unitsColor): ...
