# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import QT4FormWidgets.InputWidgets as InputWidgets
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.FormMaster.Editors.NodeGroup
import UI4.Widgets.SortablePanel
import Utils as Utils
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name) -> None: ...
    def _InputPanel__valueChangedCallback(self): ...
    def getPortName(self): ...
    def setPortName(self, name): ...

class TeleportEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _TeleportEditor__clicked(self): ...

class TeleportInputEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _TeleportInputEditor__getEventTarget(self): ...
    def _TeleportInputEditor__getNode(self): ...
    def _TeleportInputEditor__idle_callback(self, *args, **kwargs): ...
    def _TeleportInputEditor__node_addOrRemoveOutputPort_cb(self, *args, **kwargs): ...
    def _TeleportInputEditor__node_renameOutputPort_cb(self, *args, **kwargs): ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def deleteInput(self, index): ...
    def deletePanel(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def panelValueChanged(self, index): ...
    def renameInput(self, index, newName): ...
    def valueChanged(self, valuePolicy, index, final): ...
