# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.FWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from typing import ClassVar, Set, Tuple

class MultiStateBadge(QT4FormWidgets.FWidget.FStateBadge):
    _MultiStateBadge__stateInfo: ClassVar[list] = ...
    def __init__(self, parent) -> None: ...
    def _MultiStateBadge__menuHide(self): ...
    def _MultiStateBadge__setState(self, state): ...
    def mousePressEvent(self, event): ...
    def setState(self, state): ...

class ToggleStateBadge(QT4FormWidgets.FWidget.FToggleStateBadge):
    _ToggleStateBadge__stateInfo: ClassVar[list] = ...
    def __init__(self, parent) -> None: ...
    def _ToggleStateBadge__setState(self, state): ...
    def mousePressEvent(self, event): ...
    def setState(self, state): ...

def ToggleValuePolicyState(policy): ...
