# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import typing
from Nodes3DAPI.Node3D import Node3D as Node3D
from _typeshed import Incomplete
from typing import Set, Tuple

_Default_Pivot: float
_Default_Rotate: float
_Default_Scale: float
_Default_Translate: float
_Default_UniformScale: float
_ParamHints: dict
_Parameter_XML: str
_xyz: tuple

class TransformNode3D(Node3D):
    def __init__(self) -> None: ...
    def _TransformNode3D__getPivotAttr(self, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _TransformNode3D__getRotate(self, frameTime, graphState: NodegraphAPI.GraphState): ...
    def _TransformNode3D__getTransformAttr(self, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def setInteractiveTransform(self, path, absScale, absRotate, absTranslate, time): ...
    def setInteractiveTransformFlag(self, path, time): ...
    def setOverride(self, path, attrName, time, attrData, index: Incomplete | None = ..., *args, **kwargs): ...

def _GetArrayParameterConstantValue(parameter, frameTime): ...
def _GetArrayParameterSamples(parameter, graphState: NodegraphAPI.GraphState): ...
def _GetParameterConstantValue(parameter, frameTime): ...
def _GetParameterSampleTimes(parameter, graphState: NodegraphAPI.GraphState): ...
def _GetParameterSamples(parameter, graphState: NodegraphAPI.GraphState): ...
