# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import TerminalTab as TerminalTab
from UI4.Tabs.EnhancedTerminalTab.TerminalTab import EnhancedTerminalTab as EnhancedTerminalTab
from typing import Set, Tuple

PluginRegistry: list
