# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import Utils as Utils
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from typing import Set, Tuple

class SelectionLayer(RectangleLayer):
    def __init__(self, *args, **kwargs) -> None: ...
    def isOverlay(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setEnabled(self, enabled): ...
