# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.SceneGraphView.ViewLink import ViewLink as ViewLink
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DebugViewLink(ViewLink):
    _abc_impl: ClassVar[_abc_data] = ...
    __abstractmethods__: ClassVar[frozenset] = ...
    def __init__(self, bridge, parent: Incomplete | None = ...) -> None: ...
    def _DebugViewLink__updateText(self): ...
    def addLocation(self, handle, topLevelHandle): ...
    def addTopLevelLocation(self, topLevelHandle): ...
    def allowMultipleSelection(self): ...
    def collapseLocation(self, handle, topLevelHandle): ...
    def evaluateFilterRules(self, handle: Incomplete | None = ..., topLevelHandle: Incomplete | None = ...): ...
    def expandLocation(self, handle, topLevelHandle): ...
    def getSelectedLocations(self): ...
    def getWidget(self): ...
    def removeLocation(self, handle, topLevelHandle): ...
    def removeTopLevelLocation(self, topLevelHandle): ...
    def resetModel(self): ...
    def scrollToLocation(self, handle, topLevelHandle): ...
    def setAllowMultipleSelection(self, allowMultipleSelection): ...
    def setAttributeDataChildren(self, handle, topLevelHandle, attributeDataChildren): ...
    def setColumnTitles(self, titleInfo): ...
    def setContextMenuEventCallback(self, callback): ...
    def setDragMoveEventCallback(self, callback): ...
    def setDropEventCallback(self, callback): ...
    def setExpandsOnDoubleClick(self, expandsOnDoubleClick): ...
    def setKeyPressEventCallback(self, callback): ...
    def sortChildrenUnderLocation(self, handle, topLevelHandle): ...
    def updateItemDelegates(self): ...
    def updateLocation(self, handle, topLevelHandle): ...
    def updateLocationIcons(self, handle, topLevelHandle): ...
    def updateTopLevelLocation(self, topLevelHandle): ...
