# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from typing import Set, Tuple

class ProgressMonitor:
    class InterruptException(RuntimeError): ...
    def __init__(self, updateInterval: float = ...) -> None: ...
    def interrupt(self): ...
    def progress(self, message): ...
    def __del__(self) -> None: ...

def FillCache(node: NodegraphAPI.Node): ...
