# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Color.Degenerate as Degenerate
import QT4Color.Globals as Globals
import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Color.ColorTransforms import ClampRGBA as ClampRGBA, ConvertColorToUnits as ConvertColorToUnits, ConvertUnitsToColor as ConvertUnitsToColor
from typing import ClassVar, Set, Tuple

class LinearGradientWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, mode, enableFilmlook, enableNoFilmlookColorSpace, parent, orientation: PyQt5.QtCore.Qt.Orientation = ...) -> None: ...
    def _LinearGradientWidget__componentToWindowPos(self, component): ...
    def _LinearGradientWidget__drawPointer(self, painter): ...
    def _LinearGradientWidget__emit(self, componentValue, final): ...
    def _LinearGradientWidget__getPointerColor(self): ...
    def _LinearGradientWidget__isPreselectionActive(self): ...
    def _LinearGradientWidget__isfinite(self, value): ...
    def _LinearGradientWidget__recomputeComponentValue(self): ...
    def _LinearGradientWidget__windowPosToComponent(self, posX, posY): ...
    def enterEvent(self, ev): ...
    def getColor(self): ...
    def getPickingColorspace(self): ...
    def leaveEvent(self, ev): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def recomputeGradient(self): ...
    def resizeEvent(self, ev): ...
    def setColor(self, linearColor): ...
    def setFilmlookEnabled(self, enabled): ...
    def setMode(self, mode): ...
    def setNoFilmlookColorSpaceEnabled(self, enabled): ...
    def setReadOnly(self, value): ...
    def sizeHint(self): ...
    def sizePolicy(self): ...
