# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import UI4 as UI4
import Utils as Utils
from typing import Set, Tuple

def CreateManipulatorLayer(policy, *args, **kwargs): ...
def GetAnimationPathsEnabled(): ...
def GetManipulatedPolicies(): ...
def GetManipulatorPolicy(param): ...
def IsManipulatorEnabled(param): ...
def RegisterManipulatorLayer(nodeType, paramMatchString, widgetName): ...
def SetAnimationPathsEnabled(enabled): ...
def SetManipulatorEnabled(param, isEnabled): ...
