# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Any, Set, Tuple

class RenderOutputLocationPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def computeFilePath(self, outputAttrs: dict, locationAttrs: dict, renderSettingsAttr: dict, imageInfo: dict, makeVersionTemplate: bool) -> str: ...
    def computeLocation(self, outputAttrs: dict, locationAttrs: dict, renderSettingsAttr: dict, imageInfo: dict) -> str: ...
    def getLocationSettingsAttr(self, outputType: str, incomingOutputAttr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.GroupAttribute: ...

def GetPlugin(pluginName: str) -> Any: ...
def GetPluginNames() -> list[str]: ...
