# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumnTitle as SceneGraphColumnTitle
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class HorizontalHeaderView(PyQt5.QtWidgets.QHeaderView):
    ClickStyleRole: ClassVar[int] = ...
    HeaderTitleIconRole: ClassVar[int] = ...
    IsToggledOnFunctionRole: ClassVar[int] = ...
    SectionClickableRole: ClassVar[int] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _HorizontalHeaderView__getLogicalIndexes(self, pointerX: int) -> tuple[int, int] | None: ...
    def _HorizontalHeaderView__on_activePopupWidget_hide(self): ...
    def _HorizontalHeaderView__on_resizeAllToContentsAction_triggered(self): ...
    def _HorizontalHeaderView__on_resizeToContentsAction_triggered(self): ...
    def contextMenuEvent(self, contextMenuEvent: PyQt5.QtGui.QContextMenuEvent): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mouseDoubleClickEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mouseMoveEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mousePressEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def paintSection(self, painter: PyQt5.QtGui.QPainter, rect: PyQt5.QtCore.QRect, logicalIndex: int): ...
    def resizeSection(self, logicalIndex: int, size: int): ...
