# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.FormMaster.Editors.Number as Number
import QT4FormWidgets as QT4FormWidgets
import PyResolutionTableFn as ResolutionTable
import UI4.FormMaster.Editors.Number
import Utils as Utils
from typing import Set, Tuple

class AdjustMaxToDisplayWindowNumberFormWidget(UI4.FormMaster.Editors.Number.KatanaNumberFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__loadBeginCB(self, args): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__loadEndCB(self, args): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__updateMax(self): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__updateMaxCB(self, args): ...
    def _freeze(self): ...
    def _thaw(self): ...
