# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def GetParamNameForNodeType(nodeType): ...
def IsNodeNameFromParam(nodeType): ...
def RegisterNodeNameFromParam(nodeType: str, paramName: str, capitalize: bool = ..., synchronize: bool = ...): ...
def UpdateNodeNameFromParam(node: NodegraphAPI.Node): ...
