# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as FW
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Decorators as Decorators, FormMaster as FormMaster, ScenegraphManager as ScenegraphManager, Widgets as Widgets
from UI4.FormMaster.FnAttributePolicy import AttributePolicy as AttributePolicy
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class AttributesTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _AttributesTab__activePathPopupClicked(self): ...
    def _AttributesTab__activePathPopupSelected(self, path): ...
    def _AttributesTab__addImplicitResolvers(self, txn, opId, viewedNode): ...
    def _AttributesTab__buildOrUpdate(self, attrs): ...
    def _AttributesTab__clear(self): ...
    def _AttributesTab__findAttributesActionCallback(self): ...
    def _AttributesTab__getAttrMetaDict(self, gb, attrs): ...
    def _AttributesTab__iconMenuAboutToShow(self): ...
    def _AttributesTab__iconMousePress(self, event): ...
    def _AttributesTab__iconStartDrag(self): ...
    def _AttributesTab__idle(self, *args, **kwds): ...
    def _AttributesTab__nodeSetViewed(self, args): ...
    def _AttributesTab__on_renderingAPI_flushPluginCaches(self): ...
    def _AttributesTab__selectionChanged(self, args): ...
    def _AttributesTab__setTerminalOpInput(self, opInput, txn): ...
    def _AttributesTab__terminalOpCallback(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, transaction): ...
    def _AttributesTab__updateActiveLocation(self, newLocation): ...
    def _AttributesTab__updateTypeIcon(self, typeStr): ...
    def customEvent(self, event): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
