# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ExampleTimeTerminalOpDelegate as ExampleTimeTerminalOpDelegate, TerminalOpDelegate as TerminalOpDelegate, WorkingSetTerminalOpDelegate as WorkingSetTerminalOpDelegate
from Nodes3DAPI.Node3D import RegisterTerminalOpDelegate as RegisterTerminalOpDelegate
from typing import Set, Tuple
