# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.MessageBox as MessageBox
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
import Utils as Utils
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name, policy, factory) -> None: ...

class LODInputEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def deleteInput(self, index): ...
    def deletePanel(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...
