# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from ResourceFiles.ResourceManager import ResourceManager as ResourceManager
from typing import Set, Tuple

class QT4IconManager(ResourceManager):
    def __init__(self, paths, iconDir: str = ..., **kwargs) -> None: ...
    def _QT4IconManager__getData(self, rawPath): ...
    def clearCache(self): ...
    def getIcon(self, fileName): ...
    def getPixmap(self, fileName): ...
    def getSize(self, fileName): ...
    def getSvgRenderer(self, fileName): ...

class _IconData:
    def __init__(self, path) -> None: ...
