# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def IncludeProxyChildrenInWorkingSet(locationPaths: list[str], workingSetName: str): ...
