# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4.FormMaster.Editors.NodeGroup
import Utils as Utils
from typing import Set, Tuple

class Transform3DNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _Transform3DNodeEditor__copyTransform(self, *args): ...
    def _Transform3DNodeEditor__doIdle(self, *args, **kwargs): ...
    def _Transform3DNodeEditor__fitBounds(self, *args): ...
    def _Transform3DNodeEditor__getExistingTransform(self): ...
    def _Transform3DNodeEditor__getInputTransform(self): ...
    def _Transform3DNodeEditor__paneButtonAboutToShow(self, menu): ...
    def _Transform3DNodeEditor__resetTransform(self, *args): ...
    def _Transform3DNodeEditor__setTransformFromMatrix(self, matrix): ...
    def _Transform3DNodeEditor__snapToWorldPos(self, *args): ...
    def _lockChanged(self, state): ...
