# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import typing
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class IconLabelFrame(PyQt5.QtWidgets.QFrame):
    class NestedIconLabelFrame(PyQt5.QtWidgets.QFrame):
        def __init__(self, iconPixmap: PyQt5.QtGui.QPixmap, text: str, parent: Incomplete | None = ...) -> None: ...
        def getText(self) -> str: ...
        def on_textLabel_linkActivated(self, link: str): ...
        def setForegroundRole(self, foregroundRole: PyQt5.QtGui.QPalette.ColorRole): ...
        def setIconPixmap(self, iconPixmap: PyQt5.QtGui.QPixmap): ...
        def setLinkClickCallback(self, linkClickCallback: typing.Callable | None): ...
        def setText(self, text: str): ...
        def setWordWrap(self, wordWrap: bool): ...
    tabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, iconPixmap: PyQt5.QtGui.QPixmap, text: str, margin: int = ..., parent: Incomplete | None = ..., flags: PyQt5.QtCore.Qt.WindowType = ...) -> None: ...
    def getText(self) -> str: ...
    def setContentsMargins(self, left: int, top: int, right: int, bottom: int): ...
    def setForegroundRole(self, foregroundRole: PyQt5.QtGui.QPalette.ColorRole): ...
    def setIconPixmap(self, iconPixmap: PyQt5.QtGui.QPixmap): ...
    def setLinkClickCallback(self, linkClickCallback: typing.Callable | None): ...
    def setMargin(self, margin): ...
    def setText(self, text: str): ...
    def setWordWrap(self, wordWrap: bool): ...
