# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
import Utils as Utils
from typing import Set, Tuple

class IsolateNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _IsolateNodeEditor__checkBox_CB(self): ...
    def _IsolateNodeEditor__portChangedCB(self, eventType, eventID, **kwargs): ...
    def _IsolateNodeEditor__setupEvents(self, flag): ...
    def _IsolateNodeEditor__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
