# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def CheckKeyMimeData(parameters, mimeData, strictTypeCB: Incomplete | None = ...): ...
def CheckKeyMimeDataGeneric(mimeData): ...
def GetKeyMimeData(parameters, strictTypeCB: Incomplete | None = ...): ...
def GetKeyMimeDataPotentials(parameters, mimeData, timeOffset: Incomplete | None = ..., targetTime: Incomplete | None = ...): ...
def GetKeyMimeDataSources(mimeData): ...
def SetKeyMimeData(parameters, mimeData, timeOffset: Incomplete | None = ..., targetTime: Incomplete | None = ...): ...
