# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
import UI4.Widgets.SortableParams
from typing import Set, Tuple

class SortableParamsForm(UI4.Widgets.SortableParams.SortableParamsFormWidget): ...
