# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Tabs
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class TabDockWidget(PyQt5.QtWidgets.QDockWidget):
    _TabDockWidget__closeDockedTabIcon: ClassVar[None] = ...
    _TabDockWidget__detachTabIcon: ClassVar[None] = ...
    def __init__(self, tabWithTimeline: UI4.App.Tabs.TabWithTimeline, parent: Incomplete | None = ...) -> None: ...
    def _TabDockWidget__on_detachTabButton_clicked(self): ...
    def _TabDockWidget__on_dockLocationChanged(self, area: PyQt5.QtCore.Qt.DockWidgetArea): ...
    def _TabDockWidget__updateTitleBarButtons(self): ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def setWindowTitle(self, windowTitle: str): ...
    def windowTitle(self) -> str: ...
