# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import UI4.FormMaster.NodeActionDelegate.NodeActionDelegate as NodeActionDelegate
import UI4.Util.NodeGraphTab as NodeGraphTab
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from NodegraphAPI.LiveGroup import AssetPublishing as AssetPublishing
from UI4.FormMaster.NodeActionDelegate.BaseNodeActionDelegate import BaseNodeActionDelegate as BaseNodeActionDelegate
from _typeshed import Incomplete
from typing import Set, Tuple

class LiveGroupActionDelegate(BaseNodeActionDelegate):
    class _ConvertToGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _ConvertToGroupAction__triggered(self, checked): ...

    class _EditContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _EditContentsLiveGroupAction__triggered(self, checked): ...

    class _EditParentsAndContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _EditParentsAndContentsLiveGroupAction__hasLiveGroupAncestor(self): ...
        def _EditParentsAndContentsLiveGroupAction__triggered(self, checked): ...

    class _LoadLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _LoadLiveGroupAction__triggered(self, checked): ...

    class _PublishAndFinishEditingContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _PublishAndFinishEditingContentsLiveGroupAction__triggered(self, checked): ...

    class _PublishLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _PublishLiveGroupAction__triggered(self, checked): ...

    class _ReloadLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _ReloadLiveGroupAction__triggered(self, checked): ...

    class _RevertLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _RevertLiveGroupAction__triggered(self, checked): ...
    def _buildMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToContextMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToWrenchMenu(self, menu, node: NodegraphAPI.Node, hints: Incomplete | None = ...): ...

def PublishLiveGroup(liveGroupNode: NodegraphAPI.LiveGroupNode, reloadContent: bool, dialogTitle: str) -> bool: ...
