# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

class CatalogResolutionWidget(PyQt5.QtWidgets.QLabel):
    def __init__(self, *args) -> None: ...
    def _CatalogResolutionWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogResolutionWidget__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def mousePressEvent(self, ev): ...
    def setCatalogItem(self, catalogItem): ...
    def updateState(self, *args, **kwargs): ...
