# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import ConfigurationAPI_cmodule as Configuration
import NodegraphAPI.NodeExtensions as NodeExtensions
import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import NodegraphAPI.NodegraphGlobals as NodegraphGlobals
import PyXmlIO as PyXmlIO
import PyResolutionTableFn as ResolutionTable
import Utils as Utils
import NodegraphAPI.Version as Version
import typing
from NodegraphAPI_cmodule import Context as Context
from _typeshed import Incomplete
from typing import Set, Tuple

def BuildNodegraphXmlIO(forcePersistant: bool = ..., opaqueParams: Incomplete | None = ..., isAutoSave: bool = ...): ...
def BuildNodesXmlIO(nodes: list[NodegraphAPI.Node], forcePersistant: bool = ..., opaqueParams: Incomplete | None = ..., requireSiblings: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., includeNonPersistentNodes: bool = ...) -> PyXmlIO.Element | None: ...
def GetUserNodesXmlRootAttrs(): ...
def LoadElementsFromFile(fileName, versionUp: bool = ...): ...
def LoadElementsFromString(xmlString, versionUp: bool = ...): ...
def ParseNodegraphXmlIO(element: PyXmlIO.Element, sourcePath: str = ..., isCrashFile: bool = ...): ...
def ParseNodesXmlIO(element: PyXmlIO.Element, emit: bool = ..., floatNodes: bool = ..., sourcePath: str = ..., loadLiveGroups: bool = ..., lockLiveGroups: bool = ..., isParentContextNME: bool = ...) -> list: ...
def SetUserNodesXmlRootAttrs(attrDict): ...
