# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import QT4Widgets.WidgetUtils as WidgetUtils
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MenuButton(PyQt5.QtWidgets.QPushButton):
    dragEnterEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragLeaveEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dropEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, text: str = ..., alignWidget: Incomplete | None = ...) -> None: ...
    def _MenuButton__aboutToHideMenu(self): ...
    def _MenuButton__positionArrow(self): ...
    def _displayMenu(self): ...
    def contextMenuEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, event): ...
    def dropEvent(self, event): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def menu(self): ...
    def mousePressEvent(self, event): ...
    def resizeEvent(self, event): ...
    def setArrowVisible(self, value): ...
    def setButtonType(self, buttonType): ...
    def setFlat(self, flat): ...
    def setMenu(self, menu): ...
    def setPixmap(self, pixmap): ...
    def sizeHint(self): ...

class PassThroughLabel(PyQt5.QtWidgets.QLabel):
    def mousePressEvent(self, event): ...
