# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
from typing import Set, Tuple

def GetAttributes(_node): ...
def GetPortAttributes(node: NodegraphAPI.Node, port: NodegraphAPI.Port) -> dict: ...
def NewNode(_node): ...
def SetAttributes(_node, attrs): ...
