# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI
from Nodes3DAPI.TerminalOpDelegates.TerminalOpDelegate import TerminalOpDelegate as TerminalOpDelegate
from typing import Set, Tuple

class ExampleTerminalOpDelegate(TerminalOpDelegate):
    def __init__(self) -> None: ...
    def appendOp(self, op, txn, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState): ...
    def reset(self): ...
    def update(self): ...
