# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Widgets as QT4Widgets
from QT4Widgets.CustomMenu import CustomMenu as CustomMenu
from typing import Set, Tuple
