# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class CrashFileSelectorDialog(PyQt5.QtWidgets.QDialog):
    class CrashFileItem(PyQt5.QtWidgets.QTreeWidgetItem):
        def __init__(self, crashDict, *args) -> None: ...
        def getCrashDict(self): ...
    def __init__(self, crashData, parent: Incomplete | None = ...) -> None: ...
    def _CrashFileSelectorDialog__compareCrashFileWithOriginal(self, crashDict): ...
    def _CrashFileSelectorDialog__makeStatString(self, filestat): ...
    def _CrashFileSelectorDialog__on_dialogButtonBox_clicked(self, button): ...
    def accept(self): ...
    def closeEvent(self, event: PyQt5.QtWidgets.QCloseEvent): ...
    def getCrashFile(self): ...
    def getSourceFile(self): ...
    def loadSource(self): ...
    def quitRequested(self) -> bool: ...
