# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import UI4 as UI4
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from typing import ClassVar, Set, Tuple

class KeyboardShortcutFormWidget(BaseValueFormWidget):
    shortcutChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _KeyboardShortcutFormWidget__on_keyboardShortcutLineEdit_textChanged(self, text): ...
    def _buildControlWidget(self, layout: PyQt5.QtWidgets.QLayout) -> PyQt5.QtWidgets.QWidget: ...
    def _updateControlWidget(self): ...
    def setReadOnly(self, readOnly: bool): ...
