# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class BoundsAdjust(Node3D):
    ACTION_NAME_MAP: ClassVar[dict] = ...
    ACTION_PAD_LOCAL: ClassVar[str] = ...
    ACTION_PAD_PERC: ClassVar[str] = ...
    ACTION_STRIP: ClassVar[str] = ...
    VALID_ACTIONS: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
