# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModuleCommon as EventModuleCommon
import typing
from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from typing import Set, Tuple

_EventQueue: list
_SynchronousEventProcessing: bool

def Initialize(): ...
def ProcessAllEvents(): ...
def ProcessEvents() -> bool: ...
def PumpIdleQueue(): ...
def QueueEvent(eventType: str, eventID: typing.Hashable, priority: int = ..., **kwargs): ...
def QueuePriorityEvent(eventType: str, eventID: typing.Hashable, **kwargs): ...
def _handleEvents(events: list[tuple]): ...
def _invokeCollapsedDict(mask: tuple[str, object], args: list[tuple[str, object, dict]]): ...
def _invokeHandlerDict(mask: tuple[str, object], eventType: str, eventID: object, kwargs: dict): ...
