# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.UVPanel.UVWidget import UVWidget as UVWidget
from UI4.Widgets.StatefulMenu import MergeStatefulMenuData as MergeStatefulMenuData, StatefulMenu as StatefulMenu
from typing import Set, Tuple

class UVPanel(BaseTab):
    def __init__(self, *args) -> None: ...
    def _UVPanel__buildMenu(self): ...
    def _UVPanel__on_textureCombobox_activated(self, index): ...
    def _UVPanel__on_tileCombobox_activated(self, index): ...
    def _UVPanel__openTextureFile(self): ...
    def _UVPanel__updateTexturesCallback(self, textureList): ...
    def _UVPanel__updateTilesCallback(self, bounds): ...
    def getIsolateSelection(self): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getOverlaySetting(self, name): ...
    def getStencilMode(self): ...
    def getTileFormat(self): ...
    def getUVWidget(self) -> UVWidget: ...
    def setIsolateSelection(self, value): ...
    def setOverlaySetting(self, name, value): ...
    def setStencilMode(self, value): ...
    def setTileFormat(self, tileFormat): ...
