# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
from PyQt5.QtCore import CursorChange as CursorChange, WA_DontCreateNativeAncestors as WA_DontCreateNativeAncestors, WA_NativeWindow as WA_NativeWindow, WidgetWithChildrenShortcut as WidgetWithChildrenShortcut
from typing import Set, Tuple
