# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class LumaSliderWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _LumaSliderWidget__getCentralRect(self): ...
    def colorToWindowPos(self, value): ...
    def enterEvent(self, ev): ...
    def getLuma(self): ...
    def isPreselectionActive(self): ...
    def leaveEvent(self, ev): ...
    def minimumSizeHint(self): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def reset(self): ...
    def setLuma(self, luma): ...
    def sizeHint(self): ...
    def sizePolicy(self): ...
    def windowPosToColor(self, pos): ...
