# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyXmlIO as PyXmlIO
import NodegraphAPI.Xio as Xio
from typing import Set, Tuple

def CreateGroupParameter(node: NodegraphAPI.Node, delimitedParameterName): ...
def CreateNumberParameter(node: NodegraphAPI.Node, delimitedParameterName): ...
def CreateStringParameter(node: NodegraphAPI.Node, delimitedParameterName): ...
def DeleteParameter(node: NodegraphAPI.Node, delimitedParameterName): ...
