# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI
import Nodes3DAPI
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import ClassVar, Set, Tuple

class NodeDropWidget(PyQt5.QtWidgets.QLabel):
    _NodeDropWidget__NODE: ClassVar[str] = ...
    _NodeDropWidget__NODEBIG: ClassVar[str] = ...
    _NodeDropWidget__NODEDRAG: ClassVar[str] = ...
    _NodeDropWidget__NODEDROPONTO: ClassVar[str] = ...
    def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
    def _NodeDropWidget__startDrag(self): ...
    def customEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, event): ...
    def dropEvent(self, event): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def mousePressEvent(self, event): ...
    def setNode(self, node: Nodes3DAPI.Node3D): ...
