# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import ClassVar, Set, Tuple

class BaseConstraint(Node3D):
    CommonParamXML: ClassVar[str] = ...
    _CommonParamHints: ClassVar[dict] = ...
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addCommonAndNodeParamHints(self, attrName, nodeHints, inputDict): ...
    def addToConstraintList(self, time): ...
    def getAllowMissingTargets(self, time): ...
    def getBasePath(self, time): ...
    def getConstraintArguments(self, time): ...
    def getConstraintType(self, time): ...
    def getPrependFlag(self): ...
    def getRequireTargetBounds(self, time): ...
    def getRespectMotionBlur(self, time): ...
    def getTargetPaths(self, time): ...
    def setRelativeTargets(self, time): ...
