# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI_cmodule as Nodes2DAPI_cmodule
import RenderingAPI as RenderingAPI
import Utils as Utils
import Nodes2DAPI_cmodule.Views as Views
import types
from . import Expression as Expression, FileInNodeUtil as FileInNodeUtil, FileOutNodeUtil as FileOutNodeUtil, GradientNodeUtil as GradientNodeUtil, NodeColorDelegate as NodeColorDelegate, ThumbnailManager as ThumbnailManager, TransformUtil as TransformUtil
from Nodes2DAPI_cmodule import CancelRender as CancelRender, CheckExternalRender as CheckExternalRender, CheckFileIns as CheckFileIns, ClearDisplayWindowCache as ClearDisplayWindowCache, ClearImageHeaderCache as ClearImageHeaderCache, ClearSpeculativeCacheContents as ClearSpeculativeCacheContents, ConvertUpdateRectsToFnAttribute as ConvertUpdateRectsToFnAttribute, CreateExternalRenderListener as CreateExternalRenderListener, EnumerateReadableImageFormats as EnumerateReadableImageFormats, EnumerateWriteableImageFormats as EnumerateWriteableImageFormats, FinishRender as FinishRender, FrameBuffer as FrameBuffer, GetAllRenderTypes as GetAllRenderTypes, GetDisplayWindow as GetDisplayWindow, GetExternalRenderListenerInfo as GetExternalRenderListenerInfo, GetFileOutAssetId as GetFileOutAssetId, GetFileOutColorspace as GetFileOutColorspace, GetFileOutEnabled as GetFileOutEnabled, GetFileOutFilename as GetFileOutFilename, GetFileOutFormat as GetFileOutFormat, GetFileOutOutputParams as GetFileOutOutputParams, GetFileOutPassName as GetFileOutPassName, GetFileOutPostScriptInfo as GetFileOutPostScriptInfo, GetFileOutPostScriptParams as GetFileOutPostScriptParams, GetFileOutProxyOnCue as GetFileOutProxyOnCue, GetFileOutRepPrefix as GetFileOutRepPrefix, GetFileOutRepresentation as GetFileOutRepresentation, GetFileOutResolutionName as GetFileOutResolutionName, GetFilmWidthFromString as GetFilmWidthFromString, GetFrameBufferCancelledMessages as GetFrameBufferCancelledMessages, GetFrameBufferCompletedMessages as GetFrameBufferCompletedMessages, GetFrameBufferRectUpdateMessages as GetFrameBufferRectUpdateMessages, GetImageDescription as GetImageDescription, GetImageDiskUsage as GetImageDiskUsage, GetImageMemoryUsage as GetImageMemoryUsage, GetImageReadPath as GetImageReadPath, GetIncrementedRenderSequenceID as GetIncrementedRenderSequenceID, GetMaxDiskUsage as GetMaxDiskUsage, GetMaxImageMemory as GetMaxImageMemory, GetNewFrameBuffers as GetNewFrameBuffers, GetOutputDisplayWindow as GetOutputDisplayWindow, GetRenderProgressMessages as GetRenderProgressMessages, GetRenderTerminationSignal as GetRenderTerminationSignal, GetRenderThreads as GetRenderThreads, GetSpeculativeCacheContents as GetSpeculativeCacheContents, GetSpeculativeCacheEnabled as GetSpeculativeCacheEnabled, GetTileRenderOrderMessages as GetTileRenderOrderMessages, GetTileSize as GetTileSize, GetTransformBetweenNodes as GetTransformBetweenNodes, GetTransformForInputPort as GetTransformForInputPort, IntImage as IntImage, IsExternalRenderInProgress as IsExternalRenderInProgress, IsRenderInProgress as IsRenderInProgress, IsThumbnailRendering as IsThumbnailRendering, KillExternalRender as KillExternalRender, Node2D as Node2D, NotifyBufferChanged as NotifyBufferChanged, PrintImageMemoryUsage as PrintImageMemoryUsage, QueueErrorMessage as QueueErrorMessage, QueueRenderMessage as QueueRenderMessage, ReadImage as ReadImage, ReadImageThreaded as ReadImageThreaded, RegisterNukeSession as RegisterNukeSession, Render as Render, RenderThumbnail as RenderThumbnail, RestartExternalRender as RestartExternalRender, SetMaxDiskUsage as SetMaxDiskUsage, SetMaxImageMemory as SetMaxImageMemory, SetNukeSessionMappings as SetNukeSessionMappings, SetNukeSessionOutputNodeName as SetNukeSessionOutputNodeName, SetRenderDebug as SetRenderDebug, SetRenderLogFile as SetRenderLogFile, SetRenderThreads as SetRenderThreads, SetSpeculativeCacheEnabled as SetSpeculativeCacheEnabled, SetTileSize as SetTileSize, SignalExternalRender as SignalExternalRender, StartExternalRender as StartExternalRender, TerminateCancelledRenders as TerminateCancelledRenders, TileStitch as TileStitch, UnregisterNukeSession as UnregisterNukeSession, fbo_bind as fbo_bind, fbo_create as fbo_create, fbo_delete as fbo_delete, fbo_init as fbo_init, fbo_unbind as fbo_unbind, glBatchVertex as glBatchVertex, glDrawProjectedLatLongLine as glDrawProjectedLatLongLine, gl_disableFragmentProgram as gl_disableFragmentProgram, gl_enableFilmlookFragmentProgram as gl_enableFilmlookFragmentProgram, gl_enableFragmentProgram as gl_enableFragmentProgram
from _typeshed import Incomplete
from typing import Set, Tuple

RENDER_TYPE_IDLE: int
RENDER_TYPE_PRIMARY: int
TILE_PRIORITIZER_NONE: int
TILE_PRIORITIZER_SCANLINE: int
TILE_PRIORITIZER_SPIRAL: int

def GetErrorMessages(): ...
def GetNewRenders(): ...
def GetRenderMessages(): ...
def GetViewBasedPrioritization(): ...
def IsUpstreamNode2D(node: NodegraphAPI.Node, frame: Incomplete | None = ...): ...
def RegisterCommandLineNode(*args): ...
def RegisterNewRender(renderDict): ...
def Render_Buffer(outputList, sampleRate, ROI, hotRender, interactive, diskCachingAllowed, emitTileRenderOrdering, tilePrioritizer, overscanPadding, renderType, renderMethodName): ...
def ReportRenderMessage(sequenceID, message): ...
def SetCatalogEventReceiver(receiver): ...
def SetFarmPluginManager(farmPluginManager: types.ModuleType): ...
def SetPrioritizerCenter(centerPoint): ...
def SetPrioritizerWindow(window): ...
def SetViewBasedPrioritization(isEnabled): ...
def Set_GetRenderProducer_Fn(function): ...
