# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import UI4 as UI4
import Utils as Utils
from QT4Widgets.CapsuleCombo import CapsuleCombo
from typing import Set, Tuple

class RenderViewCapsule(CapsuleCombo):
    def __init__(self, parent) -> None: ...
    def _RenderViewCapsule__update_CB(self, *args, **kwargs): ...
    def _RenderViewCapsule__valueChanged_CB(self, newEnabledItems, oldEnabledItems): ...
    def updateState(self): ...

class RenderViewsAutoUpdateCheckbox(PyQt5.QtWidgets.QCheckBox):
    def __init__(self, displayName, parent) -> None: ...
    def _RenderViewsAutoUpdateCheckbox__clicked_CB(self, checked): ...
    def _RenderViewsAutoUpdateCheckbox__update_CB(self, *args, **kwargs): ...
    def updateState(self): ...
