# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class Marker:
    def __init__(self, markerText) -> None: ...
    def __del__(self) -> None: ...

def begin(additionalText: str = ...): ...
def end(): ...
