# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4 as UI4
from UI4.Tabs.Monitor.Layers.ImageLayerBase import ImageLayerBase as ImageLayerBase
from UI4.Util.GLDrawingRoutines import drawEllipse as drawEllipse, drawSmoothArrow as drawSmoothArrow, drawSmoothCross as drawSmoothCross, drawSmoothCrosshairs as drawSmoothCrosshairs, drawSmoothEllipse as drawSmoothEllipse, drawSmoothHandle as drawSmoothHandle, drawSmoothPoly as drawSmoothPoly, drawSmoothText as drawSmoothText
from typing import Set, Tuple

class LinearSwipeLayer(QT4GLLayerStack.LayerStack.Layer, ImageLayerBase):
    def __init__(self, *args, **kwargs) -> None: ...
    def defaultProcessEvent(self, event): ...
    def drawHandles(self, pick: bool = ...): ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def getWindowEndPos(self, posAxis: bool = ...): ...
    def paintDropArea(self, dropColor): ...
    def paintGL(self): ...
    def pickHandles(self, x, y): ...
    def processDragHandleEvent(self, event): ...
