# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import FaceSelectionHelper as FaceSelectionHelper, Layers as Layers, UVWidget as UVWidget
from UI4.Tabs.UVPanel.UVPanel import UVPanel as UVPanel
from typing import Set, Tuple

PluginRegistry: list
