# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
from _typeshed import Incomplete
from typing import Set, Tuple

def SetTransformFromMatrix(transformGroup, matrix, time: Incomplete | None = ..., final: bool = ..., setKey: bool = ..., pivot: Incomplete | None = ...): ...
