# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import PyFnAttribute
import PyXmlIO as PyXmlIO
from _typeshed import Incomplete
from typing import Set, Tuple

def BuildParameterXmlIOFromAttrs(inputParameter, attrList, includeDefault: bool = ..., forcePersistant: bool = ..., dynamicArrayAttrNames: Incomplete | None = ...): ...
def GetAttrNamesFromPaths(attrPaths, prefix): ...
def GetDynamicArrayAttrNames(groupAttr: PyFnAttribute.GroupAttribute, prefix: str) -> list[str]: ...
def GetDynamicArrayAttrPaths(groupAttr: PyFnAttribute.GroupAttribute) -> list[str]: ...
def GetXmlIOParameterFromAttribute(attr, path, hints, forcePersistant: bool = ...): ...
