# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import Utils as Utils
from typing import ClassVar, Set, Tuple

HIGHEST_PRIORITY: int
NORMAL_PRIORITY: int

class NotificationRecord(PyQt5.QtCore.QObject):
    action: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    priorityChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    recordDeleted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, title, text) -> None: ...
    def addAction(self, actionName, actionText): ...
    def delete(self): ...
    def getActions(self): ...
    def getPriority(self, observeIgnored: bool = ...): ...
    def getText(self): ...
    def getTimeStamp(self): ...
    def getTitle(self): ...
    def isIgnored(self): ...
    def setIgnored(self, state): ...
    def setPriority(self, priority): ...
    def setText(self, text): ...
    def setTimeStamp(self, stamp): ...
    def setTitle(self, title): ...
    def triggerAction(self, actionName): ...

def AddRecord(record): ...
def CountRecords(): ...
def GetHighestPriorityOfRecords(): ...
def GetRecords(): ...
