# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Widgets as Widgets
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class HistogramPanel(BaseTab):
    def __init__(self, parent) -> None: ...
    def _HistogramPanel__channelsChanged_CB(self, ev): ...
    def _HistogramPanel__colorspaceChanged_CB(self, ev): ...
    def _HistogramPanel__monitor_pixelProbeResult_CB(self, eventType, eventID, **kwargs): ...
    def _HistogramPanel__scaleChanged_CB(self, ev): ...
    def _HistogramPanel__setTraceLocation_CB(self, x): ...
    def _HistogramPanel__showTrace_CB(self, showTrace): ...
