# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import Utils as Utils
from QT4Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NavigationToolbar(PyQt5.QtWidgets.QFrame):
    _NavigationToolbar__pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, callback: Incomplete | None = ..., maxHistoryLength: int = ...) -> None: ...
    def _NavigationToolbar__backButtonClicked(self): ...
    def _NavigationToolbar__backButtonMenuCallback(self, action): ...
    def _NavigationToolbar__backButtonRightClicked(self): ...
    def _NavigationToolbar__clearHistory(self): ...
    def _NavigationToolbar__forwardButtonClicked(self): ...
    def _NavigationToolbar__forwardButtonMenuCallback(self, action): ...
    def _NavigationToolbar__forwardButtonRightClicked(self): ...
    def _NavigationToolbar__updateState(self): ...
    def clearFuture(self): ...
    def clearPast(self): ...
    def getCallback(self): ...
    def getCurrentEntry(self): ...
    def pushEntry(self, name, meta): ...
    def setCallback(self, callback): ...
