# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SortableGroups as SortableGroups
import UI4.Widgets.SortableGroups
import Utils as Utils
from typing import Set, Tuple

class SortableParamsFormWidget(UI4.Widgets.SortableGroups.SortableGroupsFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableParamsFormWidget__menuAction(self, action): ...
    def buildAddMenu(self, menu): ...
    def updatePanelWidgets(self): ...
