# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import Utils.EventModule as EventModule
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolibProducers
import PyXmlIO as PyXmlIO
import PyUtilModule.RenderManager.RenderTriggers as RenderTriggers
import Utils.UndoStack as UndoStack
import Utils as Utils
import collections
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

RENDERCAMERAPATH_VIEWER_BUILTIN: str
RENDERCAMERATYPES: tuple
RENDERCAMERATYPE_RENDERSETTINGS: int
RENDERCAMERATYPE_RENDERSETTINGS_LABEL: str
RENDERCAMERATYPE_SPECIFIC: int
RENDERCAMERATYPE_VIEWER: int
RENDERCAMERATYPE_VIEWER_LABEL: str
RENDERMODES: tuple
RENDERMODE_INTERACTIVE: int
RENDERMODE_LABELS: dict
RENDERMODE_OPTIONS: list
RENDERMODE_PENUP: int
RENDERMODE_PROCESS: int
TILE_PRIORITIZER_NONE: int
TILE_PRIORITIZER_SCANLINE: int
TILE_PRIORITIZER_SPIRAL: int

def ClearSequenceIDMaps(): ...
def GetAvailableSampleRates(): ...
def GetBuffer2DAutoLock(): ...
def GetDefaultSampleRate(): ...
def GetDiskCachingAllowed(): ...
def GetInteractiveSampleRate() -> Tuple[float, float]: ...
def GetLiveRenderOpTreePath() -> str | None: ...
def GetOverscanPadding() -> Tuple[float, float, float, float]: ...
def GetRenderIDPass(): ...
def GetRenderMode() -> int: ...
def GetRenderNodeTypes(): ...
def GetRenderROI(resolution: Incomplete | None = ...) -> None: ...
def GetRenderRawROI() -> None: ...
def GetRenderUseROI() -> bool: ...
def GetRenderViews(): ...
def GetRenderViewsAutoUpdate(): ...
def GetRerenderCamera(renderSettings: Incomplete | None = ...) -> Tuple[int, str]: ...
def GetRerenderMode() -> int: ...
def GetRerenderNodeName() -> str | None: ...
def GetRerenderRenderProducer() -> PyFnGeolibProducers.GeometryProducer | None: ...
def GetRerenderRendererName() -> str | None: ...
def GetSampleRate() -> Tuple[float, float]: ...
def GetSequenceIDMap(mainSequenceID: int) -> collections.OrderedDict: ...
def GetTilePrioritizer(): ...
def IsDefaultROIUsed() -> bool: ...
def IsRenderNode(nodeType): ...
def IsRenderROIAbsolute() -> bool: ...
def IsRerendering() -> bool: ...
def IsSceneGraphMaskEnabled(): ...
def QueryRender(mainSequenceID: int = ...): ...
def ResetRenderROI(): ...
def ResumeRender(mainSequenceID: int = ...): ...
def SetBuffer2DAutoLock(autoLock): ...
def SetDiskCachingAllowed(value): ...
def SetInteractiveSampleRate(newRate: Tuple[float, float]): ...
def SetLiveRenderOpTreePath(filepath: str): ...
def SetOverscanPadding(paddingLBRT: Tuple[float, float, float, float]): ...
def SetRenderIDPass(renderIDPass): ...
def SetRenderMode(renderMode: int): ...
def SetRenderROI(roi: Tuple[float, float, float, float], absolute: bool = ...): ...
def SetRenderROIAbsolute(absolute: bool): ...
def SetRenderRawROI(roi: None): ...
def SetRenderUseROI(useROI: bool): ...
def SetRenderViews(renderViews): ...
def SetRenderViewsAutoUpdate(value): ...
def SetRerenderCamera(rerenderCameraType: int, rerenderCameraPath: Incomplete | None = ...): ...
def SetRerenderMode(renderMode: int): ...
def SetRerenderNodeName(nodeName: str | None): ...
def SetRerendering(isRerendering: bool): ...
def SetSampleRate(newRate: Tuple[float, float]): ...
def SetTilePrioritizer(mode): ...
def SuspendRender(mainSequenceID: int = ...): ...
def TriggerManualRender(): ...
def UpdateSequenceIDMap(mainSequenceID: int, outputName: str, sequenceID: Incomplete | None = ...): ...
