# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

class ImageLayerBase:
    def __init__(self, *args, **kwargs) -> None: ...
    def _ImageLayerBase__compositeTimer_timeout_CB(self): ...
    def _ImageLayerBase__slotTimer_timeout_CB(self): ...
    def getDragIndex(self): ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def layerStack(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
