# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Parser as Parser
from ConditionalStateGrammar.Parser import GetParser as GetParser, ParseAndBuildHintDict as ParseAndBuildHintDict
from typing import Set, Tuple
