# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import QT4GLLayerStack.Util as Util
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import ClassVar, Set, Tuple

class EdgeScrollingLayer(QT4GLLayerStack.LayerStack.Layer):
    _INTERVAL: ClassVar[int] = ...
    scroll: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, autoScroll: bool = ...) -> None: ...
    def _EdgeScrollingLayer__move(self): ...
    def _EdgeScrollingLayer__rescale(self, inV): ...
    def _EdgeScrollingLayer__update(self): ...
    def _EdgeScrollingLayer__viewScaleChanged(self, vs): ...
    def processEvent(self, event): ...
    def setLayerStack(self, layerStack): ...
