# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import typing
from QT4Widgets.PythonConsole import FullInteractivePython as FullInteractivePython
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.BaseTab import BaseTab
from UI4.Util.PythonSyntaxHighlighter import PythonSyntaxHighlighter as PythonSyntaxHighlighter
from UI4.Util.PythonWidgetIntrospector import PythonWidgetIntrospector as PythonWidgetIntrospector
from typing import Set, Tuple

PYTHONRC_FILENAME: str
_Environment: None

class EnhancedTerminalTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _EnhancedTerminalTab__on_commandWidget_editingFinished(self): ...
    def _EnhancedTerminalTab__on_prefChanged(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _EnhancedTerminalTab__on_pythonTab_exposeObject(self, eventType: str, eventID: object, objName: str, objInstance: object): ...
    def _EnhancedTerminalTab__on_scriptWidget_aboutToExecuteCode(self, sourceCode: C[str]): ...
    def clear(self): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def printMessage(self, message: str): ...

def _HandleLayoutActivated(eventType: str | None, eventID: object): ...
def _HandleLayoutsSaved(eventType: str | None, eventID: object): ...
def _RestoreCommandAreaContentsFromPreferences(): ...
def _StoreCommandAreaContentsInPreferences(): ...
