# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class KeyDrawingLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, treeWidget, *args, **kwargs) -> None: ...
    def _KeyDrawingLayer__currentTimeCB(self, args: Incomplete | None = ...): ...
    def _KeyDrawingLayer__drawWindowSpaceText(self, text: str, textColor: None, left: int, baseline: int, center: bool = ...): ...
    def _KeyDrawingLayer__getTreeItemStartY(self): ...
    def _KeyDrawingLayer__hitTestBoxForChildren(self, firstChildTop, item, startT, endT, hitAreaBottom, hitAreaTop, hitList): ...
    def _KeyDrawingLayer__paintItemChildrenGL(self, startY, item, visibleArea, degenerate, highlightColor, topLevel: bool = ...): ...
    def _KeyDrawingLayer__paintKey(self, t, y0, y1, isLeaf, degenerate, selected: bool = ..., reduced: bool = ..., potential: bool = ..., conflict: bool = ...): ...
    def _KeyDrawingLayer__paintTimeCursor(self, t, lineRgba, textRgba, x0, x1, yBottom, yBase): ...
    def _KeyDrawingLayer__paintTimebar(self, x0, x1, yTop, yBase, yBottom, palette): ...
    def _KeyDrawingLayer__timeRangeCB(self, *args): ...
    def clearKeysPotential(self): ...
    def getTextScale(self) -> float: ...
    def hitTestBox(self, hitArea: None) -> list: ...
    def hitTestPoint(self, worldPt): ...
    def hitTestPointForItem(self, worldPt): ...
    def initializeGL(self): ...
    def paintGL(self): ...
    def setGhostTime(self, t): ...
    def setKeysPotential(self, potentials, conflict: bool = ...): ...
    def setTextScale(self, textScale: float): ...
