# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
from UI4.FormMaster.Editors.NodeGroup import NodeGroupFormWidget as NodeGroupFormWidget
from typing import Set, Tuple

class Node2DGroupFormWidget(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _createChildWidget(self, policy, parentWidget, factory, index): ...
    def _popdownCreated(self, popdown): ...
    def getPopdownWidget(self): ...
    def populateDecorations(self, popdown, layout): ...
