# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4 as UI4
from _typeshed import Incomplete
from typing import Set, Tuple

def GetImagePath(title: Incomplete | None = ..., path: Incomplete | None = ...): ...
def SetLoadPath(path): ...
