# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4Widgets.CustomMenu import CustomMenu as CustomMenu
from typing import ClassVar, Set, Tuple

class PopdownLabel(PyQt5.QtWidgets.QLabel):
    buildMenuSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def buildMenu(self, menu): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...
    def minimumSizeHint(self): ...
    def mousePressEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def sizeHint(self): ...
    def updateStyle(self, isSetToDefault): ...
