# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
import types
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

class LayeredMenu:
    def __init__(self, populateCallback: types.MethodType, actionCallback: types.MethodType, keyboardShortcut: str, alwaysPopulate: bool = ..., onlyMatchWordStart: bool = ...) -> None: ...
    def addEntry(self, value: object, labelText: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ...): ...
    def alwaysPopulate(self): ...
    def clear(self): ...
    def getEntries(self): ...
    def getKeyboardShortcut(self): ...
    def getLastChosenValue(self): ...
    def isPopulated(self): ...
    def onEntryChosen(self, value): ...
    def onlyMatchWordStart(self) -> bool: ...
    def populate(self): ...

class LayeredMenuEntry:
    def __init__(self, value: object, text: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ...) -> None: ...
    def getColor(self): ...
    def getSize(self): ...
    def getText(self): ...
    def getValue(self): ...

def GetLayeredMenu(id: str): ...
def RegisterLayeredMenu(layeredMenu, layeredMenuID): ...
