# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NodeChooserButton(FilterablePopupButton):
    buttonClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    nodeSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _NodeChooserButton__filterItemCallback(self, value: bool, name, meta) -> bool: ...
    def addPopupWindowButton(self, text: str): ...
    def addSceneNodesCheckbox(self, text: str = ..., defaultValue: bool = ...): ...
    def getNodeNames(self) -> list[str | None]: ...
    def getNodeTypeName(self) -> str | None: ...
    def on_aboutToShow(self): ...
    def on_button_clicked(self): ...
    def on_itemChosen(self, name, meta): ...
    def setNodeNames(self, nodeNames: list[str | None]): ...
    def setNodeTypeName(self, nodeTypeName: str | None): ...
