# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibServices as FnGeolibServices
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def GetGenericAssignFiles() -> list[None]: ...
def GetGenericAssignNodeTypes() -> dict: ...
def InitGenericAssignNodeTypes(searchPaths: Incomplete | None = ...): ...
def RegisterGenericAssignNodeTypes(searchPaths: Incomplete | None = ...): ...
