# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibProducers
import GeoAPI.Util as Util
import PyFnGeolibServices.XFormUtil as XFormUtil
from typing import Set, Tuple

def ProducerLocalTransform(producer: PyFnGeolibProducers.GeometryProducer): ...
def ProducerWorldBounds(producer: PyFnGeolibProducers.GeometryProducer): ...
def ProducerWorldTransform(producer: PyFnGeolibProducers.GeometryProducer): ...
def UnionBounds(bounds1, bounds2): ...
