# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import Utils as Utils
from NodegraphAPI.NodegraphGlobals import GetRootNode as GetRootNode
from NodegraphAPI_cmodule import GroupNode as GroupNode
from typing import Set, Tuple

saveflags: int
useFlags: bool

def connectFromGroupContents(currentOutPort, targetGroupNode): ...
def connectToGroupContents(currentOutPort, targetGroupNode): ...
def connectToPortOutsideOfCurrentGroup(producerPort, consumerPort): ...
def findPathBetween(sourcePort, destPort): ...
def getNodeDepth(node: NodegraphAPI.Node): ...
def getNodeListToRoot(node: NodegraphAPI.Node): ...
def getUniqueName(name, checkcallback): ...
