# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class PresetsGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _PresetsGroupFormWidget__comparePresetValuesType(self, values1, values2): ...
    def _PresetsGroupFormWidget__initParser(self): ...
    def _PresetsGroupFormWidget__parsePresetValues(self, valuesStr: str) -> list | None: ...
    def _PresetsGroupFormWidget__parsePresets(self, presetsString: str) -> list: ...
    def _PresetsGroupFormWidget__presetComboBox_CB(self, requestedPresetName): ...
    def _PresetsGroupFormWidget__syncPresetComboBox(self, event: Incomplete | None = ...): ...
    def _buildControlWidget(self, layout): ...
    def _freeze(self): ...
    def _thaw(self): ...
