# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.ExternalTools as ExternalTools
import KatanaResources as KatanaResources
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class HtmlEditorWidget(PyQt5.QtWidgets.QFrame):
    _HtmlEditorWidget__pixmaps: ClassVar[dict] = ...
    kHtmlRefURL: ClassVar[str] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, growPreview: bool = ...) -> None: ...
    def _HtmlEditorWidget__editTextChanged(self): ...
    def _HtmlEditorWidget__helpCallback(self): ...
    def _HtmlEditorWidget__insertImageCallback(self): ...
    def _HtmlEditorWidget__insertLinkCallback(self): ...
    def _HtmlEditorWidget__linkClickedCallback(self, url): ...
    def _HtmlEditorWidget__loadResources(self): ...
    def _HtmlEditorWidget__transferText(self): ...
    def getInputEditor(self): ...
    def setLocked(self, state): ...
    def setText(self, text): ...
    def text(self): ...
