# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

ARRAY_TYPE_TO_CONSTANT: list
GL_VOID_P: object
GLvoid: None
ctypes_version: list
integer_types: tuple
void: None
