# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def BackspaceSpacesToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, spacing: int = ...) -> bool: ...
def CountWhitespaceToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, previousTab: bool = ..., spacing: int = ...) -> int: ...
def DeleteSpacesToTabStop(textEdit: PyQt5.QtWidgets.QTextEdit, spacing: int = ...) -> bool: ...
def InsertNewLineAndAutoIndent(textEdit: PyQt5.QtWidgets.QTextEdit, rule: str, spacing: int = ...): ...
def MoveToLineStart(textEdit: PyQt5.QtWidgets.QTextEdit, keepAnchor: bool): ...
def Reindent(textEdit: PyQt5.QtWidgets.QTextEdit, unindent: bool, spacing: int = ...): ...
def ToggleComment(textEdit: PyQt5.QtWidgets.QTextEdit, commentSymbol: str): ...
