# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModuleCommon as EventModuleCommon
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import typing
from PyQt5.QtCore import kKatanaEventType as kKatanaEventType
from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from typing import Set, Tuple

class KatanaEventReceiver(PyQt5.QtCore.QObject):
    def __init__(self) -> None: ...
    def _KatanaEventReceiver__invokeCollapsedDict(self, handlersDict, args): ...
    def _KatanaEventReceiver__invokeHandlerDict(self, handlersDict, eventType, eventID, kwargs): ...
    def _KatanaEventReceiver__on_collapsedEventsTimer_timeout(self): ...
    def customEvent(self, event: PyQt5.QtCore.QEvent): ...
    def initialize(self): ...
    def invokeCollapsedHandlers(self): ...

def Initialize(): ...
def ProcessAllEvents(): ...
def ProcessEvents() -> bool: ...
def PumpIdleQueue(): ...
def QueueEvent(eventType: str, eventID: typing.Hashable, priority: int = ..., **kwargs): ...
def QueuePriorityEvent(eventType: str, eventID: typing.Hashable, **kwargs): ...
