# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import QT4Widgets as QT4Widgets
import Utils as Utils
from QT4Widgets.LogView import LogView
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogRenderLogWidget(LogView):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogRenderLogWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogRenderLogWidget__catalog_renderLogAppend_CB(self, eventType, eventID, item, message): ...
    def _CatalogRenderLogWidget__catalog_renderLogReset_CB(self, eventType, eventID, item): ...
    def _CatalogRenderLogWidget__renderLog_listenForMessageAppends(self, eventType, eventID, **kwargs): ...
    def getCatalogItem(self) -> CatalogAPI.CatalogItem.CatalogItem | None: ...
    def setCatalogItem(self, item): ...
    def unlockAutoScrolling(self): ...
    def updateState(self): ...
