# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtWebEngineWidgets
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import ClassVar, Set, Tuple

class HelpView(PyQt5.QtWebEngineWidgets.QWebEngineView):
    DEFAULT_STYLE_SHEET_FILENAME: ClassVar[str] = ...
    DEFAULT_ZOOM_LEVEL: ClassVar[float] = ...
    MAX_ZOOM_LEVEL: ClassVar[int] = ...
    MIN_ZOOM_LEVEL: ClassVar[float] = ...
    inlineCSS: ClassVar[str] = ...
    linkClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, defaultZoomLevel: float = ...) -> None: ...
    @classmethod
    def GetUrlFromFilename(cls, filename: str) -> PyQt5.QtCore.QUrl: ...
    def _HelpView__linkHoveredCallback(self, url): ...
    def _HelpView__resetZoomLevel(self): ...
    def backwardTo(self, index: int): ...
    def event(self, event): ...
    def eventFilter(self, obj, event): ...
    def forwardTo(self, index: int): ...
    def setBody(self, body: str): ...
    def zoomIn(self, increment: float = ...): ...
    def zoomOut(self, decrement: float = ...): ...
