# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import UI4.Tabs.NodeGraphTab.Layers.LinkConnectionLayer as LinkConnectionLayer
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MergeNodeInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _MergeNodeInteractionLayer__deletePortCallback(self, mId: Incomplete | None = ...): ...
    def _MergeNodeInteractionLayer__multiOutPopupChosen(self, text, meta): ...
    def _MergeNodeInteractionLayer__multiPopClosed(self): ...
    def _MergeNodeInteractionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _MergeNodeInteractionLayer__renamePortCallback(self, menuid: int = ...): ...
    def _MergeNodeInteractionLayer__unhilite(self): ...
    def addMultiOutPopupCallback(self, cb): ...
    def processEvent(self, event): ...
