# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Tabs.AttributesTab.AttributesTab import AttributesTab as AttributesTab
from typing import Set, Tuple

PluginRegistry: list
