# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore as QtCore
import Utils as Utils
from typing import Set, Tuple

class TimerCallbackObject:
    def __init__(self, callbackFn, interval, registerStack, suppressCallbackDurationWarning: bool = ...) -> None: ...
    def _TimerCallbackObject__timer_CB(self): ...
    def getCallback(self): ...
    def getInternalTime(self): ...
    def getIntervalText(self): ...
    def getName(self): ...
    def getNumCalls(self): ...
    def getNumExceededThresholds(self): ...

def InitializePluginManager(): ...
def PrintStatistics(): ...
def RegisterTimerCallback(callbackFn, interval, suppressCallbackDurationWarning: bool = ...): ...
def UnregisterTimerCallback(callbackFn): ...
