# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def CopyExrWithTranscode(sourceFile, destFile, mipmap: bool = ..., roundUp: bool = ..., tileSize: int = ..., compression: str = ..., disableFiltering: bool = ...): ...
