# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster as FormMaster
import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RegisterToCamera as RegisterToCamera
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Nodes3DAPI.TransformUtil as TransformUtil
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from typing import Set, Tuple

class HomogeneousTransformEditor(GroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _HomogeneousTransformEditor__assignTransform(self, matrix): ...
    def _HomogeneousTransformEditor__assignTranslation(self, matrix): ...
    def _HomogeneousTransformEditor__copyLocal(self): ...
    def _HomogeneousTransformEditor__copyWorld(self): ...
    def _HomogeneousTransformEditor__fitBounds(self): ...
    def _HomogeneousTransformEditor__getLocationPath(self): ...
    def _HomogeneousTransformEditor__getLocationProducer(self): ...
    def _HomogeneousTransformEditor__hasInputProducer(self): ...
    def _HomogeneousTransformEditor__registerToCamera(self): ...
    def _HomogeneousTransformEditor__resetTransform(self): ...
    def _HomogeneousTransformEditor__snapToWorldPos(self): ...
    def _HomogeneousTransformEditor__toolsAboutToShow(self, menu): ...
    def _lockChanged(self, state): ...
    def getHilightWidgets(self): ...

class _registerPlaneDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent, applyFunction, distance, planeType) -> None: ...
    def accept_CB(self): ...
    def apply_CB(self): ...
    def getResult(self): ...
    def reject_CB(self): ...
    def sizeHint(self): ...
