# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PackageSuperToolAPI.PackageNameItemDelegate
import UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ColorItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.LightLinkItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates
import UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.NumberItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.ShaderItemDelegate
import UI4.Widgets.SceneGraphView.ItemDelegates.WorkingSetItemDelegate
from typing import ClassVar, Set, Tuple

class ColumnDataType:
    Color: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ColorItemDelegate.ColorItemDelegate]] = ...
    Dummy: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate.DummyItemDelegate]] = ...
    LightLink: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.LightLinkItemDelegate.LightLinkItemDelegate]] = ...
    Mute: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates.MuteItemDelegate]] = ...
    Name: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate.NameItemDelegate]] = ...
    Number: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.NumberItemDelegate.NumberItemDelegate]] = ...
    PackageName: ClassVar[type[PackageSuperToolAPI.PackageNameItemDelegate.PackageNameItemDelegate]] = ...
    SceneGraphTabColorColumn: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabColorColumnDelegate]] = ...
    SceneGraphTabCustomColumn: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabCustomColumnDelegate]] = ...
    SceneGraphTabLocationName: ClassVar[type[UI4.Tabs.SceneGraphTab.SceneGraphTabNameItemDelegate.SceneGraphTabNameItemDelegate]] = ...
    Shader: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ShaderItemDelegate.ShaderItemDelegate]] = ...
    Solo: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.MuteAndSoloItemDelegates.SoloItemDelegate]] = ...
    String: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate.ParameterItemDelegate]] = ...
    WorkingSet: ClassVar[type[UI4.Widgets.SceneGraphView.ItemDelegates.WorkingSetItemDelegate.WorkingSetItemDelegate]] = ...

def RegisterDataType(dataTypeName: str, itemDelegateClass): ...
