# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

VIEW_MASK_ALL: str

def GetActiveViews(viewMask: str) -> list[str]: ...
def GetDefaultView() -> str: ...
def GetLeftView() -> str: ...
def GetRightView() -> str: ...
def GetViewAbbreviation(view: str) -> str: ...
def GetViewProductToken(view: str) -> str: ...
def GetViewUIColor(view: str) -> tuple: ...
def GetViews() -> list[str]: ...
def IsMaskedViewActive(view: str, viewMask: str) -> bool: ...
def IsViewValid(view: str) -> bool: ...
