# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class IsolateDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def _IsolateDelegate__appendIsolateScenegraphLocations(self, targetNode, locations, replace: bool = ...): ...
    def _IsolateDelegate__dialogPrompt(self, firstActionText): ...
    def _IsolateDelegate__replaceIsolateScenegraphLocations(self, targetNode, locations): ...
    def _IsolateDelegate__setIsolateRoot(self, targetNode, location): ...
    def _IsolateDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...
