# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4GLLayerStack.Util as Util
from QT4GLLayerStack.LayerStack import Layer as Layer
from typing import Set, Tuple

class ZoomInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, name, allowLeftButton: bool = ..., allowMidButton: bool = ..., allowMouseWheel: bool = ..., *args, **kwargs) -> None: ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setHorizontalLock(self, isLocked): ...
    def setVerticalLock(self, isLocked): ...
    def thaw(self): ...

class ZoomTransientLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, event, horizontalLock, verticalLock, prevFocusLayer, *args, **kwargs) -> None: ...
    def _ZoomTransientLayer__doVirtualDrag(self, globalPoint): ...
    def _ZoomTransientLayer__dragSensitivityFunction(self, delta): ...
    def freeze(self): ...
    def processEvent(self, e): ...
    def setAllowKeylessTabletInteraction(self, allowKeylessTabletInteraction): ...
    def setLayerStack(self, s): ...
    def thaw(self): ...
    def __del__(self) -> None: ...
