# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from QT4FormWidgets.ExpressionEditDialog import ExpressionEditDialog as ExpressionEditDialog
from QT4FormWidgets.StateChangeAction import StateChangeAction as StateChangeAction
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import Set, Tuple

class PasteMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, source, parent, locked) -> None: ...
    def _PasteMenu__doShow(self): ...
    def _PasteMenu__pasteAll(self): ...
    def _PasteMenu__pasteLink(self): ...
    def _PasteMenu__pasteValue(self): ...
    def copySource(self): ...

def AddPolicyTypeActions(menu, policy, locked, doConstant: Incomplete | None = ..., doCurve: Incomplete | None = ..., doExpression: Incomplete | None = ..., doKey: Incomplete | None = ..., doAutoKey: Incomplete | None = ..., doShowCurve: Incomplete | None = ...): ...
def AddValueStateMenuItems(menu: PyQt5.QtWidgets.QMenu, policy: QT4FormWidgets.AbstractValuePolicy, locked: bool): ...
