# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnAttribute as FnAttribute
import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import Set, Tuple

class LookFilePassname(StringFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFilePassname__chooseLookFilePassFromProduct(self): ...
    def _LookFilePassname__chooseLookFilePassFromSelection(self): ...
    def _LookFilePassname__menuAboutToShow(self, menu): ...
    def _buildControlWidget(self, layout): ...
    def askForPassAndSetIt(self, passes): ...
    def generateMenu(self): ...
    def getLookFilePassesFromProduct(self): ...
    def getLookFilePassesFromSelection(self): ...
    def getProductParam(self): ...
    def getProductValue(self): ...
