# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import GetGainNumberDict as GetGainNumberDict, GetGammaNumberDict as GetGammaNumberDict, GetOffsetNumberDict as GetOffsetNumberDict, GetSaturationNumberDict as GetSaturationNumberDict
from typing import Set, Tuple

_NodeHints: dict
_NodeName: str
