# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple
