# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class VPStateButton(ToolbarButton):
    def __init__(self, parent) -> None: ...
    def _VPStateButton__clicked(self): ...
    def _VPStateButton__setDirty(self, dirty): ...
    def _VPStateButton__updateCallback(self, args): ...
