# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class BaseLayoutResizer(PyQt5.QtWidgets.QFrame):
    def __init__(self, targetWidget: PyQt5.QtWidgets.QWidget, beforeTargetWidget: bool, orientation: PyQt5.QtCore.Qt.Orientation = ..., parent: Incomplete | None = ...) -> None: ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mouseMoveEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
