# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def GetRegisteredActionClasses() -> list: ...
def RegisterActionClass(actionClass: type): ...
