# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.EnvUtils as EnvUtils
import UI4.KatanaPrefs.PrefNames as PrefNames
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

def openDocument(filename: str) -> bool: ...
def openFile(filename: str, command: str, verb: str = ...) -> bool: ...
def openFileForEdit(filename: str) -> bool: ...
def openImage(filename: str) -> bool: ...
def openUrl(url: str) -> bool: ...
def splitCommandLineString(command: str) -> list[str]: ...
