# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import NodegraphAPI_cmodule
from NodegraphAPI_cmodule import PythonNode as PythonNode, node_addNodeFlavor as node_addNodeFlavor, node_registerPythonNodeType as node_registerPythonNodeType
from typing import ClassVar, Set, Tuple

class PythonRenderScript(NodegraphAPI_cmodule.PythonNode):
    PostRenderPublishContext: ClassVar[int] = ...
    PreRenderPublishContext: ClassVar[int] = ...
    RenderFrameContext: ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getActiveContexts(self): ...
    def postRenderPublish(self, versionup): ...
    def preRenderPublish(self, versionup): ...
    def renderFrame(self, graphState: NodegraphAPI.GraphState): ...
