# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import types
from _typeshed import Incomplete
from typing import Any, Set, Tuple

NodegraphAPI: None
Nodes2DAPI: None
Nodes3DAPI: None
PyUtilModule: None

class SystemModuleFinder:
    def find_module(self, fullname: str, path: Incomplete | None = ...) -> Any | None: ...

class SystemModuleLoader:
    def load_module(self, fullname: str) -> types.ModuleType | None: ...

def ProcessEnvironmentVariables(): ...
def __main(): ...
def disableSpecificWarnings(): ...
def excepthook(exceptionType: type, exception: Exception, tb: types.TracebackType): ...
def initDefaultRenderer(): ...
def initNoQt(options): ...
def initQt(): ...
def initWithQt(options): ...
def makeTmpDirectory(): ...
