# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import Utils as Utils
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from typing import Set, Tuple

class InputPortNamePopupFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _InputPortNamePopupFormWidget__node_addOrRemoveInputPort_cb(self, eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
    def _InputPortNamePopupFormWidget__node_renameInputPort_cb(self, eventType, eventID, **kwargs): ...
    def _InputPortNamePopupFormWidget__registerEventHandlers(self): ...
    def _InputPortNamePopupFormWidget__unregisterEventHandlers(self): ...
    def _InputPortNamePopupFormWidget__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
