# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from PyQt5.QtWidgets import GlobalActions as GlobalActions
from typing import Set, Tuple

class RedoAction(PyQt5.QtWidgets.QAction):
    def __init__(self, parent, hotkey) -> None: ...
    def _RedoAction__on_triggered(self): ...

class UndoAction(PyQt5.QtWidgets.QAction):
    def __init__(self, parent, hotkey) -> None: ...
    def _UndoAction__on_triggered(self): ...

def GetHotkeys(context: PyQt5.QtCore.Qt.ShortcutContext = ...) -> list: ...
def InitializeHotkeys(): ...
def ProcessHotkeyEvent(event): ...
