# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from Nodes3DAPI.Node3D import Node3D as Node3D
from Utils.Decorators import deprecated as deprecated
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class Isolate(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addIsolatePatternEntry(self, value): ...
    def addIsolateValueEntry(self, value): ...
    def addParameterHints(self, attrName, inputDict): ...
    def enableSecondaryOutput(self, isEnabled): ...
    def enableSecondayOutput(self, isEnabled): ...
    def isSecondaryOutputEnabled(self): ...
