# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import MachineInfo.MachineInfo as MachineInfo
from _typeshed import Incomplete
from typing import Set, Tuple

def GetImageDiskMemoryMB(isBatch, customLogger: Incomplete | None = ...): ...
def GetImageMemoryMB(isBatch, customLogger: Incomplete | None = ...): ...
def GetRenderThreadCount(): ...
def GetRenderTileSize(customLogger: Incomplete | None = ...): ...
