# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def GetCapsuleArgsFromHints(hints): ...
def GetColorList(listHint): ...
def GetMapping(mappingHint, numberValues: bool = ..., order: list = ...): ...
def GetSliderArgsFromHints(hints): ...
def GetStringList(listHint): ...
def HintTrue(hintName: str, hints: dict, default: bool = ...) -> bool: ...
