# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import PyFnAttribute as FnAttribute
import PyFnAttribute
import PyUtilModule.RenderingCommon as RenderingCommon
import Utils as Utils
from . import PluginActionRegistry as PluginActionRegistry
from _typeshed import Incomplete
from typing import Set, Tuple

kVirtualCameraSceneGraphLocation: str

def AppendTerminalOp(opKey: object, opType: str, opArgs: PyFnAttribute.GroupAttribute): ...
def ClearAllTerminalOps(): ...
def GetTerminalOps() -> list[None]: ...
def InsertTerminalOp(opKey: object, opType: str, opArgs: PyFnAttribute.GroupAttribute, insertIndex: int): ...
def RemoveTerminalOp(opKey: object, deferred: bool = ...): ...
def RestoreDefaultTerminalOps(): ...
def SendCommand(command: str): ...
def SendData(dataType: str | StringAttribute, locationPath: str | StringAttribute, attributes: PyFnAttribute.GroupAttribute): ...
def SetLiveAttribute(locationPath: str, attrPath: str, attrValue: PyFnAttribute.Attribute, attrEditor: Incomplete | None = ...): ...
def SetVirtualCameraAttributes(attributes: PyFnAttribute.GroupAttribute): ...
