# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def GetFreeSpaceB(dirName): ...
def GetMount(dirName): ...
def GetPrettySize(sizeInBytes): ...
def GetTotalSizeOfMountB(dirName): ...
def GetUsedSpaceB(dirName): ...
