# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DirectoryInfo:
    def __init__(self, directoryPath, findSequenceFunc: Incomplete | None = ...) -> None: ...
    def _DirectoryInfo__prepareSequences(self): ...
    def getDirectoryMTime(self): ...
    def getFileList(self): ...
    def getNonSequences(self): ...
    def getSequences(self): ...

class FileInfo:
    TYPE_DIRECTORY: ClassVar[int] = ...
    TYPE_FILE: ClassVar[int] = ...
    TYPE_LINK: ClassVar[int] = ...
    TYPE_SEQUENCE: ClassVar[int] = ...
    _DirectoryCache: ClassVar[dict] = ...
    _UIDCache: ClassVar[dict] = ...
    def __init__(self, directoryPath, fileName: Incomplete | None = ..., sequence: Incomplete | None = ...) -> None: ...
    def _FileInfo__stat(self, path): ...
    def ext(self): ...
    def mtime(self): ...
    def mtimeString(self): ...
    def name(self): ...
    def owner(self): ...
    @classmethod
    def readDirectory(cls, path, sequenceListing: bool = ..., findSequenceFunc: Incomplete | None = ...): ...
    def type(self): ...
