# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class ColorProbeBase:
    _ICON_NAME: ClassVar[str] = ...
    _ICON_NAME_HIGHLIGHT: ClassVar[str] = ...
    _ICON_NAME_ON: ClassVar[str] = ...
    _ICON_NAME_ON_HIGHLIGHT: ClassVar[str] = ...
    def __init__(self, defaultBuffer: int = ..., defaultStat: str = ..., autoClose: bool = ...) -> None: ...
    def _ColorProbeBase__monitor_pixelProbeResult_CB(self, eventType, eventID, **kwargs): ...
    def _fillMenu(self, menu): ...
    def _isEnabled(self): ...
    def _probeResult(self, probeInfo): ...
    def getBuffer(self): ...
    def getStatsType(self): ...
    def isOn(self): ...
    def setOn(self, on): ...

class ColorProbeButton(ToolbarButton, ColorProbeBase):
    monitor_pixelProbeResult: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, **kwargs) -> None: ...
    def _ColorProbeButton__aboutToShowControlMenu_CB(self): ...
    def _ColorProbeButton__toggled_CB(self): ...
    def _isEnabled(self): ...
    def _probeResult(self, probeInfo): ...
    def getControlMenu(self): ...
