# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolib
import ViewerAPI
from typing import Set, Tuple

class BaseViewerPluginExtension:
    def onApplyTerminalOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction, inputOp: PyFnGeolib.GeolibRuntimeOp | None, viewerDelegate: ViewerAPI.ViewerDelegate) -> PyFnGeolib.GeolibRuntimeOp: ...
    def onDelegateCreated(self, viewerDelegate: ViewerDelegate, pluginName: str): ...
    def onTabCreated(self, tab: BaseViewerTab): ...
    def onViewportCreated(self, viewportWidget: ViewportWidget, pluginName: str, viewportName: str): ...
