# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from typing import ClassVar, Set, Tuple

class NodeOrParameterDropLabel(PyQt5.QtWidgets.QLabel):
    parameterDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...

class TeleparamWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _TeleparamWidget__buildHostedWidget(self): ...
    def _TeleparamWidget__paramDropped(self, path): ...
    def _buildControlWidget(self, hbox): ...
    def _buildTopAreaLayout(self, layout): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def decorateUserParameterFrame(self, parent): ...
    def valueChangedEvent(self, event): ...
