# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def AddAnamorphScale(scaleAmt): ...
def GetAnamorphScales(): ...
def GetDefaultAnamorphScale(): ...
def ShouldDisplayAnamorphScale(): ...
