# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolib
import UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation as SceneGraphLocationTranslation
from UI4.Util.ClientManager import ClientManager as ClientManager
from typing import Set, Tuple

class SceneGraphViewClientManager(ClientManager):
    def __init__(self) -> None: ...
    def _SceneGraphViewClientManager__isLocationUnder(self, location: str, otherLocation: str) -> bool: ...
    def _getClientForLocation(self, location: str, topLevelLocation: str | None) -> PyFnGeolib.GeolibRuntime.Client: ...
    def topLevelLocationAdded(self, topLevelLocation: str): ...
    def topLevelLocationRemoved(self, topLevelLocation: str): ...
