# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class DragSizer(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, allowHorizontal: bool = ..., allowVertical: bool = ...) -> None: ...
    def _DragSizer__resizeParent(self, width, height): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def paintEvent(self, event): ...
    def setMinHeight(self, h): ...
    def setMinWidth(self, w): ...

class StretchBox(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, cacheSizeHint: Incomplete | None = ..., allowHorizontal: bool = ..., allowVertical: bool = ...) -> None: ...
    def _StretchBox__repositionSizer(self): ...
    def _storeSize(self, height): ...
    def childEvent(self, event): ...
    def resizeEvent(self, event): ...
    def showEvent(self, event): ...
