# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple

class CatalogItemCommentEditor(PyQt5.QtWidgets.QLineEdit):
    def __init__(self, *args) -> None: ...
    def _CatalogItemCommentEditor__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogItemCommentEditor__catalog_itemUserCommentUpdate_CB(self, eventType, eventID, item): ...
    def _CatalogItemCommentEditor__editingFinished_CB(self): ...
    def setCatalogItem(self, item): ...
    def updateState(self): ...
