# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyOpenColorIO as OCIO
import PyQt5.QtCore
import QT4Color as QT4Color
import PyQt5.QtCore as QtCore
import UI4 as UI4
from typing import ClassVar, Set, Tuple

class DrawState(PyQt5.QtCore.QObject):
    MATTE_MULT_NONE: ClassVar[int] = ...
    MATTE_MULT_PREMULT: ClassVar[int] = ...
    MATTE_MULT_UNPREMULT: ClassVar[int] = ...
    SWIZZLE_ALPHA: ClassVar[tuple] = ...
    SWIZZLE_BLUE: ClassVar[tuple] = ...
    SWIZZLE_COLOR: ClassVar[tuple] = ...
    SWIZZLE_GREEN: ClassVar[tuple] = ...
    SWIZZLE_LUMA: ClassVar[tuple] = ...
    SWIZZLE_RED: ClassVar[tuple] = ...
    _SWIZZLE_NAMES: ClassVar[dict] = ...
    calculateViewRangeSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    calculateViewRangeZSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    drawStateUpdated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    kGettersToCompare: ClassVar[list] = ...
    def __init__(self, *args) -> None: ...
    def _DrawState__gamutTimer_CB(self): ...
    def _DrawState__recomputeDisplayCC(self): ...
    def adopt(self, other, emit): ...
    def calculateViewRange(self): ...
    def calculateViewRangeZ(self): ...
    def emitChangeSignal(self): ...
    def getCC(self): ...
    def getCeilCheckValue(self): ...
    def getCurrentGamutCheckColor(self): ...
    def getDefaultInputColorspace(self): ...
    def getDefaultView(self): ...
    def getDisplay(self): ...
    def getDisplayRequest(self): ...
    def getFStopOffset(self): ...
    def getFloorCheckValue(self): ...
    def getInputColorSpaces(self): ...
    def getInputColorspace(self): ...
    def getLayerSelection(self): ...
    def getMatteMult(self): ...
    def getMatteOverlay(self): ...
    def getMatteOverlayColor(self): ...
    def getMatteOverlayInvert(self): ...
    def getSwizzle(self): ...
    def getSwizzleName(self): ...
    def getView(self): ...
    def getViewAdjustmentsMuted(self): ...
    def getViewGamma(self): ...
    def getViewMax(self): ...
    def getViewMin(self): ...
    def getViews(self): ...
    def invertViewRange(self): ...
    def isCeilCheckEnabled(self): ...
    def isFloorCheckEnabled(self): ...
    def isGamutCheckTimerActiveAndUseful(self): ...
    def isInfCheckEnabled(self): ...
    def isNanCheckEnabled(self): ...
    def resetChecks(self): ...
    def resetLayerSelection(self): ...
    def resetViewRange(self): ...
    def setCC(self, cc): ...
    def setCeilCheckEnabled(self, doCheck): ...
    def setCeilCheckValue(self, value): ...
    def setDisplay(self, display): ...
    def setFStopOffset(self, fstop): ...
    def setFloorCheckEnabled(self, doCheck): ...
    def setFloorCheckValue(self, value): ...
    def setInfCheckEnabled(self, doCheck): ...
    def setInputColorspace(self, csname): ...
    def setLayerSelection(self, layerSelection): ...
    def setMatteMult(self, state): ...
    def setMatteOverlay(self, state): ...
    def setMatteOverlayColor(self, state): ...
    def setMatteOverlayInvert(self, state): ...
    def setNanCheckEnabled(self, doCheck): ...
    def setSwizzle(self, mode): ...
    def setView(self, name): ...
    def setViewAdjustmentsMuted(self, val): ...
    def setViewGamma(self, val): ...
    def setViewMax(self, val): ...
    def setViewMin(self, val): ...
    def setViewToNormals(self): ...
    def startGamutCheckTimer(self, interval, colors): ...
    def stopGamutCheckTimer(self): ...
    def __eq__(self, other) -> bool: ...
    def __lt__(self, other) -> bool: ...

def GetDefaultOverlayColor(): ...
def GetDefaultOverlayColorPolicy(): ...
