# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibProducers
from GeoAPI import GetCameraInfo as GetCameraInfo, GetLocalToScreenMatrix as GetLocalToScreenMatrix, GetProjectionMatrix as GetProjectionMatrix
from typing import Set, Tuple, overload

def ConvertPointListToNDC(producer: PyFnGeolibProducers.GeometryProducer, cameraName: str, points: list[float]) -> list[float]: ...
def ExpandArchPath(inputString: str) -> str: ...
def FlushRendererOutputCaches() -> None: ...
def GetPixelAreaThroughCamera(producer: PyFnGeolibProducers.GeometryProducer, cameraName: str, resolution: str) -> int: ...
@overload
def ProcessTilePath(outputFile: str, tileData: list[int]) -> str: ...
@overload
def ProcessTilePath(outputFile: str, tileData: list[float]) -> str: ...
