# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

def combineLayeredMaterialOverrides(attr1: PyFnAttribute.Attribute, attr2: PyFnAttribute.Attribute, attr3: PyFnAttribute.Attribute) -> None: ...
def extractMaterialReferences(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...
def getLayerPrefixesFromMaterial(attr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.StringAttribute: ...
def resolveDeferredNetworkOps(attr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.GroupAttribute: ...
def resolveMaterialLayers(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...
def resolveMaterialReferences(attr: PyFnAttribute.GroupAttribute, processHints: bool = ...) -> PyFnAttribute.GroupAttribute: ...
