# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
import PyFnGeolib
from typing import Set, Tuple

class Traversal:
    def __init__(self, client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> None: ...
    def getLocationData(self) -> PyFnGeolib.LocationData: ...
    def getLocationPath(self) -> str: ...
    def getRelativeLocationPath(self) -> str: ...
    def next(self) -> None: ...
    def skipChildren(self) -> None: ...
    def valid(self) -> bool: ...

def GetScenegraphAsAttr(client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> PyFnAttribute.GroupAttribute: ...
def GetScenegraphAsPrettyText(client: PyFnGeolib.GeolibRuntimeClient, rootLocation: str) -> str: ...
def GetScenegraphAttrAsPrettyText(attr: PyFnAttribute.GroupAttribute, rootLocation: str) -> str: ...
