# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyQt5.QtCore as QtCore
from _typeshed import Incomplete
from typing import Set, Tuple

DEFAULT_SOURCE_NAME: str
REMOTE_HOST: str
SOURCES: dict

class _Source:
    def __init__(self, title, **urls) -> None: ...
    def get3DelightForKatanaURL(self) -> str: ...
    def getDevGuideURL(self, documentPath: str = ...) -> str: ...
    def getNodeHelpURL(self, nodeTypeName: str) -> str: ...
    def getOnlineHelpURL(self, cshid: Incomplete | None = ...) -> str: ...

def GetSource(sourceName: Incomplete | None = ...) -> _Source: ...
def GetStyleSheetsPath() -> str: ...
