# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from PyQt5.QtGui import kCopyrightTextColor as kCopyrightTextColor, kDetailTextColor as kDetailTextColor, kVersionTextColor as kVersionTextColor
from _typeshed import Incomplete
from typing import Set, Tuple

class SplashScreen(PyQt5.QtWidgets.QSplashScreen, SplashScreenMixin):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, pixmap: PyQt5.QtGui.QPixmap) -> None: ...
    def showMessage(self, message: str): ...

class SplashScreenMixin:
    def __init__(self) -> None: ...
    def _addTextGraphicsEffect(self, widget): ...
    def getRightLayout(self) -> PyQt5.QtWidgets.QVBoxLayout: ...
    def setDetailText(self, detailText: str | None): ...
    def setTextSelectable(self, textSelectable: bool): ...

def GetAboutDialogImage(release, detailText: Incomplete | None = ...): ...
def GetDefaultSplashScreenImageFilename() -> str: ...
def GetKatanaBuildDate(dateFormat: str = ...) -> str: ...
def GetSplashScreenImage(release: str, detailText: Incomplete | None = ...) -> PyQt5.QtGui.QImage | None: ...
def GetSplashScreenImageFilename() -> str: ...
def ShowSplashWindow(detailText: Incomplete | None = ...) -> PyQt5.QtWidgets.QSplashScreen | None: ...
