# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.DragTabs as DragTabs
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class PanelFrame(PyQt5.QtWidgets.QTabWidget):
    frameMaximized: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def addTab(self, widget, label): ...
    def close(self): ...
    def closeEvent(self, event): ...
    def doTabDoubleClick(self, index): ...
    def doTabRightMouse(self, index): ...
    def doTabStartDrag(self, index): ...
    def event(self, event): ...
    def getDragRect(self): ...
    def getFrameMaximized(self): ...
    def getMinSize(self): ...
    def getPhysRect(self, margin: int = ...): ...
    def getRealRect(self): ...
    def insertTab(self, index, widget, label): ...
    def keyPressEvent(self, event): ...
    def setDragRect(self, coordinates): ...
    def setFrameMaximized(self, state): ...
    def setPhysRect(self, coordinates): ...
    def setRealRect(self, coordinates): ...
    def __bool__(self) -> bool: ...
