# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class SwitchingBoxLayout(PyQt5.QtWidgets.QLayout):
    def __init__(self) -> None: ...
    def addItem(self, item): ...
    def addLayout(self, layout): ...
    def count(self): ...
    def expandingDirections(self): ...
    def hasHeightForWidth(self): ...
    def heightForWidth(self, w): ...
    def itemAt(self, index): ...
    def minimumSize(self): ...
    def setGeometry(self, geometry: Incomplete | None = ...): ...
    def setSpacing(self, spacing, direction: Incomplete | None = ...): ...
    def sizeHint(self): ...
    def spacing(self, direction: Incomplete | None = ...): ...
    def takeAt(self, index): ...
