# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Constraints.BaseConstraint import BaseConstraint as BaseConstraint
from typing import Set, Tuple

_ParamHints: dict
_Parameter_XML: str

class AimConstraint(BaseConstraint):
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getAllowMissingTargets(self, time): ...
    def getBasePath(self, time): ...
    def getConstraintArguments(self, time): ...
    def getConstraintType(self, time): ...
    def getRequireTargetBounds(self, time): ...
    def getTargetPaths(self, time): ...
