# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI.CatalogItem
import PyOpenColorIO as OCIO
import QT4Color as QT4Color
import QT4Color.Histogram
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class CatalogHistogramWidget(QT4Color.Histogram.HistogramWidget):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _CatalogHistogramWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogHistogramWidget__catalog_itemImageUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogHistogramWidget__doThrottledUpdate(self): ...
    def _CatalogHistogramWidget__updateImmediate(self): ...
    def _CatalogHistogramWidget__updateTimer_CB(self): ...
    def setCatalogItem(self, catalogItem: CatalogAPI.CatalogItem.CatalogItem | None): ...
    def setColorspace(self, colorspace: str): ...
    def setRect(self, rect: tuple | list[int]): ...
