# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def ExplodePath(locationPath): ...
def GetLocationName(locationPath): ...
def GetParentPath(locationPath, topLevelLocationPath: str = ...): ...
def IsLocationUnderTopLevelLocation(locationPath, topLevelLocationPath): ...
