# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.GLDrawingRoutines as GLDrawingRoutines
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore as QtCore
import PyResolutionTableFn as ResolutionTable
import UI4 as UI4
import UI4.Util.TransformManipulatorLayer
import Utils as Utils
from UI4.FormMaster.Editors.Layers.LayerWithTransform import LayerWithTransform as LayerWithTransform
from UI4.Util.TransformManipulatorLayer import ParameterTransformGroupManipulator as ParameterTransformGroupManipulator
from typing import Set, Tuple

class Transform2DManipLayer(LayerWithTransform, UI4.Util.TransformManipulatorLayer.ParameterTransformGroupManipulator):
    def __init__(self, valuePolicy) -> None: ...
    def _Transform2DManipLayer__paintBounds(self): ...
    def _Transform2DManipLayer__portConnectionChanged(self, args): ...
    def _Transform2DManipLayer__updateAspectRatio(self): ...
    def _Transform2DManipLayer__updateBounds(self): ...
    def _Transform2DManipLayer__updateInvert(self): ...
    def _Transform2DManipLayer__updateOrder(self): ...
    def _getComponentMatrix(self, component, toPivot, fromPivot): ...
    def _paramValueChanged(self, args): ...
    def paintGL(self): ...
