# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class OpaqueParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getWidgetHints(self): ...
