# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import UI4.Widgets as Widgets
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import ClassVar, Set, Tuple

class NewScenegraphLocationEditor(ScenegraphLocationEditorBase):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _menuAboutToShow(self, menu): ...

class ScenegraphLocationEditor(ScenegraphLocationEditorBase):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _allowNodeDrops(self): ...
    def _menuAboutToShow(self, menu): ...
    def valueChangedEvent(self, event): ...

class ScenegraphLocationEditorBase(StringFormWidget):
    _icons: ClassVar[dict] = ...
    _pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _ScenegraphLocationEditorBase__collectMenuAboutToShow(self, menu): ...
    def _ScenegraphLocationEditorBase__loadResources(self): ...
    def _allowNodeDrops(self): ...
    def _filterValueText(self, text): ...
    def _menuAboutToShow(self, qmenu): ...
    def checkMimeData(self, data): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def getButtonMenu(self): ...
    def getMimeData(self) -> PyQt5.QtCore.QMimeData: ...
    def setMimeData(self, data, dropAction): ...
