# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class KatanaPrefsObject:
    def __init__(self) -> None: ...
    def _KatanaPrefsObject__declarePref(self, key: str, typeName: str, helpText: Incomplete | None = ..., visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def commit(self): ...
    def declareBoolPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareColorPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareDoublePref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareGroupPref(self, key, visible: bool = ..., hints: Incomplete | None = ...): ...
    def declareIntPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareScenegraphColumnDescriptionPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def declareStringPref(self, key, default, helpText, visible: bool = ..., hints: Incomplete | None = ..., enabled: bool = ...): ...
    def flush(self): ...
    def getChildPrefs(self, key): ...
    def getHelpText(self, key): ...
    def getHints(self, key): ...
    def getType(self, key): ...
    def getVersion(self): ...
    def getVisible(self, key): ...
    def keys(self): ...
    def setVersion(self, prefsVersion): ...
    def shutdownCommit(self): ...
    def __contains__(self, item) -> bool: ...
    def __getitem__(self, key): ...
    def __len__(self) -> int: ...
    def __setitem__(self, key, value) -> None: ...
