# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import RenderingAPI as RenderingAPI
from typing import ClassVar, Set, Tuple

class RenderModes:
    DISK_RENDER: ClassVar[str] = ...
    DISK_RENDER_MENU_KEY: ClassVar[str] = ...
    LIVE_RENDER: ClassVar[str] = ...
    LIVE_RENDER_MENU_KEY: ClassVar[str] = ...
    MENU_ACTIONS: ClassVar[dict] = ...
    MENU_COMMANDS: ClassVar[dict] = ...
    MENU_ORDER: ClassVar[list] = ...
    MENU_PLURALS: ClassVar[dict] = ...
    MENU_TITLES: ClassVar[dict] = ...
    PREVIEW_RENDER: ClassVar[str] = ...
    PREVIEW_RENDER_MENU_KEY: ClassVar[str] = ...
    PROFILE_RENDER_MENU_KEY: ClassVar[str] = ...
