# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Tabs as Tabs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Widgets.LogRecordTreeView import LogRecordTreeView as LogRecordTreeView
from _typeshed import Incomplete
from typing import Set, Tuple

PluginRegistry: list

class MessagesTab(BaseTab):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _MessagesTab__updateTabTitle(self): ...
    def applySettings(self, settings: dict): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getSettings(self) -> dict: ...
    def on_treeView_activeLevelNamesChanged(self, activeLevelNames: list[str]): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...
