# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def CropWindowToImageRect(dataWindow, cropWindow): ...
def ImageRectToCropWindow(dataWindow, imageRect): ...
