# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
import Utils as Utils
from UI4.Util.IconManager import GetPixmap as GetPixmap
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class SimpleStopWidget(ToolbarButton):
    _SimpleStopWidget__DEFAULT_LABEL: ClassVar[str] = ...
    _SimpleStopWidget__NUM_PIXMAPS: ClassVar[int] = ...
    def __init__(self, parent, small: bool = ..., showPreselect: bool = ..., clickable: bool = ...) -> None: ...
    def _SimpleStopWidget__released(self): ...
    def advanceTick(self): ...
    def getActive(self): ...
    def isClickable(self): ...
    def isStopping(self): ...
    def mousePressEvent(self, event): ...
    def resetButton(self, frame: int = ..., disable: bool = ...): ...
    def setActive(self, active): ...
    def setClickable(self, clickable): ...
    def setStopping(self, stopping): ...

class StopButton(SimpleStopWidget):
    def __init__(self, parent) -> None: ...
    def _StopButton__clickedCallback(self): ...
    def connectToWorkQueue(self, workQueue): ...
    def getPixmapSize(self): ...
    def start(self): ...
    def startEvent(self, eventName, eventId, **kwargs): ...
    def stop(self): ...
    def stopEvent(self, eventName, eventId, **kwargs): ...
    def tickEvent(self, eventName, eventId, **kwargs): ...
