# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.RolloverPixmap import RolloverPixmap as RolloverPixmap
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class PanelWidget(PyQt5.QtWidgets.QWidget):
    class CloseBoxButton(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
        def __init__(self, parent) -> None: ...

    class DragBox(RolloverPixmap, PyQt5.QtWidgets.QLabel):
        dragBoxContextMenu: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, parent) -> None: ...
        def _DragBox__processDrag(self): ...
        def _resetAfterDrag(self): ...
        def contextMenuEvent(self, ev): ...
        def mousePressEvent(self, ev): ...
        def setIdentifier(self, identifier): ...
        def setWidgetSource(self, source): ...

    class IgnoreLabel(PyQt5.QtWidgets.QLabel):
        _IgnoreLabel__polygon: ClassVar[None] = ...
        def __init__(self, parent) -> None: ...

    class ZoomBox(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
        def __init__(self, parent) -> None: ...
    dragBoxContextMenu: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelDeleted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelDragInProgress: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    panelValueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, name, argdict: Incomplete | None = ...) -> None: ...
    def _PanelWidget__closeBoxCallback(self): ...
    def _PanelWidget__idle_callback(self, *args, **kwargs): ...
    def _PanelWidget__zoomBoxCallback(self): ...
    def aboutToBeDeleted(self): ...
    def added(self): ...
    def event(self, e): ...
    def getCloseBox(self): ...
    def getContentArea(self): ...
    def getDragBox(self): ...
    def getFormWidgetParent(self): ...
    def getIndex(self): ...
    def getLabel(self): ...
    def getName(self): ...
    def getTitleBar(self): ...
    def getTitleBarLeft(self): ...
    def getTitleBarRight(self): ...
    def getTitlePreLabel(self): ...
    def getValue(self): ...
    def isIgnoreable(self): ...
    def isIgnored(self): ...
    def paintEvent(self, event): ...
    def resizeEvent(self, e): ...
    def sendChange(self): ...
    def setFormWidgetParent(self, parent): ...
    def setIgnoreable(self, value): ...
    def setIgnored(self, value): ...
    def setIndex(self, index): ...
    def setLocked(self, state): ...
    def setName(self, name): ...
    def setZoomBoxVisible(self, state): ...
    def zoomBoxClicked(self): ...
