# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatResourceFiles
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import Utils as Utils
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import Set, Tuple
