# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class AttributeDropLabel(PyQt5.QtWidgets.QLabel):
    attrDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    attrDroppedWithCoAttributes: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    attrDroppedWithScenegraphPath: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    def dragEnterEvent(self, event: PyQt5.QtGui.QDragEnterEvent): ...
    def dropEvent(self, event: PyQt5.QtGui.QDropEvent): ...
