# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

class KeyboardShortcutItem:
    def __init__(self, name: str, data: dict, parent: Incomplete | None = ...) -> None: ...
    def _setParent(self, parent: KeyboardShortcutItem | None): ...
    def appendChild(self, child: KeyboardShortcutItem | None): ...
    def getChildByRow(self, row: int) -> KeyboardShortcutItem | None: ...
    def getCurrentShortcut(self) -> str: ...
    def getDefaultShortcut(self) -> str: ...
    def getID(self) -> str: ...
    def getName(self) -> str: ...
    def getParent(self) -> KeyboardShortcutItem: ...
    def getRowOfChild(self, child: KeyboardShortcutItem) -> int: ...
    def sort(self): ...
    def __len__(self) -> int: ...
