# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class NonexclusiveCheckboxPopup(FilterablePopupButton):
    valuesChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, emptyLabel: str = ...) -> None: ...
    def _NonexclusiveCheckboxPopup__itemChosen(self, name, meta): ...
    def _NonexclusiveCheckboxPopup__popupClosed(self): ...
    def _NonexclusiveCheckboxPopup__setItemCheck(self, item): ...
    def _NonexclusiveCheckboxPopup__treeCheckboxItem(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMouseMoveEvent(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMousePressEvent(self, event): ...
    def _NonexclusiveCheckboxPopup__treeMouseReleaseEvent(self, event): ...
    def addItem(self, *args, **kwds): ...
    def clear(self): ...
    def getValues(self): ...
    def setValues(self, values, updateItems: bool = ..., sendSignal: bool = ..., force: bool = ...): ...
