# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import Set, Tuple

DEFAULT: int
DEFAULT_REFERENCE: int
DELETE_LOCAL: int
FORCE_DEFAULT: int
FORCE_GLOBAL: int
GLOBAL: int
GLOBAL_DEFAULT_REFERENCE: int
INCOMING_LOCAL: int
LIVE: int
LOCAL: int
LOCAL_MULTI: int

def GetStateAppearance(state): ...
