# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from typing import Set, Tuple

def flush(isNodeGraphLoading: bool = ...): ...
def registerFlushCallback(fnc, post: bool = ...): ...
def setDirty(): ...
