# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
import Utils as Utils
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name) -> None: ...
    def _InputPanel__valueChangedCallback(self): ...
    def getName(self): ...
    def setName(self, name): ...

class PortNameAndOrderWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy) -> None: ...
    def _PortNameAndOrderWidget__idle_callback(self, *args, **kwargs): ...
    def _PortNameAndOrderWidget__node_addOrRemoveInputPort_cb(self, eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
    def _PortNameAndOrderWidget__node_renameInputPort_cb(self, eventType, eventID, **kwargs): ...
    def _PortNameAndOrderWidget__registerEventHandlers(self): ...
    def _PortNameAndOrderWidget__unregisterEventHandlers(self): ...
    def _PortNameAndOrderWidget__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def renamePort(self, oldName, newName): ...
