# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

class AttrMap:
    def __init__(self, *args, **kwargs) -> None: ...
    def get(self, key: str) -> PyFnAttribute.Attribute: ...
    def getKeys(self) -> PyFnAttribute.StringAttribute: ...

class LookFile:
    def __init__(self, filePath: str, passName: str = ...) -> None: ...
    def getAttrs(self, locationName: str, rootId: str = ...) -> AttrMap: ...
    def getMaterial(self, materialName: str, asGlobal: bool = ...) -> PyFnAttribute.Attribute: ...
    def getMaterialType(self, materialName: str) -> str: ...
    def getMaterials(self) -> AttrMap: ...
    @classmethod
    def getPassNamesForLookFileAsset(cls, asset: str) -> PyFnAttribute.StringAttribute: ...
    def getPathsWithOverrides(self, rootId: str = ...) -> PyFnAttribute.StringAttribute: ...
    def getRootIdNames(self) -> PyFnAttribute.StringAttribute: ...
    def getRootIdType(self, rootId: str) -> str: ...
    def getRootOverrides(self) -> AttrMap: ...
    @classmethod
    def getSafePath(cls, asset: str, includeVersion: bool = ...) -> PyFnAttribute.StringAttribute: ...
