# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

def Critical(title, text, acceptText: Incomplete | None = ..., cancelText: Incomplete | None = ..., parent: Incomplete | None = ..., detailedText: Incomplete | None = ...): ...
def Information(title, text, acceptText: Incomplete | None = ..., cancelText: Incomplete | None = ..., parent: Incomplete | None = ..., detailedText: Incomplete | None = ...): ...
def Question(title, text, acceptText: Incomplete | None = ..., cancelText: Incomplete | None = ..., parent: Incomplete | None = ..., detailedText: Incomplete | None = ...): ...
def Tristate(title, text, yesText: Incomplete | None = ..., noText: Incomplete | None = ..., cancelText: Incomplete | None = ..., icon: PyQt5.QtWidgets.QMessageBox.Icon = ..., Parent: Incomplete | None = ..., detailedText: Incomplete | None = ...): ...
def Warning(title, text, acceptText: Incomplete | None = ..., cancelText: Incomplete | None = ..., parent: Incomplete | None = ..., detailedText: Incomplete | None = ...): ...
