# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import ClassVar, Set, Tuple

class InitialState:
    DEFAULT: ClassVar[float] = ...
    OFF: ClassVar[float] = ...
    ON: ClassVar[float] = ...
    USE_EXISTING_VALUE: ClassVar[float] = ...
