# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import Utils as Utils
import collections
from Nodes3DAPI.Node3D import Node3D as Node3D
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class GenericAssign(Node3D):
    _GenericAssign__AttrTypeClasses: ClassVar[dict] = ...
    _HintTrueValues: ClassVar[list] = ...
    __pychecker__: ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def EscapeValue(value): ...
    @staticmethod
    def HintTrue(hintName: str, hints: dict, default: bool = ...) -> bool: ...
    def _GenericAssign__applyOverridesToInput(self, inputProducer, port: NodegraphAPI.Port, sourceTime, frameTime, applyLocalSettings: bool = ..., varNameSuffix: Incomplete | None = ...): ...
    @staticmethod
    def _decodeHints(text: str) -> dict: ...
    @staticmethod
    def _encodeHints(hints: collections.OrderedDict | dict) -> str: ...
    def _filterAttrList(self, graphState: NodegraphAPI.GraphState, attrList): ...
    def _getAttrRootForIncomingSceneQuery(self): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOpChain(self, interface): ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
    def _getStaticDefaultAttrForIncomingSceneQuery(self, attrPath): ...
    @staticmethod
    def _processGroup(attrlist, currentpath): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def findOverrideParameter(self, path, attrName, time, index: Incomplete | None = ..., editable: bool = ...): ...
    def getArgsParamRoot(self): ...
    def getFixedCELStatement(self): ...
    def setOverride(self, path, attrName, time, attrData, index: Incomplete | None = ..., *args, **kwargs): ...
    def updateArgsParameterDict(self, argsinfo, changeNode: bool = ...): ...
    def updateArgsParameterFile(self, filename: str): ...

def GetArgsFileDict(filename: str) -> collections.OrderedDict: ...
def GetArgsFileXML(filename: str) -> str: ...
