# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.PolicyFindPopup as PolicyFindPopup
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from UI4.FormMaster.AttributePolicy import BaseAttributePolicy as BaseAttributePolicy
from UI4.FormMaster.FnAttributePolicy import AttributePolicy as AttributePolicy
from _typeshed import Incomplete
from typing import Set, Tuple

class PeerHeaderGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: Incomplete | None = ...): ...
    def _buildLock(self, layout): ...
    def _buildStateBadge(self, policy): ...
    def _lockChanged(self, state): ...
    def _participatesInLabelAlignment(self): ...
    def getLabelWidth(self): ...
    def setLabelWidth(self, width): ...
    def showEvent(self, event): ...
