# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
from _typeshed import Incomplete
from typing import Set, Tuple

def CalcCropWindow(rect, dataWindow, renderSettingsCropWindow): ...
def GetLocalNumber(): ...
def GetTmpLocalFile(suffix: str, prefix: str, frame: Incomplete | None = ...) -> str: ...
def SetModeFlags(filename): ...
def ShouldCleanupTmpFiles(): ...
