# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ParameterValueOption:
    def __init__(self, *values) -> None: ...
    def __eq__(self, value: str) -> bool: ...
    def __ne__(self, value: str) -> bool: ...
