# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.ValuePolicy
import QT4FormWidgets.ValuePolicy as ValuePolicy
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class PythonDictValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    RESERVED_NAMES: ClassVar[set] = ...
    def __init__(self, name, dictionary, parent: Incomplete | None = ..., childOrderList: Incomplete | None = ..., childHintDict: Incomplete | None = ...) -> None: ...
    def _PythonValuePolicy__confirmChildHintDict(self, childHints): ...
    def _PythonValuePolicy__confirmOrderList(self, orderList): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getType(self): ...
    def getWidgetHints(self): ...

class PythonGroupPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, name, parent: Incomplete | None = ...) -> None: ...
    def addChildPolicy(self, policy): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getStateAppearance(self, state: set): ...
    def getType(self): ...
    def getWidgetHints(self): ...
    def removeChildPolicy(self, policy): ...
    def setWidgetHints(self, hints): ...

class PythonValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    RESERVED_NAMES: ClassVar[set] = ...
    def __init__(self, name, dictionary, parent: Incomplete | None = ..., childOrderList: Incomplete | None = ..., childHintDict: Incomplete | None = ...) -> None: ...
    def _PythonValuePolicy__confirmChildHintDict(self, childHints): ...
    def _PythonValuePolicy__confirmOrderList(self, orderList): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getType(self): ...
    def getWidgetHints(self): ...

class _ArrayPythonPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, name, valueList, parent) -> None: ...
    def _ArrayPythonPolicy__buildChildren(self): ...
    def getArrayChild(self, index): ...
    def getArraySize(self): ...
    def getName(self): ...
    def getType(self): ...
    def getWidgetHints(self): ...
    def setArraySize(self, size): ...

class _NumberPythonPolicy(_StringPythonPolicy):
    Types: ClassVar[tuple] = ...

class _StringPythonPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    Types: ClassVar[tuple] = ...
    def __init__(self, name, dictionary, parent) -> None: ...
    def getName(self): ...
    def getType(self): ...
    def getValue(self): ...
    def getWidgetHints(self): ...
    def setValue(self, value, final: bool = ..., emit: bool = ...): ...
