# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyXmlIO as PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import UI4.Widgets.SortablePanel
from UI4.Widgets.SortablePanel import ParameterExpressionPanel as ParameterExpressionPanel, ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget, SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class SortableArrayEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SortableArrayEditor__getArrayChild(self, i): ...
    def _SortableArrayEditor__isArray(self): ...
    def buildAddMenu(self, menu): ...
    def getArrayPanelClass(self): ...
    def newEntry(self): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class SortableArrayPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, policy, factory) -> None: ...
    def getFormWidget(self): ...
    def getPolicy(self): ...

class _HintWrapperPolicyProxy(QT4FormWidgets.ValuePolicy.ValuePolicyProxy):
    def __init__(self, policy, extraHints) -> None: ...
    def getWidgetHints(self): ...
