# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import UI4.FormMaster as FormMaster
import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets.SortableTreeWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Utils as Utils
import UI4.Widgets as Widgets
from QT4FormWidgets.FormWidget import FormWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AttrSourceStateSource(PyQt5.QtCore.QObject):
    def __init__(self, prefix, attrSource) -> None: ...
    def getHints(self, path): ...

class ShadingNetworkMaterialInterfaceOrderFormWidget(FormWidget):
    class _ShadingNetworkMaterialInterfaceOrderFormWidget__TreeDelegate(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItemDelegate):
        GRAYED_PALETTE: ClassVar[None] = ...
        def _TreeDelegate__buildPalette(self, palette): ...
        def paint(self, painter, option, index): ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__aboutToDragCallback(self, items, dragObject): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__addTreePolicy(self, parent, policy, leafIndex, openNames, interfaceAttr, parentPath: str = ...): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__buildFromCurrentState(self, onlyLocals: bool = ...): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__dragMoveEventCallback(self, event, parent, index, callbackRecord): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__dropEventCallback(self, event, parent, index): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__getDragSlices(self, items): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__getFirstNonPageIndex(self, item): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__getSliceCount(self, item, count: Incomplete | None = ...): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__jumpToSource(self): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__listMousePressEvent(self, event): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__menuAboutToShow(self, menu, selectedItems: Incomplete | None = ...): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__treeContextMenuCallback(self, event: PyQt5.QtGui.QContextMenuEvent): ...
    def _ShadingNetworkMaterialInterfaceOrderFormWidget__updateTree(self): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildTopAreaLayout(self, layout): ...
    def showPopdown(self, value: bool): ...
    def valueChangedEvent(self, event): ...
