# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from typing import Set, Tuple

def AddInput(node: NodegraphAPI.Node): ...
def AddPostScript(node: NodegraphAPI.Node): ...
def DeleteInput(node: NodegraphAPI.Node, index): ...
def DeletePostScript(node: NodegraphAPI.Node, index): ...
def EnableFirstInput(node: NodegraphAPI.Node): ...
def GetActiveViewMask(node: NodegraphAPI.Node): ...
def IsParameterTreeOutOfDate(node: NodegraphAPI.Node): ...
def ReorderInput(node: NodegraphAPI.Node, index, newIndex): ...
def ReorderPostScript(node: NodegraphAPI.Node, index, newIndex): ...
def SyncAllOutputPorts(): ...
def SyncOutputPorts(node: NodegraphAPI.Node): ...
def SyncParametersToPorts(node: NodegraphAPI.Node): ...
