# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class GroupParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _GroupParameterPolicy__clearMissingCached(self): ...
    def _GroupParameterPolicy__getChildPolicyObject(self, childParam): ...
    def _GroupParameterPolicy__recursivelyUpdateHintsForPolicy(self, policy): ...
    def _childPolicyRenamed(self, childPolicy): ...
    def _freeze(self): ...
    def _handleHintChanged(self, args): ...
    def _handleNodeNameChanged(self, args: list[tuple[str, object, dict]]): ...
    def _handleTopologyChanged(self, args): ...
    def _thaw(self): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
