# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Widgets.PanelScrollArea import PanelScrollArea
from typing import Set, Tuple

class ProjectSettingsPanel(PanelScrollArea):
    def __init__(self, *args) -> None: ...
    def _ProjectSettingsPanel__collapsedEventHandler(self, args): ...
    def _ProjectSettingsPanel__rebuild(self): ...
    def highlightParameter(self, path): ...
    def showFindPopup(self): ...

class ProjectSettingsTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _ProjectSettingsTab__findSettingActionCallback(self): ...
    def highlightParameter(self, path): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
