# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def axisAngleToQuaternion(axis, angle): ...
def crossProduct3(a, b): ...
def decomposeMatrix4x4(m): ...
def dotProduct3(a, b): ...
def explodeMatrix4x4(m): ...
def identity(): ...
def invert(m): ...
def magnitude3(a): ...
def multiply(a: None, b: None): ...
def multiplyv3(m: None, v: None): ...
def multiplyv4(m: None, v: None): ...
def normalize3(a): ...
def quaternionToRotationMatrix(quat): ...
def scaleMatrix(x, y, z): ...
def transformPoint4ByMatrix4x4(p, m): ...
def translationMatrix(x, y, z): ...
def transpose4x4(m): ...
def xRotationMatrix(x): ...
def xformPointByMatrix(p, m): ...
def yRotationMatrix(y): ...
def zRotationMatrix(z): ...
