# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.ConditionalHints as ConditionalHints
import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import UI4.Widgets.SortablePanel as SortablePanel
import UI4.Widgets.SortablePanel
from QT4FormWidgets.StringFormWidget import StringFormWidget
from UI4.Util.UndoGrouping import UndoGrouping as UndoGrouping
from typing import Set, Tuple

class OperationGroupEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def _OperationGroupEditor__addOperatorsToMenu(self, menu, names): ...
    def _getPanelForPolicy(self, vp): ...
    def buildAddMenu(self, menu): ...

class OperationPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, widgetFactory) -> None: ...

class PathNameString(StringFormWidget):
    def checkMimeData(self, data): ...
    def setMimeData(self, data, dropAction): ...

class TargetNameString(StringFormWidget):
    def checkMimeData(self, data): ...
    def setMimeData(self, data, dropAction): ...

def _IsValidMimeDrop(data): ...
def _checkIfPolicyIsPage(data): ...
