# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.CameraCreate as CameraCreate
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.CameraCreate
import PyXmlIO as PyXmlIO
import Naming as UniqueName
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict
_Manipulator_XML: str

class LightNode3D(Nodes3DAPI.CameraCreate.CameraNode3D):
    def __init__(self) -> None: ...
    def AddGroup(self): ...
    def DeleteGroup(self, index): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def getCameraAttributes(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getCameraGeometry(self, cameraName, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def getCurveEditorNameHint(self, paramName): ...
    def getDefaultObjectName(self): ...
    def getExtraParameters(self): ...
    def getManipulatorAttributes(self, frameTime, presetAttrs): ...
    def getObjectType(self): ...
    def getOrCreateManipulatorGroup(self, preset, manipName, frameTime): ...
    def getRootAttr(self, objScenegraphLocation): ...
    def getViewerInfo(self, frameTime): ...
    def getWorldAttr(self, objScenegraphLocation, frameTime: Incomplete | None = ...): ...
    def setOverride(self, path, attrName, time, attrData, **kwargs): ...
