# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.HintsDelegate as HintsDelegate
from typing import Set, Tuple

_DotNodeHints: dict
_TeleportHints: dict
