# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class OpaqueWidget(PyQt5.QtWidgets.QWidget):
    def paintEvent(self, event): ...

class WidgetHilightBox(PyQt5.QtCore.QObject):
    def __init__(self, target, width: int = ..., color: PyQt5.QtGui.QColor = ...) -> None: ...
    def hide(self): ...
    def setColor(self, color): ...
    def show(self): ...
    def snapToSize(self): ...
    def __del__(self) -> None: ...
