# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Utils as Utils
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from _typeshed import Incomplete
from typing import Set, Tuple

def CreateLastFileSaveBookmark(): ...
def CreateScenegraphBookmark(bookmarkName: str, openSet: set[str], selectionSet: set[str], pinSet: set[str]): ...
def CreateWorkingSetsBookmark(bookmarkName: str, workingSetNames: Incomplete | None = ..., excludeWorkingSetNames: Incomplete | None = ..., bookmarkIfEmpty: bool = ...): ...
def DeleteScenegraphBookmark(bookmarkName: str): ...
def GetScenegraphBookmarkXML() -> str: ...
def GetScenegraphBookmarks() -> list[dict]: ...
def GetScenegraphFolders() -> list[str]: ...
def ImportScenegraphBookmarkXML(xml: str): ...
def LoadBookmark(bookmarkDict: dict, workingSetNames: Incomplete | None = ..., excludeWorkingSetNames: Incomplete | None = ...): ...
