# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import drawing_cmodule as DrawingModule
import Utils.EventModule as EventModule
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def CopyNodeColorToLinkColor(node: NodegraphAPI.Node): ...
def GetCustomNodeColor(node: NodegraphAPI.Node): ...
def HasCustomNodeColor(node: NodegraphAPI.Node): ...
def RemoveCustomNodeColor(node: NodegraphAPI.Node): ...
def SetCustomNodeColor(node: NodegraphAPI.Node, r, g, b): ...
